@@ -106,8 +106,8 @@ $stile_soldi = stile_soldi();
 if ($priv_ins_entrate != "s") $inserisci_entrata = "";
 if ($priv_ins_spese != "s") $inserisci_spesa = "";
 
-if ($inserisci_entrata or $inserisci_spesa) {
-if ($inserisci_entrata) $inserisci_spesa = "";
+if (!empty($inserisci_entrata) or !empty($inserisci_spesa)) {
+if (!empty($inserisci_entrata)) $inserisci_spesa = "";
 $mostra_form_inserimento = "NO";
 $tabelle_lock = array($tablecosti);
 $altre_tab_lock = array($tablepersonalizza,$tablecasse);
@@ -211,13 +211,13 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"costi.php\"><div>
 </div></form>";
 
 unlock_tabelle($tabelle_lock);
-} # fine if ($inserisci_entrata or $inserisci_spesa)
+} # fine if (!empty($inserisci_entrata) or !empty($inserisci_spesa))
 
 
 
 
 
-if ($mostra_form_inserimento != "NO") {
+if (!isset($mostra_form_inserimento) or $mostra_form_inserimento != "NO") {
 
 $casse = esegui_query("select * from $tablecasse order by idcasse");
 $num_casse = numlin_query($casse);
@@ -246,7 +246,7 @@ $metodo_pagamento_txt = "<tr><td>".mex("Metodo di pagamento",$pag).":
  <select name=\"metodo_pagamento\">
 <option value=\"\">----</option>";
 $metodi_pagamento = explode(",",$metodi_pagamento);
-for ($num1 = 0 ; $num1 < count($metodi_pagamento) ; $num1++) $metodo_pagamento_txt .= "<option value=\"".$metodi_pagamento[$num1]."\"$sel>".$metodi_pagamento[$num1]."</option>";
+for ($num1 = 0 ; $num1 < count($metodi_pagamento) ; $num1++) $metodo_pagamento_txt .= "<option value=\"".$metodi_pagamento[$num1]."\">".$metodi_pagamento[$num1]."</option>";
 $metodo_pagamento_txt .= "</select>&nbsp;(".mex("opzionale",$pag).").</td></tr>";
 } # fine if ($metodi_pagamento)
 
@@ -342,7 +342,7 @@ echo "<table><tr><td style=\"height: 8px;\"></td></tr></table>
 </div></form><table><tr><td style=\"height: 20px;\"></td></tr></table>";
 
 
-} # fine if ($mostra_form_inserimento != "NO")
+} # fine if (!isset($mostra_form_inserimento) or $mostra_form_inserimento != "NO")
 
 
 
