@@ -43,7 +43,9 @@ $var_pag[14] = 'lingua';
 $var_pag[15] = 'torna_a_contr';
 $var_pag[16] = 'mostra_header';
 $var_pag[17] = 'salva_backup';
-$n_var_pag = 18;
+$var_pag[18] = 'includi_modelli';
+$var_pag[19] = 'cancella_backup';
+$n_var_pag = 20;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -104,7 +106,7 @@ if (fixset($azione) == "SI") {
 if (!empty($crea_backup)) {
 include_once("./includes/funzioni_$PHPR_DB_TYPE"."_extra.php");
 
-if ($backup_contratti != "SI") {
+if (!isset($backup_contratti) or $backup_contratti != "SI") {
 $raggiunto_limite = 0;
 if (defined('C_LIMITE_BACKUP_GIORNALIERI') and C_LIMITE_BACKUP_GIORNALIERI > 0 and $id_utente != "b") {
 $tabelle_lock = array($tablecache);
@@ -363,7 +365,7 @@ if (@is_file("$percorso_cartella_modello/$nome_file")) dump_modello($nome_file,$
 $lang_dir = opendir("./includes/lang/");
 while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != "..") {
-if ($template_file_name[$ini_lingua]) $nome_file = $template_file_name[$ini_lingua];
+if (!empty($template_file_name[$ini_lingua])) $nome_file = $template_file_name[$ini_lingua];
 else $nome_file = $ini_lingua."_".$template_file_name['en'];
 if (@is_file("$percorso_cartella_modello/$nome_file")) dump_modello($nome_file,$percorso_cartella_modello,$file);
 } # fine if ($ini_lingua != "." && $ini_lingua != "..")
@@ -386,7 +388,7 @@ echo mex("File creato",$pag).".<br>
 else echo mex("Non ho il permesso di scrittura sul file",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
 } # fine else if ($raggiunto_limite)
-} # fine if ($backup_contratti != "SI")
+} # fine if (!isset($backup_contratti) or $backup_contratti != "SI")
 
 
 else {
@@ -428,29 +430,29 @@ unlock_tabelle($tabelle_lock);
 echo mex("File creato",$pag).".<br>";
 } # fine if ($file)
 else echo mex("Non ho il permesso di scrittura sul file",$pag)." dati/hoteld_doc_backup.php.<br>";
-} # fine else if ($backup_contratti != "SI")
+} # fine else if (!isset($backup_contratti) or $backup_contratti != "SI")
 } # fine if (!empty($crea_backup))
 
 
 
 if (!empty($upload_backup) and $id_utente == 1) {
 $errore = "NO";
-if ($backup_contratti != "SI") {
+if (!isset($backup_contratti) or $backup_contratti != "SI") {
 $file_tmp = C_DATI_PATH."/hoteld_backup.php.tmp";
 $file_backup = C_DATI_PATH."/hoteld_backup.php";
-} # fine if ($backup_contratti != "SI")
+} # fine if (!isset($backup_contratti) or $backup_contratti != "SI")
 else {
 $file_tmp = C_DATI_PATH."/hoteld_doc_backup.php.tmp";
 $file_backup = C_DATI_PATH."/hoteld_doc_backup.php";
-} # fine else if ($backup_contratti != "SI")
-if (!$file_backup_upload) {
-if ($HTTP_POST_FILES['file_backup_upload']['tmp_name']) $file_backup_upload = $HTTP_POST_FILES['file_backup_upload']['tmp_name'];
-else if ($_FILES['file_backup_upload']['tmp_name']) $file_backup_upload = $_FILES['file_backup_upload']['tmp_name'];
-} # fine if (!$file_backup_upload)
+} # fine else if (!isset($backup_contratti) or $backup_contratti != "SI")
+if (empty($file_backup_upload)) {
+if (!empty($HTTP_POST_FILES['file_backup_upload']['tmp_name'])) $file_backup_upload = $HTTP_POST_FILES['file_backup_upload']['tmp_name'];
+else if (!empty($_FILES['file_backup_upload']['tmp_name'])) $file_backup_upload = $_FILES['file_backup_upload']['tmp_name'];
+} # fine if (empty($file_backup_upload))
 if (!move_uploaded_file($file_backup_upload,$file_tmp)) $errore = "SI";
 if ($errore == "NO") {
 if (defined("C_MASSIMO_NUM_BYTE_UPLOAD") and C_MASSIMO_NUM_BYTE_UPLOAD != 0 and filesize($file_tmp) > C_MASSIMO_NUM_BYTE_UPLOAD) $errore = "SI";
-if ($compresso == "SI") {
+if (isset($compresso) and $compresso == "SI") {
 if (rename($file_tmp,"$file_tmp.gz")) {
 if ($cfp = gzopen("$file_tmp.gz","r") and $fileaperto = fopen($file_tmp,"w")) {
 flock($fileaperto,2);
@@ -464,7 +466,7 @@ gzclose($cfp);
 } # fine if ($cfp = gzopen("$file_tmp.gz","r") and...
 unlink("$file_tmp.gz");
 } # fine if (rename($file_tmp,"$file_tmp.gz"))
-} # fine if ($compresso == "SI")
+} # fine if (isset($compresso) and $compresso == "SI")
 unset($linee_file);
 $fileaperto = fopen($file_tmp,"r");
 $linee_file = trim(fread($fileaperto,25));
@@ -498,7 +500,7 @@ $file = C_DATI_PATH."/hoteld_doc_backup.php";
 $filelock = @crea_lock_file($file);
 if ($filelock) {
 if (@is_file($file)) {
-if ($compresso == "SI") {
+if (isset($compresso) and $compresso == "SI") {
 list($usec,$sec) = explode(' ',microtime());
 mt_srand((float) $sec + ((float) $usec * 100000));
 $file_compresso = C_DATI_PATH."/backup".mt_rand(10000,99999).".php.gz";
@@ -514,14 +516,14 @@ fclose ($fbackup);
 gzclose($cfp);
 $file = $file_compresso;
 $nome_file = $nome_file_compresso;
-} # fine if ($compresso == "SI")
+} # fine if (isset($compresso) and $compresso == "SI")
 $lunghezza_file = (int) filesize($file);
 header("Pragma: public");
 header("Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT");
 header("Cache-Control: no-store, no-cache, must-revalidate");
 header("Cache-Control: pre-check=0, post-check=0, max-age=0");
 header("Content-Transfer-Encoding: none");
-if ($compresso == "SI") header("Content-Type: application/x-gzip; name=\"$nome_file\"");
+if (isset($compresso) and $compresso == "SI") header("Content-Type: application/x-gzip; name=\"$nome_file\"");
 else {
 header("Content-Type: application/octetstream; name=\"$nome_file\"");
 header("Content-Type: application/octet-stream; name=\"$nome_file\"");
@@ -546,7 +548,7 @@ if ($id_utente == "b") unlink(C_DATI_PATH."/backup_ext.php");
 
 
 if (!empty($cancella_backup)) {
-if ($backup_contratti != "SI") $file_backup = C_DATI_PATH."/hoteld_backup.php";
+if (!isset($backup_contratti) or $backup_contratti != "SI") $file_backup = C_DATI_PATH."/hoteld_backup.php";
 else $file_backup = C_DATI_PATH."/hoteld_doc_backup.php";
 if (!@unlink($file_backup)) echo mex("Si è verificato un errore cancellando il file",$pag).".<br>";
 else echo mex("File cancellato",$pag).".<br>";
@@ -605,15 +607,15 @@ fclose($prova);
 } # fine if ($prova = @fopen(C_DATI_PATH."/prova","w"))
 else $dati_scrivibile = "NO";
 if ($versione_file and $versione_file == $versione_corrente) {
-if ($dati_scrivibile != "NO") {
+if (!isset($dati_scrivibile) or $dati_scrivibile != "NO") {
 
-if ($continua != "SI") {
+if (!isset($continua) or $continua != "SI") {
 echo "<br><big>".mex("<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, prima di ripristinare i dati dal <i>file</i>, tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>",$pag)."!</big><br><br>";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./crea_backup.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"ripristina_backup\" value=\"$ripristina_backup\">
-<input type=\"hidden\" name=\"mantieni_anni\" value=\"$mantieni_anni\">
+<input type=\"hidden\" name=\"mantieni_anni\" value=\"".htmlspecialchars(fixset($mantieni_anni))."\">
 <input type=\"hidden\" name=\"azione\" value=\"SI\">
 <input type=\"hidden\" name=\"continua\" value=\"SI\">";
 
@@ -669,7 +671,7 @@ echo "<div style=\"text-align: center;\">
 <button class=\"rbkp\" type=\"submit\"><div>".mex("Continua",$pag)."</div></button>
 </div></div></form><br>";
 
-} # fine if ($continua != "SI")
+} # fine if (!isset($continua) or $continua != "SI")
 
 if ($dati_conn == "attuali") {
 $N_PHPR_DB_TYPE = $PHPR_DB_TYPE;
@@ -682,9 +684,9 @@ $N_PHPR_LOAD_EXT = $PHPR_LOAD_EXT;
 $N_PHPR_TAB_PRE = $PHPR_TAB_PRE;
 } # fine if ($dati_conn == "attuali")
 
-if ($continua == "SI" and ((!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI") or (defined('C_PASS_DEMO_ADMIN') and C_PASS_DEMO_ADMIN == $pass_demo_admin))) ripristina_backup($file,"NO",$pag,$numconnessione,$database_esistente,$tempdatabase,$PHPR_DB_TYPE,$PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT,$PHPR_TAB_PRE,$N_PHPR_DB_TYPE,$N_PHPR_DB_NAME,$N_PHPR_DB_HOST,$N_PHPR_DB_PORT,$N_PHPR_DB_USER,$N_PHPR_DB_PASS,$N_PHPR_LOAD_EXT,$N_PHPR_TAB_PRE,$ext_pgsql_caricata,$ext_mysql_caricata,$mantieni_anni);
+if (isset($continua) and $continua == "SI" and ((!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI") or (defined('C_PASS_DEMO_ADMIN') and C_PASS_DEMO_ADMIN == $pass_demo_admin))) ripristina_backup($file,"NO",$pag,$numconnessione,fixset($database_esistente),fixset($tempdatabase),$PHPR_DB_TYPE,$PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT,$PHPR_TAB_PRE,$N_PHPR_DB_TYPE,$N_PHPR_DB_NAME,$N_PHPR_DB_HOST,$N_PHPR_DB_PORT,$N_PHPR_DB_USER,$N_PHPR_DB_PASS,$N_PHPR_LOAD_EXT,$N_PHPR_TAB_PRE,$ext_pgsql_caricata,$ext_mysql_caricata,$mantieni_anni);
 
-} # fine if ($dati_scrivibile != "NO")
+} # fine if (!isset($dati_scrivibile) or $dati_scrivibile != "NO")
 else echo mex("Non ho i permessi di scrittura sulla cartella dati",$pag).".<br>";
 } # fine if ($versione_file and $versione_file == $versione_corrente)
 else {
@@ -702,7 +704,7 @@ else {
 if (@is_file(C_DATI_PATH."/hoteld_doc_backup.php")) {
 if ($linee_backup = file(C_DATI_PATH."/hoteld_doc_backup.php")) {
 
-if (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI") ripristina_backup_contr($linee_backup,"NO",$pag,$PHPR_TAB_PRE,$modalita,$contr_agg);
+if (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI") ripristina_backup_contr($linee_backup,"NO",$pag,$PHPR_TAB_PRE,$modalita,fixset($contr_agg));
 
 } # fine if ($linee_backup = file(C_DATI_PATH."/hoteld_doc_backup.php"))
 else echo mex("Non ho potuto leggere il file",$pag).".<br>";
