@@ -723,11 +723,11 @@ else {
 $idregole = esegui_query("select max(idregole) from $tableregole");
 $idregole = risul_query($idregole,0,0);
 $idregole = $idregole + 1;
-if ($regola_2b) esegui_query("insert into $tableregole (idregole,tariffa_per_app,iddatainizio,motivazione2) values ('$idregole','".aggslashdb($tipotariffa)."','$num_giorni','$lista_app')");
+if (!empty($regola_2b)) esegui_query("insert into $tableregole (idregole,tariffa_per_app,iddatainizio,motivazione2) values ('$idregole','".aggslashdb($tipotariffa)."','$num_giorni','$lista_app')");
 else {
 esegui_query("insert into $tableregole (idregole,tariffa_per_app,motivazione) values ('$idregole','".aggslashdb($tipotariffa)."','$lista_app')");
 if ($num_apti > 1) esegui_query("update $tableregole set motivazione3 = '$v_apti$num_apti' where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
-} # fine else if ($regola_2b)
+} # fine else if (!empty($regola_2b))
 echo "<br>".mex("La regola di assegnazione",$pag)." 2 ".mex("è stata inserita",$pag).".<br><br>";
 } # fine else if ($num_regole_esistente != 0)
 $aggiorna_ic_disp = 1;
@@ -883,9 +883,9 @@ $mostra_solo_regola = 3;
 $origine = "visualizza_tabelle.php?tipo_tabella=regole#hreg3";
 } # fine if ($origine == "tab_reg3")
 if ($origine == "tab_tariffa") {
-if ($tipotariffa_regola2) $mostra_solo_regola = 2;
-if ($tipotariffa_regola3) $mostra_solo_regola = 3;
-$origine = "tab_tariffe.php?numtariffa1=".htmlspecialchars(substr($tipotariffa_regola2.$tipotariffa_regola3,7));
+if (!empty($tipotariffa_regola2)) $mostra_solo_regola = 2;
+if (!empty($tipotariffa_regola3)) $mostra_solo_regola = 3;
+$origine = "tab_tariffe.php?numtariffa1=".htmlspecialchars(substr($tipotariffa_regola2.fixset($tipotariffa_regola3),7));
 } # fine if ($origine == "tab_tariffa")
 if (substr($origine,0,3) == "ic_") {
 $orig = explode("_",$origine);
