@@ -30,7 +30,23 @@ $var_pag[2] = 'continua';
 $var_pag[3] = 'prima_pass';
 $var_pag[4] = 'seconda_pass';
 $var_pag[5] = 'tipo_pass';
-$n_var_pag = 6;
+$var_pag[6] = 'modifica_utenti';
+$var_pag[7] = 'num_utenti_tab';
+$var_pag[8] = 'prima_pass1';
+$var_pag[9] = 'seconda_pass1';
+$var_pag[10] = 'tipo_pass1';
+$n_var_pag = 11;
+$num2 = 0;
+if (isset($_POST['num_utenti_tab'])) $num2 = (int) $_POST['num_utenti_tab'];
+elseif (isset($_GET['num_utenti_tab'])) $num2 = (int) $_GET['num_utenti_tab'];
+for ($num1 = 0 ; $num1 < $num2 ; $num1++) {
+$var_pag[$n_var_pag++] = "id_utente_tab$num1";
+$num3= 0;
+if (isset($_POST["id_utente_tab$num1"])) $num3 = (int) $_POST["id_utente_tab$num1"];
+elseif (isset($_GET["id_utente_tab$num1"])) $num3 = (int) $_GET["id_utente_tab$num1"];
+$var_pag[$n_var_pag++] = "nome$num3";
+$var_pag[$n_var_pag++] = "tipo_pass$num3";
+} # fine for $num1
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -61,21 +77,23 @@ if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$t
 else include("./includes/head.php");
 
 
-if ($modifica_utenti) {
+if (!empty($modifica_utenti)) {
 $mostra_tabella_iniziale = "NO";
 $tabelle_lock = array($tableutenti,$tablesessioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 if (defined('C_RESTRIZIONI_DEMO_ADMIN') and C_RESTRIZIONI_DEMO_ADMIN == "SI") $cond_escludi_admin = " where idutenti != '1'";
 else $cond_escludi_admin = "";
 $lista_utenti = esegui_query("select idutenti,nome_utente,password,tipo_pass from $tableutenti$cond_escludi_admin order by idutenti");
+$num_lista_utenti = numlin_query($lista_utenti);
 
-if ($continua != "SI") {
+if (!isset($continua) or $continua != "SI") {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"modifica_utenti\" value=\"SI\">
+<input type=\"hidden\" name=\"num_utenti_tab\" value=\"$num_lista_utenti\">
 <input type=\"hidden\" name=\"continua\" value=\"SI\">";
-for ($num1 = 0 ; $num1 < numlin_query($lista_utenti) ; $num1++) {
+for ($num1 = 0 ; $num1 < $num_lista_utenti ; $num1++) {
 $cambiato = "NO";
 $id = risul_query($lista_utenti,$num1,'idutenti');
 if (@get_magic_quotes_gpc()) {
@@ -84,7 +102,7 @@ ${"prima_pass".$id} = stripslashes(${"prima_pass".$id});
 } # fine if (@get_magic_quotes_gpc())
 ${"nome".$id} = elimina_caratteri_slash (${"nome".$id});
 ${"tipo_pass".$id} = aggslashdb(${"tipo_pass".$id});
-${"prima_pass".$id} = aggslashdb(${"prima_pass".$id});
+${"prima_pass".$id} = aggslashdb(fixset(${"prima_pass".$id}));
 $nome = risul_query($lista_utenti,$num1,'nome_utente');
 if (htmlspecialchars(${"nome".$id}) != ${"nome".$id}) ${"nome".$id} = $nome;
 $tipo_pass = risul_query($lista_utenti,$num1,'tipo_pass');
@@ -93,7 +111,8 @@ if ($nome != ${"nome".$id} and str_replace("&","",${"nome".$id}) == ${"nome".$id
 $cambiato = "SI";
 $cambia_nome = 1;
 echo mex("Il <b>nome</b> dell'utente",$pag)." <b>$id</b> ".mex("verrà cambiato da",$pag)." <i>$nome</i> ".mex("a",$pag)." <i>".${"nome".$id}."</i>.<br>";
-echo "<input type=\"hidden\" name=\"nome$id\" value=\"".${"nome".$id}."\">";
+echo "<input type=\"hidden\" name=\"nome$id\" value=\"".${"nome".$id}."\">
+<input type=\"hidden\" name=\"id_utente_tab$num1\" value=\"$id\">";
 } # fine if ($nome != ${"nome".$id} and...
 $n_tipo_pass = ${"tipo_pass".$id};
 if ($n_tipo_pass != "5" and $n_tipo_pass != "t") $n_tipo_pass = "n";
@@ -134,14 +153,14 @@ echo "<button class=\"musr\" type=\"submit\"><div>".mex("Continua",$pag)."</div>
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form>";
-} # fine if ($continua != "SI")
+} # fine if (!isset($continua) or $continua != "SI")
 
 else {
-for ($num1 = 0 ; $num1 < numlin_query($lista_utenti) ; $num1++) {
+for ($num1 = 0 ; $num1 < $num_lista_utenti ; $num1++) {
 $id = risul_query($lista_utenti,$num1,'idutenti');
-${"nome".$id} = elimina_caratteri_slash (${"nome".$id});
-${"tipo_pass".$id} = aggslashdb(${"tipo_pass".$id});
-${"prima_pass".$id} = aggslashdb(${"prima_pass".$id});
+${"nome".$id} = elimina_caratteri_slash (fixset(${"nome".$id}));
+${"tipo_pass".$id} = aggslashdb(fixset(${"tipo_pass".$id}));
+${"prima_pass".$id} = aggslashdb(fixset(${"prima_pass".$id}));
 $nome = risul_query($lista_utenti,$num1,'nome_utente');
 $tipo_pass = risul_query($lista_utenti,$num1,'tipo_pass');
 $nome_esistente = esegui_query("select idutenti from $tableutenti where nome_utente = '".${"nome".$id}."'");
@@ -202,13 +221,13 @@ if ($id == 1 and @is_file(C_DATI_PATH."/abilita_login")) unlink(C_DATI_PATH."/ab
 } # fine if ($n_tipo_pass and $tipo_pass != $n_tipo_pass)
 } # fine for $num1
 } # fine else if ($continua == "NO")
-} # fine else if ($continua != "SI")
+} # fine else if (!isset($continua) or $continua != "SI")
 
 unlock_tabelle($tabelle_lock);
-} # fine if ($modifica_utenti)
+} # fine if (!empty($modifica_utenti))
 
 
-if ($aggiungi_utente) {
+if (!empty($aggiungi_utente)) {
 if (htmlspecialchars($nome) != $nome) $nome = "";
 if ($nome) {
 $nome = elimina_caratteri_slash($nome);
@@ -331,10 +350,10 @@ aggiorna_relutenti("","","","SI",$id_utente,$nuovo_id,"","","","","",1,"","paren
 } # fine else if ($continua == "NO")
 
 } # fine if ($nome)
-} # fine if ($aggiungi_utente)
+} # fine if (!empty($aggiungi_utente))
 
 
-if ($modifica_pass) {
+if (!empty($modifica_pass)) {
 $tabelle_lock = array($tableutenti);
 $altre_tab_lock = "";
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
@@ -342,11 +361,11 @@ $dati_utente = esegui_query("select * from $tableutenti where idutenti = '".aggs
 if (numlin_query($dati_utente) != 1) $continua = "NO";
 else $nome_utente = risul_query($dati_utente,0,'nome_utente');
 if ($id_utente_pass == 1 and defined('C_RESTRIZIONI_DEMO_ADMIN') and C_RESTRIZIONI_DEMO_ADMIN == "SI") $continua = "NO";
-if ($continua == "SI" and ($prima_pass != $seconda_pass or $prima_pass == "" or $prima_pass != str_replace("&","",$prima_pass))) {
+if (isset($continua) and $continua == "SI" and ($prima_pass != $seconda_pass or $prima_pass == "" or $prima_pass != str_replace("&","",$prima_pass))) {
 unset($continua);
 echo mex("Le nuove password non coincidono",$pag).".<br><br>";
-} # fine if ($continua == "SI" and ($prima_pass != $seconda_pass or...
-if (!$continua) {
+} # fine if (isset($continua) and $continua == "SI" and ($prima_pass != $seconda_pass or...
+if (empty($continua)) {
 $mostra_tabella_iniziale = "NO";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -357,8 +376,8 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.ph
 ".mex("Inserisci una nuova password per l'utente",$pag)." <b>$nome_utente</b>.<br><br>
 ".mex("Nuova password",$pag).": <input type=\"password\" name=\"prima_pass\" size=\"12\"><br>
 ".mex("Ripeti la password",$pag).": <input type=\"password\" name=\"seconda_pass\" size=\"12\"><br><br>";
-echo "<input type=\"hidden\" name=\"tipo_pass$id\" value=\"$n_tipo_pass\">";
-if ($cambiato == "SI") echo "<hr style=\"width: 45%; margin-left: 0; text-align: left;\">";
+#echo "<input type=\"hidden\" name=\"tipo_pass$id\" value=\"$n_tipo_pass\">";
+if (isset($cambiato) and $cambiato == "SI") echo "<hr style=\"width: 45%; margin-left: 0; text-align: left;\">";
 echo "<button class=\"cont\" type=\"submit\"><div>".mex("Continua",$pag)."</div></button>
 </div></form><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.php\"><div>
@@ -366,8 +385,8 @@ echo "<button class=\"cont\" type=\"submit\"><div>".mex("Continua",$pag)."</div>
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form>";
-} # fine if (!$continua)
-if ($continua == "SI") {
+} # fine if (empty($continua))
+if (isset($continua) and $continua == "SI") {
 $tipo_pass = risul_query($dati_utente,0,'tipo_pass');
 if ($tipo_pass != "n") {
 $salt = "";
@@ -380,12 +399,12 @@ for ($num1 = 0 ; $num1 < 15 ; $num1++) $prima_pass = md5($prima_pass.substr($sal
 } # fine if ($tipo_pass == "5")
 esegui_query("update $tableutenti set password = '$prima_pass', salt = '$salt' where idutenti = '$id_utente_pass'");
 } # fine if ($tipo_pass != "n")
-} # fine if ($continua == "SI")
+} # fine if (isset($continua) and $continua == "SI")
 unlock_tabelle($tabelle_lock);
-} # fine if ($modifica_pass)
+} # fine if (!empty($modifica_pass))
 
 
-if ($modifica_gruppi) {
+if (!empty($modifica_gruppi)) {
 if (htmlspecialchars($nuovo_gruppo) != $nuovo_gruppo) $nuovo_gruppo = "";
 $nuovo_gruppo = elimina_caratteri_slash($nuovo_gruppo);
 $tabelle_lock = array("$tableutenti","$tablegruppi","$tablerelgruppi");
@@ -494,10 +513,10 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.ph
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form>";
 } # fine if ($mostra_tabella_iniziale == "NO")
-} # fine if ($modifica_gruppi)
+} # fine if (!empty($modifica_gruppi))
 
 
-if ($cancella or $importa_priv) {
+if (!empty($cancella) or !empty($importa_priv)) {
 function cancella_relazioni_utente ($tablerelutenti,$idrelutenti,$tablerel,$idrel) {
 $relazioni = esegui_query("select $idrel from $tablerel");
 $num_rel = numlin_query($relazioni);
@@ -507,10 +526,10 @@ $rel_esist = esegui_query("select $idrelutenti from $tablerelutenti where $idrel
 if (numlin_query($rel_esist) == 0) esegui_query("delete from $tablerel where $idrel = '$relazione' ");
 } # fine for $num1
 } # fine function cancella_relazioni_utente
-} # fine if ($cancella or $importa_priv)
+} # fine if (!empty($cancella) or !empty($importa_priv))
 
 
-if ($cancella) {
+if (!empty($cancella)) {
 if ($id_utente_canc == 1) $id_utente_canc = 0;
 $id_utente_canc = aggslashdb($id_utente_canc);
 $dati_collegati = "NO";
@@ -600,10 +619,10 @@ distruggi_lock_file($filelock,C_DATI_PATH."/tema.php");
 } # fine else if ($continua != "SI")
 } # fine if ($continua != "NO")
 unlock_tabelle($tabelle_lock);
-} # fine if ($cancella)
+} # fine if (!empty($cancella))
 
 
-if ($importa_priv) {
+if (!empty($importa_priv)) {
 $id_utente_importa = aggslashdb($id_utente_importa);
 $id_utente_esporta = aggslashdb($id_utente_esporta);
 include("./includes/funzioni_menu.php");
@@ -719,11 +738,11 @@ if ($priv_importati == "SI") echo "<b>".mex("Privilegi importati",$pag).".</b><b
 if ($pers_importate == "SI") echo "<b>".mex("Personalizzazioni importate",$pag).".</b><br>";
 if ($grup_importati == "SI") echo "<b>".mex("Gruppi importati",$pag).".</b><br>";
 unlock_tabelle($tabelle_lock);
-} # fine if ($importa_priv)
+} # fine if (!empty($importa_priv))
 
 
 
-if ($mostra_tabella_iniziale != "NO") {
+if (!isset($mostra_tabella_iniziale) or $mostra_tabella_iniziale != "NO") {
 
 echo "<h4 id=\"h_usrs\"><span>";
 if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") echo mex("Gestione degli utenti",$pag);
@@ -786,7 +805,8 @@ else $mhash_sel = "";
 echo "<tr><td align=\"center\" valign=\"middle\">$id";
 if ($id == 1) echo "*";
 echo "</td>
-<td align=\"center\" valign=\"middle\"><input type=\"text\" name=\"nome$id\" size=\"15\" value=\"$nome\"></td>
+<td align=\"center\" valign=\"middle\"><input type=\"text\" name=\"nome$id\" size=\"15\" value=\"$nome\">
+<input type=\"hidden\" name=\"id_utente_tab$num1\" value=\"$id\"></td>
 <td align=\"center\" valign=\"middle\"><select name=\"tipo_pass$id\">";
 if (!defined('C_DISABILITA_PASS_ADMIN') or C_DISABILITA_PASS_ADMIN != "NO" or $id != 1 or $disab_sel) echo "<option value=\"n\"$disab_sel>".mex("disabilitato",$pag)."</option>";
 #echo "<option value=\"t\"$testo_sel>".mex("password conservata in chiaro",$pag)."</option>";
@@ -800,7 +820,7 @@ echo "</td>
 if ($tipo_pass != "n") echo "<a href=\"./gestione_utenti.php?anno=$anno&amp;id_sessione=$id_sessione&amp;modifica_pass=SI&amp;id_utente_pass=$id\">".mex("password",$pag)."</a>";
 if ($tipo_pass != "n" and $id != 1) echo "<br>";
 if ($id != 1) echo "<a href=\"./privilegi_utenti.php?anno=$anno&amp;id_sessione=$id_sessione&amp;id_utente_privilegi=$id\">".mex("privilegi",$pag)."</a>";
-if (!is_array($gruppi_utente_nome[$id])) $titolo_gruppi = "";
+if (!isset($gruppi_utente_nome[$id]) or !is_array($gruppi_utente_nome[$id])) $titolo_gruppi = "";
 else $titolo_gruppi = " title=\"".htmlspecialchars(implode(", ",$gruppi_utente_nome[$id]))."\"";
 echo "<br><a$titolo_gruppi href=\"./gestione_utenti.php?anno=$anno&amp;id_sessione=$id_sessione&amp;modifica_gruppi=SI&amp;id_utente_mod=$id\">".mex("gruppi",$pag)."</a>";
 if ($id != 1) {
@@ -830,6 +850,7 @@ echo "</table></div>
 <small>* ".mex("Amministratore",$pag).".&nbsp;&nbsp;&nbsp;
 ** ".mex("Abilitare per usare altri utenti",$pag).".</small><br>
 <input type=\"hidden\" name=\"modifica_utenti\" value=\"1\">
+<input type=\"hidden\" name=\"num_utenti_tab\" value=\"$num_lista_utenti\">
 <button class=\"musr\" type=\"submit\"><div>".mex("Modifica gli utenti",$pag)."</div></button>
 </div></form></div><br>";
 
@@ -876,7 +897,7 @@ $num_utenti_esistenti = esegui_query("select idutenti from $tableutenti");
 $num_utenti_esistenti = numlin_query($num_utenti_esistenti);
 if ($num_utenti_esistenti >= C_MASSIMO_NUM_UTENTI) $aggiungi_utenti = "NO";
 } # fine if (defined("C_MASSIMO_NUM_UTENTI") and C_MASSIMO_NUM_UTENTI != 0)
-if ($aggiungi_utenti != "NO") {
+if (!isset($aggiungi_utenti) or $aggiungi_utenti != "NO") {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -885,7 +906,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.ph
 <input type=\"hidden\" name=\"aggiungi_utente\" value=\"1\">
 <button class=\"ausr\" type=\"submit\"><div>".mex("Aggiungi",$pag)."</div></button>
 </div></form>";
-} # fine if ($aggiungi_utenti != "NO")
+} # fine if (!isset($aggiungi_utenti) or $aggiungi_utenti != "NO")
 
 echo "<br><div style=\"text-align: center;\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"personalizza.php\"><div>
@@ -894,7 +915,7 @@ echo "<br><div style=\"text-align: center;\">
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br></div>";
 
-} # fine if ($mostra_tabella_iniziale != "NO")
+} # fine if (!isset($mostra_tabella_iniziale) or $mostra_tabella_iniziale != "NO")
 
 
 
