@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -74,7 +74,8 @@ define('C_MASSIMO_NUM_COSTI',90000);
 define('C_MASSIMO_NUM_APP',0);
 define('C_MASSIMO_NUM_BYTE_UPLOAD',12582912);
 define('C_CREA_ULTIMO_ACCESSO',"SI");
-if (!defined('C_CARTELLA_CREA_MODELLI')) define('C_CARTELLA_CREA_MODELLI',"");
+#if (!defined('C_CARTELLA_CREA_MODELLI')) define('C_CARTELLA_CREA_MODELLI',"");
+#if (!defined('C_URL_CREA_MODELLI')) define('C_URL_CREA_MODELLI',"");
 define('C_DOMINIO_CREA_MODELLI',"");
 define('C_CHMOD_EXEC_MODELLI',"NO");
 define('C_CARTELLA_DOC',"");
@@ -96,7 +97,7 @@ define('C_URL_MODULO_PAYBOX',"http://");
 define('C_NASCONDI_MARCA',"");
 define('C_DISABILITA_COD_EMAIL_MODELLI',"NO");
 define('C_PASSWORD_BOOKINGCOM_IC',"");
-define('C_ORGANIZZAZIONE_VENERE_IC',"");
+define('C_PASSWORD_EXPEDIA_IC',"");
 define('C_API_KEY_BBLIVERATE_IC',"");
 define('C_URL_MOD_EXT_CARTE_CREDITO',"");
 define('C_IP_MOD_EXT_CARTE_CREDITO',"");
