@@ -252,6 +252,7 @@ $files_sorgente = array(
 'includes/templates/cal/phrases.php',
 'includes/templates/cal/template.php',
 'includes/templates/cal/themes.php',
+'includes/templates/cal/var.php',
 'includes/templates/rat/',
 'includes/templates/rat/form.php',
 'includes/templates/rat/functions.php',
@@ -259,6 +260,7 @@ $files_sorgente = array(
 'includes/templates/rat/phrases.php',
 'includes/templates/rat/template.php',
 'includes/templates/rat/themes.php',
+'includes/templates/rat/var.php',
 'includes/unit.php',
 'themes/',
 'themes/blu/',
