@@ -78,8 +78,8 @@ $trad_ui = 0;
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',3.02);
-define('C_PHPR_VERSIONE_TXT',"3.0.2");
+define('C_PHPR_VERSIONE_NUM',3.03);
+define('C_PHPR_VERSIONE_TXT',"3.0.3");
 
 if (!isset($nome_utente_phpr)) $nome_utente_phpr = "";;
 if (!isset($password_phpr)) $password_phpr = "";;
@@ -101,7 +101,7 @@ if (@is_file(C_DATI_PATH."/versione.php")) include(C_DATI_PATH."/versione.php");
 else define('C_DIFF_ORE',0);
 } # fine if (!defined('C_DIFF_ORE'))
 $anno_corrente = date("Y",(time() + (C_DIFF_ORE * 3600)));
-if (!isset($anno) or !$anno) {
+if (empty($anno)) {
 if ($id_sessione) $anno = substr($id_sessione,0,4);
 else {
 if (!defined('C_GIORNI_NUOVO_ANNO')) include("./costanti.php");
@@ -111,7 +111,7 @@ if ($anno_corrente != $anno) {
 if (@is_file(C_DATI_PATH."/selectperiodi$anno_corrente.1.php") or !@is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) $anno = $anno_corrente;
 } # fine if ($anno_corrente != $anno)
 } # fine else if ($id_sessione)
-} # fine if (!isset($anno) or !$anno)
+} # fine if (empty($anno))
 if ($id_sessione and $pag != "inizio.php" and $pag != "api.php" and $pag != "aggiorna.php" and !is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) $id_sessione = "";
 
 
@@ -179,6 +179,15 @@ else return null;
 
 
 
+function fix_set (&$var) {
+
+if (!isset($var)) $var = null;
+return $var;
+
+} # fine function fix_set
+
+
+
 function controlla_anno (&$anno) {
 
 $verificato = "SI";
@@ -1017,12 +1026,12 @@ if (substr($file,0,(strlen(C_DATI_PATH) + 15)) == C_DATI_PATH."/selperiodimenu"
 $lista_var = "";
 if (@is_array($_POST)) reset($_POST);
 for($num1 = 0 ; $num1 < count($_POST); $num1++) {
-if (key($_POST) != "mos_tut_dat" and substr(key($_POST),0,8) != "modifica") $lista_var .= "&amp;".htmlspecialchars(key($_POST))."=".htmlspecialchars(strip_magic_slashs($_POST[key($_POST)]));
+if (key($_POST) != "mos_tut_dat" and substr(key($_POST),0,8) != "modifica") $lista_var .= "&amp;".urlencode(key($_POST))."=".urlencode(strip_magic_slashs($_POST[key($_POST)]));
 next($_POST);
 } # fine for $num1
 if (@is_array($_GET)) reset($_GET);
 for($num1 = 0 ; $num1 < count($_GET); $num1++) {
-if (key($_GET) != "mos_tut_dat" and substr(key($_GET),0,8) != "modifica") $lista_var .= "&amp;".htmlspecialchars(key($_GET))."=".htmlspecialchars(strip_magic_slashs($_GET[key($_GET)]));
+if (key($_GET) != "mos_tut_dat" and substr(key($_GET),0,8) != "modifica") $lista_var .= "&amp;".urlencode(key($_GET))."=".urlencode(strip_magic_slashs($_GET[key($_GET)]));
 next($_GET);
 } # fine for $num1
 if ($lista_var) {
