@@ -198,7 +198,7 @@ $max_mese_prec = "";
 $data_ini_agg = "";
 } # fine else if (numlin_query($max_data_ini_prec) != 0)
 } # fine if ($importa_anno_prec == "SI")
-else unset($altre_tab_lock);
+else $altre_tab_lock = array();
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 # Elimino tutte le transazioni, potrebbero contenere date dell'anno creato
@@ -343,6 +343,7 @@ if ($importa_anno_prec == "SI" and @is_file(C_DATI_PATH."/selperiodimenu".($anno
 else copy(C_DATI_PATH."/selectperiodi$anno.1.php",C_DATI_PATH."/selperiodimenu$anno.1.php");
 
 $lista_clienti_importati = "";
+$inserisci_in_ntariffe = "";
 
 
 # Importo eventuali prenotazioni, tariffe e regole dell'anno precedente
@@ -1019,7 +1020,7 @@ $funz_crea_modello($percorso_cartella_modello,$anno_modello,$PHPR_TAB_PRE,$pag,$
 $lang_dir = opendir("./includes/lang/");
 while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != "..") {
-if ($template_file_name[$ini_lingua]) $nome_file = $template_file_name[$ini_lingua];
+if (!empty($template_file_name[$ini_lingua])) $nome_file = $template_file_name[$ini_lingua];
 else $nome_file = $ini_lingua."_".$template_file_name["en"];
 for ($num_cart = 0 ; $num_cart < $num_perc_cart_mod_vett ; $num_cart++) {
 $percorso_cartella_modello = $perc_cart_mod_vett[$num_cart];
