@@ -479,7 +479,7 @@ if ($dati_ca[$num_costo]['moltiplica'] == "c") $moltiplica = $nummoltiplica_ca;
 if ($dati_ca[$num_costo]['moltiplica'] == "p") $moltiplica = $numpersone;
 if ($dati_ca[$num_costo]['moltiplica'] == "t") {
 $letti_agg_max = 0;
-if ($dati_ca[$num_costo]['modo_cp_molt']) {
+if (!empty($dati_ca[$num_costo]['modo_cp_molt'])) {
 for ($num1 = $idinizioperiodo; $num1 <= $idfineperiodo; $num1++) {
 if ($dati_ca[$num_costo]['modo_cp_molt'] == "i") $num_letti_agg[$num1] = 0;
 for ($num2 = 0 ; $num2 < $dati_ca[$num_costo]['cp_molt']['num'] ; $num2++) {
@@ -490,7 +490,7 @@ else $num_letti_agg[$num1] = $num_letti_agg[$num1] - $num_letti_agg['catp_tot'][
 } # fine if (!empty($dati_ca[$num_costo]['cp_molt'][$cp]['esist']) and !empty($num_letti_agg['catp_tot'][$num1][$cp]))
 } # fine for $num2
 } # fine for $num1
-} # fine if ($dati_ca[$num_costo]['modo_cp_molt'])
+} # fine if (!empty($dati_ca[$num_costo]['modo_cp_molt']))
 if ($dati_ca[$num_costo]['tipo'] == "s" and $dati_ca[$num_costo]['associasett'] == "s") {
 for ($num1 = $idinizioperiodo; $num1 <= $idfineperiodo; $num1++) {
 if (!strcmp(fixset($num_letti_agg[$num1]),"")) $num_letti_agg[$num1] = 0;
