@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -61,6 +61,13 @@ $dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO","
 } # fine if ($ins_costi_agg or $costo_letto_imposto != "NO")
 
 $app_eliminati_costi = array();
+$inserire = "";
+$mess_prenota = "";
+$lista_idprenota = "";
+$lista_idini = "";
+$lista_idfine = "";
+$mess_errore = "";
+$mess_regola1 = "";
 
 
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
@@ -72,32 +79,34 @@ $num_idinizioperiodo = numlin_query($idinizioperiodo);
 if ($num_idinizioperiodo == 0) $idinizioperiodo = 10000;
 else $idinizioperiodo = risul_query($idinizioperiodo,0,'idperiodi');
 $inizioperiodo[$n_t] = $idinizioperiodo;
-if (!$idinizioperiodo_tot or $idinizioperiodo < $idinizioperiodo_tot) $idinizioperiodo_tot = $idinizioperiodo;
+if (empty($idinizioperiodo_tot) or $idinizioperiodo < $idinizioperiodo_tot) $idinizioperiodo_tot = $idinizioperiodo;
 $idfineperiodo = esegui_query("select idperiodi from $tableperiodi where datafine = '".aggslashdb($fineperiodo[$n_t])."' ");
 $num_idfineperiodo = numlin_query($idfineperiodo);
 if ($num_idfineperiodo == 0) $idfineperiodo = -1;
 else $idfineperiodo = risul_query($idfineperiodo,0,'idperiodi');
 $fineperiodo[$n_t] = $idfineperiodo;
-if (!$idfineperiodo_tot or $idfineperiodo > $idfineperiodo_tot) $idfineperiodo_tot = $idfineperiodo;
+if (empty($idfineperiodo_tot) or $idfineperiodo > $idfineperiodo_tot) $idfineperiodo_tot = $idfineperiodo;
 
 $id_periodo_corrente = calcola_id_periodo_corrente($anno);
-if ($id_periodo_corrente > $idinizioperiodo and !$ins_passato) $data_sbagliata = "SI";
-if ($idfineperiodo < $idinizioperiodo or $data_sbagliata == "SI") {
+if ($id_periodo_corrente > $idinizioperiodo and !$ins_passato) $data_sbagliata = 1;
+else $data_sbagliata = 0;
+if ($idfineperiodo < $idinizioperiodo or $data_sbagliata) {
 $inserire = "NO";
 $mess_errore .= mex("Le date sono sbagliate","clienti.php");
 if ($num_tipologie > 1) $mess_errore .= " (".mex("tipologia","clienti.php")." $n_t)";
 $mess_errore .= ".<br>";
 } # fine if ($idfineperiodo < $idinizioperiodo or...
 
+$tariffa_sbagliata = "";
 if (substr($tipotariffa[$n_t],0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa[$n_t],7)) == "NO") $tariffa_sbagliata = "SI";
 else {
-$tar_sett_imp = $tariffe_sett_imp[$n_t];
+$tar_sett_imp = fixset($tariffe_sett_imp[$n_t]);
 for ($num1 = $inizioperiodo[$n_t] ; $num1 <= $fineperiodo[$n_t] ; $num1++) {
 $rigasettimana = esegui_query("select * from $tableperiodi where idperiodi = '$num1' ");
 $esistetariffa = risul_query($rigasettimana,0,$tipotariffa[$n_t]);
 $esistetariffap = risul_query($rigasettimana,0,$tipotariffa[$n_t]."p");
-if ((!strcmp($esistetariffa,"") or $esistetariffa < 0) and (!strcmp($esistetariffap,"") or $esistetariffap < 0) and !strcmp($tar_sett_imp[$num1],"")) $tariffa_sbagliata = "SI";
-if ($dati_tariffe[$tipotariffa[$n_t]]['chiusa'][$num1] and !strcmp($tar_sett_imp[$num1],"")) $tariffa_sbagliata = "SI";
+if ((!strcmp($esistetariffa,"") or $esistetariffa < 0) and (!strcmp($esistetariffap,"") or $esistetariffap < 0) and (!isset($tar_sett_imp[$num1]) or !strcmp($tar_sett_imp[$num1],""))) $tariffa_sbagliata = "SI";
+if (!empty($dati_tariffe[$tipotariffa[$n_t]]['chiusa'][$num1]) and (!isset($tar_sett_imp[$num1]) or !strcmp($tar_sett_imp[$num1],""))) $tariffa_sbagliata = "SI";
 } # fine for $num1
 } # fine else if (substr($tipotariffa[$n_t],0,7) != "tariffa" or...
 if ($tariffa_sbagliata == "SI") {
@@ -110,9 +119,9 @@ else {
 
 # se vi è una regola 2 per la tariffa
 unset($app_regola2_predef);
-if (!$lista_app[$n_t]) {
+if (empty($lista_app[$n_t])) {
 $lista_app[$n_t] = dati_regole2($dati_r2,$app_regola2_predef,$tipotariffa[$n_t],$idinizioperiodo,$idfineperiodo,$id_periodo_corrente,$tipo_periodi,$anno,$tableregole);
-} # fine if (!$lista_app[$n_t])
+} # fine if (empty($lista_app[$n_t]))
 
 $id_utente_ins = "";
 # se vi è una regola 3 per la tariffa
@@ -150,7 +159,7 @@ else $cognome = risul_query($cliente_esistente,0,"cognome");
 
 $app_richiesti_id[$n_t] = array();
 $assegnazioneapp[$n_t] = "v";
-if ($lista_app[$n_t]) {
+if (!empty($lista_app[$n_t])) {
 $assegnazioneapp[$n_t] = "c";
 $vett_app = explode(",",$lista_app[$n_t]);
 $num_app = count($vett_app);
@@ -166,12 +175,12 @@ if ($num_tipologie > 1) $mess_errore .= " (".mex("tipologia","clienti.php")." $n
 $mess_errore .= ".<br>";
 } # fine if (numlin_query($appartamento_esistente) != 1)
 } # fine for $num1
-} # fine if ($lista_app[$n_t])
+} # fine if (!empty($lista_app[$n_t]))
 
 # se il costo letto imposto ha appartamenti incompatibili
 if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] and strcmp($dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'],"")) {
 $app_incomp_costi[$n_t] = ",".$dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'].",";
-$lista_app_corr = $lista_app[$n_t];
+$lista_app_corr = fixset($lista_app[$n_t]);
 $lista_app[$n_t] = "";
 if (strcmp($lista_app_corr,"")) $lista_app_corr = ",$lista_app_corr,";
 for ($num1 = 0 ; $num1 < $numappartamenti ; $num1++) {
@@ -215,7 +224,7 @@ $posto_reg2_orig = 0;
 for ($num1 = 0 ; $num1 < $numappartamenti ; $num1++) {
 $idapp = risul_query($appartamenti,$num1,'idappartamenti');
 $maxoccupanti = risul_query($appartamenti,$num1,'maxoccupanti');
-if (!$app_richiesti_copia or $app_richiesti_copia[$idapp] == "SI") {
+if (!$app_richiesti_copia or (isset($app_richiesti_copia[$idapp]) and $app_richiesti_copia[$idapp] == "SI")) {
 if ($maxoccupanti and $maxoccupanti < $numpersone[$n_t]) {
 $app_richiesti_id[$n_t][$idapp] = "NO";
 } # fine if ($maxoccupanti and $maxoccupanti < $numpersone[$n_t])
@@ -223,7 +232,7 @@ else {
 $app_richiesti_id[$n_t][$idapp] = "SI";
 $posti++;
 } # fine else if ($maxoccupanti and $maxoccupanti < $numpersone[$n_t])
-} # fine if (!$app_richiesti_copia or $app_richiesti_copia[$idapp] == "SI")
+} # fine if (!$app_richiesti_copia or (isset($app_richiesti_copia[$idapp]) and...
 if ($app_regola2_predef) {
 if (str_replace(",$idapp,","",$app_regola2_predef) != $app_regola2_predef) {
 if (!$maxoccupanti or $maxoccupanti >= $numpersone[$n_t]) $posto_reg2_orig = 1;
@@ -238,7 +247,7 @@ $inserire = "NO";
 } # fine if ($posti == 0 or...
 } # fine if ($numpersone[$n_t])
 
-unset($lista_app_richiesti);
+$lista_app_richiesti = "";
 if (!$app_richiesti_id[$n_t]) $lista_app_richiesti = ",tutti,,";
 else foreach ($app_richiesti_id[$n_t] as $key => $val) if ($val == "SI") $lista_app_richiesti .= $key.",";
 $lista_app_richiesti = substr($lista_app_richiesti,0,-1);
@@ -268,6 +277,7 @@ else unset($id_prenota_imp);
 
 if ($inserire != "NO") {
 
+$condizioni_regole1_non_sel = "";
 $app_agenzia = esegui_query("select * from $tableregole where app_agenzia != ''$condizioni_regole1_non_sel");
 $num_app_agenzia = numlin_query($app_agenzia);
 
@@ -278,7 +288,7 @@ esegui_query("delete from $tableprenota where idclienti = '0' and datainseriment
 
 #Se ci sono regole per $app_agenzia inserisco false prenotazioni fisse in $app_prenota_id2
 if ($num_app_agenzia != 0) {
-unset($limiti_var);
+$limiti_var = array();
 unset($app_prenota_id);
 unset($app_orig_prenota_id);
 unset($inizio_prenota_id);
@@ -286,7 +296,7 @@ unset($fine_prenota_id);
 unset($app_assegnabili_id);
 unset($prenota_in_app_sett);
 unset($dati_app);
-unset($profondita);
+$profondita = array();
 $limiti_var['n_ini'] = $idinizioperiodo_tot;
 $limiti_var['n_fine'] = $idfineperiodo_tot;
 $limiti_var['lim_prenota_temp'] = $lim_prenota_temp;
@@ -332,7 +342,7 @@ if ($info_periodi_ag['numero']) inserisci_prenota_fittizie($info_periodi_ag,$pro
 $occupare_app_agenzia_sempre = "NO";
 for ($num1 = $idinizioperiodo_tot ; $num1 <= $idfineperiodo_tot ; $num1++) {
 $numprenotazioni = 0;
-for ($num2 = 0 ; $num2 < $dati_app['totapp'] ; $num2++) if ($prenota_in_app_sett2[$dati_app['posizione'][$num2]][$num1]) $numprenotazioni++;
+for ($num2 = 0 ; $num2 < $dati_app['totapp'] ; $num2++) if (!empty($prenota_in_app_sett2[$dati_app['posizione'][$num2]][$num1])) $numprenotazioni++;
 if ($numprenotazioni >= $numappartamenti) $occupare_app_agenzia_sempre = "SI";
 } # fine for $num1
 if ($occupare_app_agenzia_sempre != "SI") {
@@ -444,7 +454,7 @@ $mess_regola1 .= mex("La nuova prenotazione verrà inserita nell'appartamento",'
 else {
 # se non ci sono app_agenzia della regola di assegnazione 1
 unset($limiti_var);
-unset($profondita_);
+$profondita_ = "";
 unset($app_prenota_id_);
 unset($app_orig_prenota_id_);
 unset($inizio_prenota_id_);
@@ -493,7 +503,7 @@ $lunghezza_periodo = $fineperiodo[$n_t] - $inizioperiodo[$n_t] + 1;
 
 $max_idprenota = esegui_query("select numlimite from $tablecostiprenota where idcostiprenota = '1'");
 $max_idprenota = risul_query($max_idprenota,0,'numlimite');
-if ($id_prenota_imp[$n_t]) $idprenota = $id_prenota_imp[$n_t];
+if (!empty($id_prenota_imp[$n_t])) $idprenota = $id_prenota_imp[$n_t];
 else $idprenota = $max_idprenota;
 if ($idprenota >= $max_idprenota) esegui_query("update $tablecostiprenota set numlimite = '".($idprenota + 1)."' where idcostiprenota = '1'");
 
@@ -506,23 +516,23 @@ $mess_prenota .= mex("nell'appartamento",'unit.php')." <b>".$appartamento[$n_t].
 if ($assegnazioneapp[$n_t] == "k") $mess_prenota .= " (".mex("fisso","unit.php").")";
 else {
 $mess_prenota .= " (".mex("mobile","prenota.php");
-if ($lista_app[$n_t]) $mess_prenota .= " ".mex("in","prenota.php")." ".str_replace(",",", ",$lista_app[$n_t]);
+if (!empty($lista_app[$n_t])) $mess_prenota .= " ".mex("in","prenota.php")." ".str_replace(",",", ",$lista_app[$n_t]);
 $mess_prenota .= ")";
 } # fine else if ($assegnazioneapp[$n_t] == "k")
 $mess_prenota .= ":<br><br>";
 
 $costo_tariffa_tot = (double) 0;
-unset($lista_tariffe_sett);
-unset($lista_tariffep_sett);
-unset($lista_tariffepo_sett);
-$tar_sett_imp = $tariffe_sett_imp[$n_t];
+$lista_tariffe_sett = "";
+$lista_tariffep_sett = "";
+$lista_tariffepo_sett = "";
+$tar_sett_imp = fixset($tariffe_sett_imp[$n_t]);
 for ($num2 = $inizioperiodo[$n_t] ; $num2 <= $fineperiodo[$n_t] ; $num2++) {
 $riga_tariffa = esegui_query("select * from  $tableperiodi where idperiodi = $num2");
-if (strcmp($tar_sett_imp[$num2],"")) $costo_tariffa = $tar_sett_imp[$num2];
+if (isset($tar_sett_imp[$num2]) and strcmp($tar_sett_imp[$num2],"")) $costo_tariffa = $tar_sett_imp[$num2];
 else $costo_tariffa = risul_query($riga_tariffa,0,$tipotariffa[$n_t]);
 if ($dati_tariffe[$tipotariffa[$n_t]]['moltiplica'] == "p") {
 if (!strcmp($costo_tariffa,"")) $costo_tariffa = 0;
-if (strcmp($tar_sett_imp[$num2],"")) $costo_tariffap = 0;
+if (isset($tar_sett_imp[$num2]) and strcmp($tar_sett_imp[$num2],"")) $costo_tariffap = 0;
 else $costo_tariffap = risul_query($riga_tariffa,0,$tipotariffa[$n_t]."p");
 if (!strcmp($costo_tariffap,"")) $costo_tariffap = 0;
 $lista_tariffepo_sett .= ",".$costo_tariffap;
@@ -554,11 +564,11 @@ $mess_prenota .= "$costo_tariffa_tot_p $Euro &nbsp;&nbsp;&nbsp;&nbsp;&nbsp; ".me
 
 $valori = "abcdefghijkmnpqrstuvwxz";
 srand((double)microtime() * 1000000);
-unset($cod_prenota);
+$cod_prenota = "";
 for ($num2 = 0 ; $num2 < 4 ; $num2++) $cod_prenota .= substr($valori,rand(0,22),1);
 if ($conferma[$n_t] == "SI") $conf = "S";
 else $conf = "N";
-if ($pagato[$n_t] > 0) $conf = "S";
+if (isset($pagato[$n_t]) and $pagato[$n_t] > 0) $conf = "S";
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 
 esegui_query("insert into $tableprenota (idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,tariffa,tariffesettimanali,codice,conferma,datainserimento,hostinserimento,utente_inserimento) values ('$idprenota','".$idclienti[$n_t]."','".aggslashdb($appartamento[$n_t])."','".$inizioperiodo[$n_t]."','".$fineperiodo[$n_t]."','$tariffa','$lista_tariffe_sett','$cod_prenota','$conf','$datainserimento','$HOSTNAME','$id_utente_ins')");
@@ -571,24 +581,24 @@ if ($dati_tariffe[$tipotariffa[$n_t]]['tasse_percent']) {
 esegui_query("update $tableprenota set tasseperc = '".$dati_tariffe[$tipotariffa[$n_t]]['tasse_percent']."' where idprenota = '$idprenota' ");
 } # fine if ($dati_tariffe[$tipotariffa[$n_t]]['tasse_percent'])
 
-$caparra[$n_t] = formatta_soldi($caparra[$n_t]);
+$caparra[$n_t] = formatta_soldi(fixset($caparra[$n_t]));
 if (controlla_soldi($caparra[$n_t],"pos") == "NO") $caparra[$n_t] = "";
 if (!$caparra[$n_t]) $caparra[$n_t] = calcola_caparra($dati_tariffe,$tipotariffa[$n_t],$inizioperiodo[$n_t],$fineperiodo[$n_t],$costo_tariffa_tot,$lista_tariffe_sett);
 
 
 # calcolo costi nulli, non letto e senza inventario da associare alla tariffa, tutti come se fossero "se possibile". Oppure il costo imposto per letti aggiuntivi
 if ($ins_costi_agg or $costo_letto_imposto != "NO") {
-unset($num_letti_agg);
-unset($num_costi_presenti);
+$num_letti_agg = array('max' => 0);
+$num_costi_presenti = array();
 $oggi_costo = date("Ymd",(time() + (C_DIFF_ORE * 3600)));
 for ($num_costo = 0 ; $num_costo < $dati_ca['num'] ; $num_costo++) {
 $associa_costo = "NO";
 $nummoltiplica_ca = "";
 if ($ins_costi_agg == "costi_nulli") {
-if (!$dati_ca[$num_costo]['valore'] and !$dati_ca[$num_costo]['valore_perc'] and $dati_ca[$num_costo]['letto'] != "s" and !$dati_ca[$num_costo]['tipo_beniinv']) {
+if (!$dati_ca[$num_costo]['valore'] and empty($dati_ca[$num_costo]['valore_perc']) and $dati_ca[$num_costo]['letto'] != "s" and empty($dati_ca[$num_costo]['tipo_beniinv'])) {
 $associa_costo_tariffa = associa_costo_a_tariffa($dati_ca,$num_costo,$tipotariffa[$n_t],($fineperiodo[$n_t] - $inizioperiodo[$n_t] + 1));
 if ($associa_costo_tariffa == "SI") $associa_costo = "SI";
-if ($associa_costo_tariffa != "SI" and !$dati_ca[$num_costo]["incomp_".$tipotariffa[$n_t]]) {
+if ($associa_costo_tariffa != "SI" and empty($dati_ca[$num_costo]["incomp_".$tipotariffa[$n_t]])) {
 if ($dati_ca[$num_costo]['assegna_con_num_prenota'] and count($inizioperiodo) >= $dati_ca[$num_costo]['assegna_con_num_prenota']) $associa_costo = "SI";
 if ($dati_ca[$num_costo]['assegna_da_ini_prenota']) {
 $giorni_lim = substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],1);
@@ -597,7 +607,7 @@ if (substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],0,1) == ">" and $oggi_
 if (substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],0,1) == "<" and $oggi_costo > $limite) $associa_costo = "SI";
 } # fine if ($dati_ca[$num_costo][assegna_da_ini_prenota])
 } # fine if ($associa_costo_tariffa != "SI" and...
-} # fine if (!$dati_ca[$num_costo]['valore'] and !$dati_ca[$num_costo]['valore_perc'] and...
+} # fine if (!$dati_ca[$num_costo]['valore'] and empty($dati_ca[$num_costo]['valore_perc']) and...
 } # fine if ($ins_costi_agg == "costi_nulli")
 if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] == $dati_ca[$num_costo]['id'] and $dati_ca[$num_costo]['letto'] == "s") {
 $associa_costo = "SI";
@@ -619,7 +629,7 @@ $idcostiprenota = esegui_query("select max(idcostiprenota) from $tablecostipreno
 $idcostiprenota = risul_query($idcostiprenota,0,0) + 1;
 $tipo_ca = $dati_ca[$num_costo]['tipo'].$dati_ca[$num_costo]['tipo_val'];
 $valore_ca = $dati_ca[$num_costo]['valore'];
-$valore_perc_ca = $dati_ca[$num_costo]['valore_perc'];
+$valore_perc_ca = fixset($dati_ca[$num_costo]['valore_perc']);
 $prezzo_costo_tot = calcola_prezzo_totale_costo($dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,$moltiplica,$costo_tariffa,$lista_tariffe_sett,$costo_tariffa_tot,$caparra,$numpersone[$n_t],"","");
 $associasett_ca = $dati_ca[$num_costo]['associasett'];
 if ($dati_ca[$num_costo]['var_percentuale'] != "s" and $dati_ca[$num_costo]['tipo_val'] != "f") {
@@ -683,11 +693,11 @@ $costo_tariffa_tot = (double) $costo_tariffa_tot + (double) $prezzo_costo_tot;
 # assegnabili quando si modifica la prenotazione (se il costo mantiene gli appartamenti 
 # incompatibili con la modifica della prenotazione, allora questi appartamenti verranno tolti 
 # di nuovo dal costo quando si modifica la prenotazione, finchè il costo rimarrà associato)
-if ($app_eliminati_costi[$n_t]) {
+if (!empty($app_eliminati_costi[$n_t])) {
 esegui_query("update $tableprenota set incompatibilita = '".aggslashdb($app_eliminati_costi[$n_t])."' where idprenota = '$idprenota' ");
-} # fine if ($app_eliminati_costi[$n_t])
+} # fine if (!empty($app_eliminati_costi[$n_t]))
 
-$sconto[$n_t] = (double) formatta_soldi($sconto[$n_t]);
+$sconto[$n_t] = (double) formatta_soldi(fixset($sconto[$n_t]));
 if ($sconto[$n_t] and controlla_soldi($sconto[$n_t]) == "SI") {
 if ($sconto[$n_t] > $costo_tariffa_tot) $sconto[$n_t] = $costo_tariffa_tot;
 esegui_query("update $tableprenota set sconto = '".$sconto[$n_t]."' where idprenota = '$idprenota' ");
@@ -706,9 +716,9 @@ esegui_query("update $tableprenota set tariffa_tot = '$costo_tariffa_tot' where
 $costo_tariffa_tot_p = punti_in_num($costo_tariffa_tot,$stile_soldi);
 $mess_prenota .= "<b>$costo_tariffa_tot_p $Euro &nbsp;&nbsp;&nbsp;&nbsp;&nbsp; ".mex("TOTALE","prenota.php")."</b><br>";
 
-if ($lista_app[$n_t]) {
+if (!empty($lista_app[$n_t])) {
 esegui_query("update $tableprenota set app_assegnabili = '".$lista_app[$n_t]."' where idprenota = '$idprenota' ");
-} # fine if ($lista_app[$n_t])
+} # fine if (!empty($lista_app[$n_t]))
 
 if ($assegnazioneapp[$n_t]) {
 esegui_query("update $tableprenota set assegnazioneapp = '".$assegnazioneapp[$n_t]."' where idprenota = '$idprenota' ");
@@ -724,7 +734,7 @@ $mess_prenota .= "<br>".mex("Caparra","prenota.php").": <b>$caparra_p</b> $Euro
 } # fine if ($caparra[$n_t])
 
 $met_trovato = "NO";
-if ($met_paga_caparra[$n_t] and $metodi_pagamento) {
+if (!empty($met_paga_caparra[$n_t]) and $metodi_pagamento) {
 for ($num2 = 0 ; $num2 < count($metodi_pagamento) ; $num2++) {
 if ($met_paga_caparra[$n_t] == $metodi_pagamento[$num2]) $met_trovato = "SI";
 } # fine for $num2
@@ -733,7 +743,7 @@ esegui_query("update $tableprenota set metodo_pagamento = '".aggslashdb($met_pag
 if (!$caparra) $mess_prenota .= "<br>";
 $mess_prenota .= mex("Metodo pagamento caparra","prenota.php").": <b>".$met_paga_caparra[$n_t]."</b>.<br>";
 } # fine if ($met_trovato == "SI")
-} # fine if ($met_paga_caparra[$n_t] and $metodi_pagamento)
+} # fine if (!empty($met_paga_caparra[$n_t]) and $metodi_pagamento)
 
 if ($commissioni[$n_t]) {
 esegui_query("update $tableprenota set commissioni = '".$commissioni[$n_t]."' where idprenota = '$idprenota' ");
@@ -757,7 +767,7 @@ $mess_prenota .= mex("Origine","prenota.php").": <b>".stripslashes($origine_pren
 } # fine if ($orig_trovata == "SI")
 } # fine if ($origine_prenota[$n_t] and $origini_prenota)
 
-if ($giorno_stima_checkin[$n_t] and $ora_stima_checkin[$n_t] and $min_stima_checkin[$n_t]) {
+if (!empty($giorno_stima_checkin[$n_t]) and !empty($ora_stima_checkin[$n_t]) and !empty($min_stima_checkin[$n_t])) {
 if ($tipo_periodi == "g") $giorni_periodo = $lunghezza_periodo;
 else $giorni_periodo = ($lunghezza_periodo * 7);
 if (controlla_num_pos($giorno_stima_checkin[$n_t]) == "SI" and $giorno_stima_checkin[$n_t] >= 1 and $giorno_stima_checkin[$n_t] <= 7 and $giorno_stima_checkin[$n_t] <= ($giorni_periodo + 1)) {
@@ -774,12 +784,12 @@ esegui_query("update $tableprenota set checkout = '$stima_checkin' where idpreno
 $mess_prenota .= "<br>".mex("Orario stimato di entrata","prenota.php").": <b>".substr(str_replace($data_ini_prenota_f,"",formatta_data($stima_checkin,$stile_data)),0,-3)."</b>.<br>";
 } # fine if (preg_match("/[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:00/",$stima_checkin))
 } # fine if (controlla_num_pos($giorno_stima_checkin) == "SI" and...
-} # fine if ($giorno_stima_checkin[$n_t] and $ora_stima_checkin[$n_t] and $min_stima_checkin[$n_t])
+} # fine if (!empty($giorno_stima_checkin[$n_t]) and !empty($ora_stima_checkin[$n_t]) and...
 
 if (strcmp($commento[$n_t],"") or $commento['pers'][$n_t]) {
 $commento[$n_t] = htmlspecialchars($commento[$n_t]);
 if (strcmp($commento[$n_t],"")) $mess_prenota .= "<br>".mex("Commento","prenota.php").": ".$commento[$n_t]."<br>";
-if ($commento['pers'][$n_t]) $commento[$n_t] .= $commento['pers'][$n_t];
+if (!empty($commento['pers'][$n_t])) $commento[$n_t] .= $commento['pers'][$n_t];
 $commento[$n_t] = aggslashdb($commento[$n_t]);
 esegui_query("update $tableprenota set commento = '".$commento[$n_t]."' where idprenota = '$idprenota' ");
 } # fine if (strcmp($commento[$n_t],"") or $commento['pers'][$n_t])
