@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -39,7 +39,7 @@ function connetti_db ($database,$host,$port,$user,$password,$estensione) {
 global $link_mysqli;
 if ($estensione == "SI") dl("mysqli.so");
 $link_mysqli = mysqli_connect($host,$user,$password,$database,$port);
-@mysqli_query($link_mysqli,"SET NAMES 'utf8'");
+@mysqli_query($link_mysqli,"SET NAMES 'utf8mb4'");
 
 return $link_mysqli;
 
@@ -66,10 +66,10 @@ $risul[-2] = -1;
 
 if (!$risul[-1]) {
 # bug mariadb: temporary table already existing when adding a column
-if (strtolower(substr($query,0,12)) == "alter table ") {
+if (strtolower(substr($query,0,12)) == "alter table " or strtolower(substr($query,0,15)) == "alter database ") {
 sleep(1);
 $risul[-1] = mysqli_query($link_mysqli,$query);
-} # fine if (strtolower(substr($query,0,12)) == "alter table ")
+} # fine if (strtolower(substr($query,0,12)) == "alter table " or strtolower(substr($query,0,15)) == "alter database ")
 if (!$risul[-1]) {
 $risul = $risul[-1];
 if ($silenzio != "totale") {
@@ -224,6 +224,7 @@ $query = array();
 
 function lock_tabelle ($tabelle,$altre_tab_usate = "") {
 
+$lista_tabelle = "";
 if (@is_array($tabelle)) {
 for ($num1 = 0 ; $num1 < count($tabelle); $num1++) {
 $lista_tabelle .= $tabelle[$num1]." write,";
