@@ -28,7 +28,7 @@ if ($tipo_periodi == "s") $colspan = 14;
 else $colspan = 2;
 $num_raggr = 0;
 unset($nome_raggr);
-unset($app_ric_raggr);
+$app_ric_raggr = array();
 unset($tipotariffa);
 $napp_ric_raggr = array();
 
@@ -47,17 +47,18 @@ $num_raggr++;
 
 if ($mostra_quadro_disp == "reg2") {
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
-if ($app_regola2_orig[$numtariffa]) {
+if (!empty($app_regola2_orig[$numtariffa])) {
 $app_regola2 = explode(",",$app_regola2_orig[$numtariffa]);
-for ($num1 = 0 ; $num1 < count($app_regola2) ; $num1++) if ($app_consentito[$app_regola2[$num1]] == "SI") $app_ric_raggr[$num_raggr] .= "$app_regola2[$num1],";
+$app_ric_raggr[$num_raggr] = "";
+for ($num1 = 0 ; $num1 < count($app_regola2) ; $num1++) if (isset($app_consentito[$app_regola2[$num1]]) and $app_consentito[$app_regola2[$num1]] == "SI") $app_ric_raggr[$num_raggr] .= "$app_regola2[$num1],";
 if ($app_ric_raggr[$num_raggr]) {
 $app_ric_raggr[$num_raggr] = substr($app_ric_raggr[$num_raggr],0,-1);
 $nome_raggr[$num_raggr] = str_replace(" ","&nbsp;",$nome_tariffa[$numtariffa]);
 $tipotariffa[$num_raggr] = "tariffa$numtariffa";
-$napp_ric_raggr[$num_raggr] = $app_regola2_orig['napp'][$numtariffa];
+$napp_ric_raggr[$num_raggr] = fixset($app_regola2_orig['napp'][$numtariffa]);
 $num_raggr++;
 } # fine if ($app_ric_raggr[$num_raggr])
-} # fine if ($app_regola2_orig[$numtariffa])
+} # fine if (!empty($app_regola2_orig[$numtariffa]))
 } # fine for $numtariffa
 } # fine if ($mostra_quadro_disp == "reg2")
 
@@ -102,7 +103,7 @@ $app_ric_colonna = ",".$app_ric_raggr[$num1].",";
 for ($num2 = 0 ; $num2 < $num_colonne_tab_disp ; $num2++) {
 $id_periodo = $id_data_inizio_tab_disp + $num2;
 $num_app_liberi = $max_app_liberi;
-if ($app_consentito_sett[',attivo,'] == "SI") {
+if (isset($app_consentito_sett[',attivo,']) and $app_consentito_sett[',attivo,'] == "SI") {
 if ($num2 == 0) {
 $app_ric_col_vett = explode(",",$app_ric_raggr[$num1]);
 $num_app_ric_col = count($app_ric_col_vett);
@@ -114,7 +115,7 @@ $app_ric_colonna = str_replace(",".$app_ric_col_vett[$num3].",",",",$app_ric_col
 $num_app_liberi--;
 } # fine if ($app_consentito_sett[$app_ric_col_vett[$num3]][$id_periodo] != "SI")
 } # fine for $num3
-} # fine if ($app_consentito_sett[',attivo,'] == "SI")
+} # fine if (isset($app_consentito_sett[',attivo,']) and $app_consentito_sett[',attivo,'] == "SI")
 $pren_pres_in_lista = array();
 $lista_prenota_periodo = array();
 $num_lista_pren_per = 0;
@@ -123,7 +124,7 @@ for ($num3 = 0 ; $num3 < $num_lista_pren_per ; $num3++) {
 if (str_replace(",".$app_orig_prenota_id[$lista_prenota_periodo[$num3]].",","",$app_ric_colonna) != $app_ric_colonna) $num_app_liberi--;
 } # fine for $num3
 if ($napp_ric_raggr[$num1]) $num_app_liberi = floor($num_app_liberi / $napp_ric_raggr[$num1]);
-if ($mostra_quadro_disp == "reg2" and $dati_tariffe and $dati_tariffe[$tipotariffa[$num1]]['chiusa'][$id_periodo]) $num_app_liberi = 0;
+if ($mostra_quadro_disp == "reg2" and $dati_tariffe and !empty($dati_tariffe[$tipotariffa[$num1]]['chiusa'][$id_periodo])) $num_app_liberi = 0;
 if ($num_app_liberi > 0) $color = $c_libero_tab_disp;
 else $color = $c_occupato_tab_disp;
 if ($num_app_liberi > 0 and $mostra_num_liberi == "SI") $val_liberi = $num_app_liberi;
