@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2015 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -37,13 +37,13 @@ if (!$num_relutente_usata) esegui_query("delete from $tablerel where id$rel_plur
 function aggiorna_relutenti ($aggiungi_rel,$rel_predefinite,$elimina_tutte_rel,$importa_rel,$id_utente,$id_utente_mod,$nuova_rel,$sup_n_rel,$cod_n_rel,$cod2_n_rel,$cod3_n_rel,$utente_importa_rel,$pag,$rel_sing,$rel_plur,$tablerel,$tablerelutenti,$rel_sup_sing="",$rel_sup_plur="",$tablerel_sup="",$rel_inf_sing="",$rel_inf_plur="",$tablerel_inf="") {
 if ($id_utente != 1 or $id_utente_mod == $utente_importa_rel) $importa_rel = "";
 if ($aggiungi_rel or $rel_predefinite or $elimina_tutte_rel or $importa_rel) {
-if (get_magic_quotes_gpc()) {
+if (@get_magic_quotes_gpc()) {
 $nuova_rel = stripslashes($nuova_rel);
 $cod_n_rel = stripslashes($cod_n_rel);
 $cod2_n_rel = stripslashes($cod2_n_rel);
 $cod3_n_rel = stripslashes($cod3_n_rel);
 $sup_n_rel = stripslashes($sup_n_rel);
-} # fine if (get_magic_quotes_gpc())
+} # fine if (@get_magic_quotes_gpc())
 $nuova_rel = htmlspecialchars($nuova_rel);
 $cod_n_rel = htmlspecialchars($cod_n_rel);
 $cod2_n_rel = htmlspecialchars($cod2_n_rel);
@@ -187,6 +187,20 @@ $cod_esistente[$nome_rel] = risul_query($rel_esistenti,0,"codice_$rel_sing");
 } # fine if ($num_rel_agg <= $num_passa_a_var)
 
 if (!$rel_esistente[$lista_rel[$num1]]) {
+if ($cod_rel[$num1] and $id_utente_mod != 1 and (!$cod2_rel[$num1] or !$cod3_rel[$num1])) {
+$cod_esistenti = esegui_query("select id$rel_plur,codice2_$rel_sing,codice3_$rel_sing from $tablerel where codice_$rel_sing = '".aggslashdb($cod_rel[$num1])."' and (codice2_$rel_sing is not NULL or codice3_$rel_sing is not NULL) ");
+# Query con inner join è molto più lenta con molte città
+#$cod_admin = esegui_query("select distinct $tablerel.codice2_$rel_sing,codice3_$rel_sing from $tablerel inner join $tablerelutenti on $tablerel.id$rel_plur = $tablerelutenti.id$rel_sing where $tablerelutenti.idutente = '1' and $tablerel.codice_$rel_sing = '".aggslashdb($cod_rel[$num1])."' ");
+for ($num2 = 0 ; $num2 < numlin_query($cod_esistenti) ; $num2++) {
+$id_rel_cod = risul_query($cod_esistenti,$num2,"id$rel_plur");
+$utente_cod = esegui_query("select id$rel_sing from $tablerelutenti where id$rel_sing = '$id_rel_cod' and idutente = '1' ");
+if (numlin_query($utente_cod)) {
+if (!$cod2_rel[$num1]) $cod2_rel[$num1] = risul_query($cod_esistenti,$num2,"codice2_$rel_sing");
+if (!$cod3_rel[$num1]) $cod3_rel[$num1] = risul_query($cod_esistenti,$num2,"codice3_$rel_sing");
+break;
+} # fine if (numlin_query($utente_cod))
+} # fine for $num2
+} # fine if ($cod_rel[$num1] and $id_utente_mod != 1 and (!$cod2_rel[$num1] or !$cod3_rel[$num1]))
 if (!$num_max) {
 $num_max = esegui_query("select max(id$rel_plur) from $tablerel ");
 $num_max = risul_query($num_max,0,0) + 1;
@@ -201,9 +215,9 @@ $cod_esistente[$lista_rel[$num1]] = $cod_rel[$num1];
 else {
 $num_n_rel = $id_esistente[$lista_rel[$num1]];
 $r_cod = $cod_esistente[$lista_rel[$num1]];
-if (!$r_cod and $cod_rel[$num1]) esegui_query("update $tablerel set codice_$rel_sing = '".aggslashdb($cod_rel[$num1])."' where id$rel_plur = '$num_n_rel' ");
-if ($cod2_rel[$num1]) esegui_query("update $tablerel set codice2_$rel_sing = '".aggslashdb($cod2_rel[$num1])."' where id$rel_plur = '$num_n_rel' ");
-if ($cod3_rel[$num1]) esegui_query("update $tablerel set codice3_$rel_sing = '".aggslashdb($cod3_rel[$num1])."' where id$rel_plur = '$num_n_rel' ");
+if ((!$r_cod or $rel_predefinite) and $cod_rel[$num1]) esegui_query("update $tablerel set codice_$rel_sing = '".aggslashdb($cod_rel[$num1])."' where id$rel_plur = '$num_n_rel' ","",$nolog);
+if ($cod2_rel[$num1]) esegui_query("update $tablerel set codice2_$rel_sing = '".aggslashdb($cod2_rel[$num1])."' where id$rel_plur = '$num_n_rel' ","",$nolog);
+if ($cod3_rel[$num1]) esegui_query("update $tablerel set codice3_$rel_sing = '".aggslashdb($cod3_rel[$num1])."' where id$rel_plur = '$num_n_rel' ","",$nolog);
 if ($num_rel_agg < $num_passa_a_var) {
 $rel_esistenti2 = esegui_query("select idsup from $tablerelutenti where idutente = '$id_utente_mod' and id$rel_sing = '$num_n_rel' ");
 if (numlin_query($rel_esistenti2)) {
@@ -221,7 +235,7 @@ $idsup_esistente2[$num_n_rel] = $id_rel_sup;
 } # fine (!$rel_esistente2[$num_n_rel])
 elseif ($id_rel_sup) {
 $idsup = $idsup_esistente2[$num_n_rel];
-if (!$idsup) esegui_query("update $tablerelutenti set idsup = '$id_rel_sup' where idutente = '$id_utente_mod' and id$rel_sing = '$num_n_rel' ");
+if (!$idsup) esegui_query("update $tablerelutenti set idsup = '$id_rel_sup' where idutente = '$id_utente_mod' and id$rel_sing = '$num_n_rel' ","",$nolog);
 } # fine elseif ($id_rel_sup)
 } # fine for $num1
 
