@@ -320,9 +320,9 @@ if ($num_ord > 0 or "tariffa".$dati_tariffe[$tariffa]['importa_prezzi'][0] == $t
 
 if ($num_ord != $num_ord_prec) {
 $importa_percent = (double) $dati_tariffe[$tariffa]['val_importa'][$num_ord];
-$importa_arrotond = (double) $dati_tariffe[$tariffa]['arrotond_importa'][$num_ord];
+$importa_arrotond = (double) fixset($dati_tariffe[$tariffa]['arrotond_importa'][$num_ord]);
 $tipo_percent = $dati_tariffe[$tariffa]['tipo_importa'][$num_ord];
-if ($tipo_percent == "s" and !$agg_vett[$tariffa][$num_ord]) {
+if ($tipo_percent == "s" and empty($agg_vett[$tariffa][$num_ord])) {
 $agg_int = floor($importa_percent);
 $resto_int = $importa_percent - (double) $agg_int;
 $agg_gio = floor($agg_int / 7);
@@ -336,7 +336,7 @@ for ($num2 = 7 ; $num2 > (7 - $resto) ; $num2--) $agg_vett[$tariffa][$num_ord][$
 $agg_vett[$tariffa][$num_ord][1] += $resto_int;
 $num_agg[$tariffa][$num_ord]['s'] = 0;
 $num_agg[$tariffa][$num_ord]['p'] = 0;
-} # fine if ($tipo_percent == "s" and !$agg_vett[$tariffa][$num_ord])
+} # fine if ($tipo_percent == "s" and empty($agg_vett[$tariffa][$num_ord]))
 if ($tipo_percent == "g") $perc = $importa_percent;
 } # fine if ($num_ord != $num_ord_prec)
 
