@@ -59,7 +59,7 @@ if ($lunghezza < 0) {
 $lunghezza = $num_caratteri + $lunghezza - $inizio;
 if ($lunghezza < 0) $lunghezza = 0;
 } # fine if ($lunghezza < 0)
-for ($num1 = ($inizio + 1) ; $num1 <= ($inizio + $lunghezza) ; $num1++) $n_lun = $n_lun + $num_byte_car[$num1];
+for ($num1 = ($inizio + 1) ; $num1 <= ($inizio + $lunghezza) ; $num1++) $n_lun = $n_lun + fixset($num_byte_car[$num1]);
 $testo = substr($testo,$n_ini,$n_lun);
 } # fine else if ($lunghezza == "NO")
 
