@@ -267,6 +267,7 @@ case "Pagine importate":  			$messaggio = "Pages imported"; break;
 case "con i servizi opzionali selezionati":  	$messaggio = "with selected optional services"; break;
 case "Utilizzare le personalizzazioni (tipi di persone, liste di nazioni, regioni, ecc.) dell'utente":	$messaggio = "Use customizations (people types, lists of nations, regions, etc.) from user"; break;
 case "Url del file css per la modalità frame":	$messaggio = "Url of css file for framed mode"; break;
+case "Url del file javascript per la modalità frame":	$messaggio = "Url of javascript file for framed mode"; break;
 case "Utilizza per l'aspetto della pagina":  	$messaggio = "Use for page appearance"; break;
 case "html personalizzato":  			$messaggio = "custom html"; break;
 case "il tema chiamato":  			$messaggio = "the theme called"; break;
@@ -298,6 +299,7 @@ case "aggiunto al commento":  			$messaggio = "added to comment"; break;
 case "aggiunto al campo":  			$messaggio = "added to field"; break;
 case "del cliente":  				$messaggio = "in client data"; break;
 case "URL file css":  				$messaggio = "URL of css file"; break;
+case "URL file javascript":  			$messaggio = "URL of javascript file"; break;
 case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "there are rates without assignment rule n. 2"; break;
 case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
 case "Partita iva":  				$messaggio = "VAT number"; break;
@@ -330,6 +332,7 @@ case "Raggruppamento":  			$messaggio = "Grouping"; break;
 case "Valuta della caparra":  			$messaggio = "Deposit currency"; break;
 case "Seconda email":  				$messaggio = "Second email"; break;
 case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
+case "non deve contenere \"php\" e deve terminare con \".js\"":	$messaggio = "must not contain \"php\" and must end with \".js\""; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -399,6 +402,7 @@ case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_active_calen
 case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_selected_calendar_date"; break;
 case "var_stile_tabella_prenotazione":  	$messaggio = "var_reservation_table_style"; break;
 case "var_file_css_frame":  			$messaggio = "var_framed_css_file"; break;
+case "var_file_js_frame":  			$messaggio = "var_framed_js_file"; break;
 case "var_apri_nuova_finestra_da_frame":  	$messaggio = "var_open_new_window_from_frame"; break;
 case "var_larghezza_finestra_da_frame":  	$messaggio = "var_window_from_frame_width"; break;
 case "var_altezza_finestra_da_frame":  		$messaggio = "var_window_from_frame_height"; break;
