@@ -20,6 +20,10 @@ case "tentativi prima del blocco dei login": 	$messaggio = "attempts remaining b
 case "Manca solo":  				$messaggio = "Only"; break;
 case "tentativo prima del blocco dei login":	$messaggio = "attempt remaining before locking the login"; break;
 case "È possibile reimpostare la password dal proprio account di hosting":	$messaggio = "You can reset the password from your hosting account"; break;
+case "orario del server":  			$messaggio = "server time"; break;
+case "Avviso":  				$messaggio = "Warning"; break;
+case "Mancano meno di":  			$messaggio = "Less than"; break;
+case "giorni alla scadenza dell'account":  	$messaggio = "days left until the account expires"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
