@@ -47,6 +47,8 @@ $trad_var['data_inizio'] = 'starting_date';
 $trad_var['data_fine'] = 'ending_date';
 $trad_var['num_periodi'] = 'periods_num';
 $trad_var['orario_entrata_stimato'] = 'estimated_checkin_time';
+$trad_var['orario_registrazione_entrata'] = 'checkin_time';
+$trad_var['orario_registrazione_uscita'] = 'checkout_time';
 $trad_var['nome_tariffa'] = 'rate_name';
 $trad_var['costo_tariffa'] = 'rate_price';
 $trad_var['costo_tariffa_p'] = 'rate_price_p';
