@@ -113,9 +113,9 @@ case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 4 for"; break;
 case "La regola di assegnazione è stata cancellata":	$messaggio = "The assignment rule has been deleted"; break;
 case "La regola di assegnazione è già stata cancellata":	$messaggio = "The assignment rule has already been deleted"; break;
-case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Table with the assignment rules 1 of"; break;
+case "Tabella con le regole di assegnazione":	$messaggio = "Table with the assignment rules"; break;
+case "del":	 				$messaggio = "of"; break;
 case "Motivazione":  				$messaggio = "Motivation"; break;
-case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Table with the assignment rules 2 of"; break;
 case "Tariffa":  				$messaggio = "Rate"; break;
 case "Inserisci nuove regole":  		$messaggio = "Insert new rules"; break;
 case "Il numero inserito esiste già":  		$messaggio = "The inserted number already exists"; break;
@@ -168,7 +168,6 @@ case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "f
 case "Profilo":  				$messaggio = "Profile"; break;
 case "Cliente":  				$messaggio = "Client"; break;
 case "cliente":  				$messaggio = "client"; break;
-case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Table with the assignment rules 3 of"; break;
 case "Utente":  				$messaggio = "User"; break;
 case "Periodi_permessi":  			$messaggio = "Permitted_periods"; break;
 case "unico":  					$messaggio = "single"; break;
@@ -221,7 +220,6 @@ case "Applica i cambiamenti":  			$messaggio = "Apply changes"; break;
 case "documento di tipo":  			$messaggio = "document type"; break;
 case "visualizza":  				$messaggio = "view"; break;
 case "Vedi tutte le prenotazioni":  		$messaggio = "View all reservations"; break;
-case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Table with the assignment rules 4 of"; break;
 case "Numero di persone":  			$messaggio = "Number of people"; break;
 case "assegna_se_":  				$messaggio = "assign_if_"; break;
 case "più_di_":  				$messaggio = "less_than_"; break;
