@@ -267,6 +267,7 @@ case "Pagine importate":  			$messaggio = "Páginas importadas"; break;
 case "con i servizi opzionali selezionati":  	$messaggio = "con los servicios opcionales seleccionados"; break;
 case "Utilizzare le personalizzazioni (tipi di persone, liste di nazioni, regioni, ecc.) dell'utente":	$messaggio = "Utilizar las personalizaciones (tipos de personas, listas de naciones, regiones, etc.) del usuario"; break;
 case "Url del file css per la modalità frame":	$messaggio = "Url del archivo css para la modalidad frame"; break;
+case "Url del file javascript per la modalità frame":	$messaggio = "Url del archivo javascript para la modalidad frame"; break;
 case "Utilizza per l'aspetto della pagina":  	$messaggio = "Utilizar para el aspecto de la página"; break;
 case "html personalizzato":  			$messaggio = "html personalizado"; break;
 case "il tema chiamato":  			$messaggio = "el tema llamado"; break;
@@ -298,6 +299,7 @@ case "aggiunto al commento":  			$messaggio = "añadido al comentario"; break;
 case "aggiunto al campo":  			$messaggio = "añadido al campo"; break;
 case "del cliente":  				$messaggio = "del cliente"; break;
 case "URL file css":  				$messaggio = "URL del archivo css"; break;
+case "URL file javascript":  			$messaggio = "URL del archivo javascript"; break;
 case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "hay tarifas sin regla de asignación n. 2"; break;
 case "Codice fiscale":  			$messaggio = "N. Identificación Fiscal"; break;
 case "Partita iva":  				$messaggio = "Cert. Identificación Fiscal"; break;
@@ -330,6 +332,7 @@ case "Raggruppamento":  			$messaggio = "Agrupación"; break;
 case "Valuta della caparra":  			$messaggio = "Divisa de la fianza"; break;
 case "Seconda email":  				$messaggio = "Segunda email"; break;
 case "PEC o codice destinatario":  		$messaggio = "Email certificada"; break;
+case "non deve contenere \"php\" e deve terminare con \".js\"":	$messaggio = "no debe contener \"php\" y debe terminar con \".js\""; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -399,6 +402,7 @@ case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_fecha_activa
 case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_fecha_seleccionada_calendario"; break;
 case "var_stile_tabella_prenotazione":  	$messaggio = "var_estilo_tabla_reserva"; break;
 case "var_file_css_frame":  			$messaggio = "var_archivo_css_frame"; break;
+case "var_file_js_frame":  			$messaggio = "var_archivo_js_frame"; break;
 case "var_apri_nuova_finestra_da_frame":  	$messaggio = "var_abrir_nueva_ventana_desde_frame"; break;
 case "var_larghezza_finestra_da_frame":  	$messaggio = "var_anchura_ventana_desde_frame"; break;
 case "var_altezza_finestra_da_frame":  		$messaggio = "var_altura_ventana_desde_frame"; break;
