@@ -67,6 +67,9 @@ case "Cancella o ridimensiona queste regole":  	$messaggio = "Borrar o reducir e
 case "Cancella":  				$messaggio = "Borrar"; break;
 case "Ridimensiona":  				$messaggio = "Reducir"; break;
 case "Modifica la regola":  			$messaggio = "Modificar la regla"; break;
+case "chiusure":  				$messaggio = "cierres"; break;
+case "numero di persone":  			$messaggio = "número de personas"; break;
+case "utente inserimento":  			$messaggio = "usuario que inserta"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
