@@ -14,7 +14,7 @@ case "minuti":  				$messaggio = "minutos"; break;
 case "Dopo un login <div style=\"display: inline; color: red;\">errato</div> si devono attendere":	$messaggio = "Despues de un login <div style=\"display: inline; color: red;\">equivocado</div> hay que esperar"; break;
 case "secondi":  				$messaggio = "segundos"; break;
 case "Il database deve essere aggiornato":  	$messaggio = "Hay que actualizar la base de datos"; break;
-case "Aggiorna":  				$messaggio = "Actualiza"; break;
+case "Aggiorna":  				$messaggio = "Actualizar"; break;
 case "Mancano solo":  				$messaggio = "Faltan solo"; break;
 case "tentativi prima del blocco dei login": 	$messaggio = "intentos antes del bloqueo del login"; break;
 case "Manca solo":  				$messaggio = "Falta solo"; break;
