@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Modifica Documento":  			$messaggio = "Modificar Documento"; break;
 case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "documento":  				$messaggio = "documento"; break;
 case "Modifica il documento":  			$messaggio = "Modificar el documento"; break;
@@ -111,6 +112,14 @@ case "Tutti le partenze del":  			$messaggio = "Todas las salidas del"; break;
 case "Tutti i clienti":  			$messaggio = "Todos los clientes"; break;
 case "escludendo gli ospiti":  			$messaggio = "excluyendo a los huéspdes"; break;
 case "inclusi gli ospiti":  			$messaggio = "incluidos los huéspdes"; break;
+case "ripetizione documenti salvati":  		$messaggio = "repetición documentos salvados"; break;
+case "formato dell'utente":  			$messaggio = "formato del usuario"; break;
+case "Formato dei soldi":  			$messaggio = "Formato de las monedas"; break;
+case "Formato delle date":  			$messaggio = "Formato de las fechas"; break;
+case "Formati predefiniti del documento cambiati":	$messaggio = "Formatos predefinidos del documento cambiados"; break;
+case "i documenti esistenti non verranno mai sovrascritti, ogni volta che si chiama la API verrà salvato un nuovo documento":	$messaggio = "los documentos existentes nunca serán sobrescritos, cada vez que se llama la API se guardará un nuevo documento"; break;
+case "Tutti i pagamenti nella cassa":  		$messaggio = "Todos los pagos en la caja"; break;
+case "nome_cassa":  				$messaggio = "nombre_caja"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
