@@ -122,6 +122,9 @@ case "in ASCII esteso":  			$messaggio = "en ASCII extendido"; break;
 case "codificato con MD5":  			$messaggio = "codificado con MD5"; break;
 case "solo nelle ripetizioni dei documenti salvati":	$messaggio = "solo en las repeticiones de los documentos salvados"; break;
 case "Condizioni eliminate":  			$messaggio = "Condiciones eliminadas"; break;
+case "tutti i documenti":  			$messaggio = "todos los documentos"; break;
+case "documento":  				$messaggio = "documento"; break;
+case "anche condizioni":  			$messaggio = "también condiciones"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
