@@ -10,7 +10,7 @@ case "Modifica delle proprie personalizzazioni":	$messaggio = "Modificación de
 case "Si":  					$messaggio = "Si"; break;
 case "No":  					$messaggio = "No"; break;
 case "Inserimento di nuovi clienti":  		$messaggio = "Inserción de nuevos clientes"; break;
-case "Possibilità di vedere ed utilizzare nelle prenotazioni i clienti già inseriti":	$messaggio = "Posibilidad ded ver y utilizar en las reservas los clientes ya insertados"; break;
+case "Possibilità di vedere ed utilizzare nelle prenotazioni i clienti già inseriti":	$messaggio = "Posibilidad de ver y utilizar en las reservas los clientes ya insertados"; break;
 case "Solo":  					$messaggio = "Solo"; break;
 case "i propri":  				$messaggio = "los proprios"; break;
 case "Modifica e cancellazione dei clienti già inseriti":  	$messaggio = "Modificación y cancelación de los clientes ya insertados"; break;
