@@ -33,7 +33,7 @@ $trad_var['telefono3'] = 'telefono3';
 $trad_var['fax'] = 'fax';
 $trad_var['email'] = 'email';
 $trad_var['email2'] = 'email2';
-$trad_var['email_certificata'] = 'email_certificada';
+$trad_var['email_certificata'] = 'email_certificado';
 $trad_var['codice_fiscale'] = 'num_identificacion_fiscal';
 $trad_var['partita_iva'] = 'certificado_identificacion_fiscal';
 $trad_var['num_persone'] = 'num_personas';
@@ -208,7 +208,7 @@ $trad_var['telefono3_ospite'] = 'telefono3_huesped';
 $trad_var['fax_ospite'] = 'fax_huesped';
 $trad_var['email_ospite'] = 'email_huesped';
 $trad_var['email2_ospite'] = 'email2_huesped';
-$trad_var['email_certificata_ospite'] = 'email_certificada_huesped';
+$trad_var['email_certificata_ospite'] = 'email_certificado_huesped';
 $trad_var['codice_fiscale_ospite'] = 'codigo_fiscal_huesped';
 $trad_var['partita_iva_ospite'] = 'num_identificacion_fiscal_huesped';
 $trad_var['codice_cittadinanza_ospite'] = 'codigo_nacionalidad_huesped';
