@@ -113,9 +113,9 @@ case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 4 para la"; break;
 case "La regola di assegnazione è stata cancellata":	$messaggio = "La regla de asignación ha sido borrada"; break;
 case "La regola di assegnazione è già stata cancellata":	$messaggio = "La regla de asignación había sido ya borrada"; break;
-case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Tabla con las reglas de asignación 1 del"; break;
+case "Tabella con le regole di assegnazione":	$messaggio = "Tabla con las reglas de asignación"; break;
+case "del":					$messaggio = "del"; break;
 case "Motivazione":  				$messaggio = "Motivación"; break;
-case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Tabla con las reglas de asignación 2 del"; break;
 case "Tariffa":  				$messaggio = "Tarifa"; break;
 case "Inserisci nuove regole":  		$messaggio = "Insertar nuevas reglas"; break;
 case "Il numero inserito esiste già":  		$messaggio = "El número insertado ya existe"; break;
@@ -169,7 +169,6 @@ case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "d
 case "Profilo":  				$messaggio = "Perfil"; break;
 case "Cliente":  				$messaggio = "Cliente"; break;
 case "cliente":  				$messaggio = "cliente"; break;
-case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Tabla con las reglas de asignación 3 del"; break;
 case "Utente":  				$messaggio = "Usuario"; break;
 case "Periodi_permessi":  			$messaggio = "Periodos_permitidos"; break;
 case "unico":  					$messaggio = "único"; break;
@@ -222,7 +221,6 @@ case "Applica i cambiamenti":  			$messaggio = "Aplicar los cambios"; break;
 case "documento di tipo":  			$messaggio = "documento tipo"; break;
 case "visualizza":  				$messaggio = "Ver"; break;
 case "Vedi tutte le prenotazioni":  		$messaggio = "Mirar todas las reservas"; break;
-case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Tabla con las reglas de asignación 4 del"; break;
 case "Numero di persone":  			$messaggio = "Número de personas"; break;
 case "assegna_se_":  				$messaggio = "asignar_con_"; break;
 case "più_di_":  				$messaggio = "más_de_"; break;
