@@ -27,7 +27,7 @@ global $debug;
 $limiti_var['n_ini'] = $idinizio;
 $limiti_var['n_fine'] = $idfine;
 if (!is_array($profondita)) {
-$primo_ciclo = "SI";
+$primo_ciclo = 1;
 $prof_copia = $profondita;
 $profondita = "";
 $profondita['iniziale'] = $prof_copia;
@@ -54,7 +54,7 @@ if ($dati_app['maxocc'][$numapp] >= $num_persone) {
 $prima_prenota = prenota_in_app_e_periodo($numapp,$idinizio,$idinizio,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
 if ($num_pp != 0) $idprima_prenota = $prima_prenota[1];
 else $idprima_prenota = "";
-if (!$idprima_prenota or $app_assegnabili_id[$idprima_prenota]) {
+if (!$idprima_prenota or !empty($app_assegnabili_id[$idprima_prenota])) {
 $limiti_var_orig = $limiti_var;
 $nuova_profondita = $profondita;
 $nuova_profondita['attuale'] = $profondita['attuale'] + 1;
@@ -135,7 +135,7 @@ $fine_prenota_id[$num2] = "";
 } # fine for $num2
 aggiorna_app_aggiunti($limiti_var,$limiti_var_orig,$app_orig_prenota_id,$app_prenota_id,$inizio_prenota_id,$fine_prenota_id,$prenota_in_app_sett);
 
-} # fine if (!$idprima_prenota or $app_assegnabili_id[$idprima_prenota])
+} # fine if (!$idprima_prenota or !empty($app_assegnabili_id[$idprima_prenota]))
 } # fine if ($dati_app['maxocc'][$numapp] >= $num_persone)
 } # fine for $num1
 
@@ -148,10 +148,10 @@ $vett_idinizio = $vett_idinizio3;
 $vett_idfine = $vett_idfine3;
 $app_prenota_id = $app_prenota_id_mod;
 $prenota_in_app_sett = $prenota_in_app_sett_mod;
-if ($primo_ciclo == "SI") {
+if (isset($primo_ciclo)) {
 $risul_agg = aggiorna_tableprenota($app_prenota_id,$app_orig_prenota_id,$tableprenota);
 if (!$risul_agg) $n_tronchi = -1;
-} # fine if ($primo_ciclo == "SI")
+} # fine if (isset($primo_ciclo))
 } # fine if ($n_tronchi != -1)
 
 } # fine function spezzaprenota
