@@ -72,20 +72,20 @@ $NO = mex2("NO",$pag,$lingua_mod_esist);
 echo "<form method=\"post\" action=\"crea_modelli.php\" enctype=\"multipart/form-data\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"id_transazione\" value=\"$id_transazione\">
+<input type=\"hidden\" name=\"id_transazione\" value=\"".htmlspecialchars(fixset($id_transazione))."\">
 <input type=\"hidden\" name=\"crea_modello\" value=\"SI\">
 <input type=\"hidden\" name=\"fonte_dati_conn\" value=\"$fonte_dati_conn\">
-<input type=\"hidden\" name=\"T_PHPR_DB_TYPE\" value=\"".htmlspecialchars($T_PHPR_DB_TYPE)."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_NAME\" value=\"".htmlspecialchars($T_PHPR_DB_NAME)."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_HOST\" value=\"".htmlspecialchars($T_PHPR_DB_HOST)."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_PORT\" value=\"".htmlspecialchars($T_PHPR_DB_PORT)."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_USER\" value=\"".htmlspecialchars($T_PHPR_DB_USER)."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_PASS\" value=\"".htmlspecialchars($T_PHPR_DB_PASS)."\">
-<input type=\"hidden\" name=\"T_PHPR_LOAD_EXT\" value=\"".htmlspecialchars($T_PHPR_LOAD_EXT)."\">
-<input type=\"hidden\" name=\"T_PHPR_TAB_PRE\" value=\"".htmlspecialchars($T_PHPR_TAB_PRE)."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_TYPE\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_TYPE))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_NAME\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_NAME))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_HOST\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_HOST))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_PORT\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_PORT))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_USER\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_USER))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_PASS\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_PASS))."\">
+<input type=\"hidden\" name=\"T_PHPR_LOAD_EXT\" value=\"".htmlspecialchars(fixset($T_PHPR_LOAD_EXT))."\">
+<input type=\"hidden\" name=\"T_PHPR_TAB_PRE\" value=\"".htmlspecialchars(fixset($T_PHPR_TAB_PRE))."\">
 <input type=\"hidden\" name=\"anno_modello\" value=\"$anno_modello\">
 <input type=\"hidden\" name=\"lingua_modello\" value=\"$lingua_modello\">
-<input type=\"hidden\" name=\"perc_cart_mod_sel\" value=\"".htmlspecialchars($perc_cart_mod_sel)."\">
+<input type=\"hidden\" name=\"perc_cart_mod_sel\" value=\"".htmlspecialchars(fixset($perc_cart_mod_sel))."\">
 <input type=\"hidden\" name=\"templ_data_dir\" value=\"$template_data_dir\">
 
 <div style=\"height: 4px;\"></div>
@@ -94,13 +94,13 @@ echo "<form method=\"post\" action=\"crea_modelli.php\" enctype=\"multipart/form
 ".mext_cal("Mostra le date",$pag)."</td><td>";
 #if (!$num_periodi_date or controlla_num_pos($num_periodi_date) == "NO") $num_periodi_date = 1;
 $num_periodi_date = 1;
-$numero_date_menu = $n_dates_menu;
+#$numero_date_menu = $n_dates_menu;
 $numero_data = 0;
 for ($num1 = 0 ; $num1 < $num_periodi_date ; $num1++) {
 echo mex("dal",$pag)." ";
-mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","inizioperiodo$num1",${"inizioperiodo".$num1},"","",$id_utente,$tema);
+mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","inizioperiodo$num1",fixset(${"inizioperiodo".$num1}),"","",$id_utente,$tema);
 echo " ".mex("al",$pag)." ";
-mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","fineperiodo$num1",${"fineperiodo".$num1},"","",$id_utente,$tema);
+mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","fineperiodo$num1",fixset(${"fineperiodo".$num1}),"","",$id_utente,$tema);
 echo "<input type=\"hidden\" name=\"num_periodi_date\" value=\"1\">";
 /*
 if (!${"intervalloperiodo".$num1}) ${"intervalloperiodo".$num1} = 1;
@@ -108,7 +108,7 @@ echo ",&nbsp;".str_replace(" ","&nbsp;",mex("$parola_settimane di intervallo",$p
 <input type=\"text\" name=\"intervalloperiodo$num1\" value=\"".${"intervalloperiodo".$num1}."\" size=\"2\" maxlength=\"2\"><br>";
 */
 } # fine for $num1
-if (!$estendi_ultima_data or strtoupper($estendi_ultima_data) == $SI or $estendi_ultima_data == "SI") { $sel_SI = " selected"; $sel_NO = ""; }
+if (empty($estendi_ultima_data) or strtoupper($estendi_ultima_data) == $SI or $estendi_ultima_data == "SI") { $sel_SI = " selected"; $sel_NO = ""; }
 else { $sel_NO = " selected"; $sel_SI = ""; }
 /*
 echo "</td><td width=\"20\"></td><td valign=\"bottom\">";
@@ -124,15 +124,15 @@ echo "</td></tr></table>
 <option value=\"NO\"$sel_NO>".mex("NO",$pag)."</option>
 </select><br>
 <table cellspacing=0 cellpadding=0><tr><td>".mext_cal("Prima data selezionaza",$pag).":</td>";
-if (!$data_preselezionata) $check_data_att = " checked";
-else $check_data_fiss = " checked";
+if (empty($data_preselezionata)) { $check_data_att = " checked"; $check_data_fiss = ""; }
+else { $check_data_fiss = " checked"; $check_data_att = ""; }
 echo "<td>
 <label><input type=\"radio\" name=\"data_presel\" value=\"attuale\"$check_data_att>".mext_cal("data attuale",$pag)."</label>
 </td></tr><tr><td></td><td>
 <label><input type=\"radio\" name=\"data_presel\" value=\"fissa\"$check_data_fiss>".mext_cal("data fissa",$pag)."</label>:";
-mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","data_fissa_sel",$data_preselezionata,"","",$id_utente,$tema,"SI");
+mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","data_fissa_sel",fixset($data_preselezionata),"","",$id_utente,$tema,"SI");
 echo "</td></tr></table>";
-if (!$numero_giorni) $numero_giorni = 31;
+if (empty($numero_giorni)) $numero_giorni = 31;
 echo "".mext_cal("Numero di $parola_settimane della tabella",$pag).":
  <input type=\"text\" name=\"numero_giorni\" size=\"3\" maxlength=\"3\" value=\"$numero_giorni\"><br><br>";
 
@@ -150,19 +150,19 @@ echo "".str_replace("?",":",mex("Mostrare il quadro indicativo della disponibili
 <option value=\"reg2\"$sel_REG2>".mex("Raggruppando gli appartamenti con la regola di assegnazione 2",'unit.php')."</option>
 <option value=\"pers\"$sel_PERS>".mex("Raggruppando gli appartamenti per numero di persone",'unit.php')."</option>
 </select><br><table><tr><td style=\"width: 25px;\"></td><td>";
-if (!$stile_tabella_cal and $stile_tabella_cal != "SI") $stile_tabella_cal = htmlspecialchars("border=1 cellspacing=0 cellpadding=1  style=\"background-color: #dddddd; font-size:70%; text-align: center; margin-left: auto;  margin-right: auto;\"");
+if (empty($stile_tabella_cal)) $stile_tabella_cal = htmlspecialchars("border=1 cellspacing=0 cellpadding=1  style=\"background-color: #dddddd; font-size:70%; text-align: center; margin-left: auto;  margin-right: auto;\"");
 else $stile_tabella_cal = htmlspecialchars($stile_tabella_cal);
-if (!$mostra_quadro_disponibilita and !$colore_inizio_settimana_quadro_disponibilita) $colore_inizio_settimana_quadro_disponibilita = "#bbbbbb";
+if (empty($mostra_quadro_disponibilita) and empty($colore_inizio_settimana_quadro_disponibilita)) $colore_inizio_settimana_quadro_disponibilita = "#bbbbbb";
 else $colore_inizio_settimana_quadro_disponibilita = htmlspecialchars($colore_inizio_settimana_quadro_disponibilita);
-if (!$mostra_quadro_disponibilita and !$colore_libero_quadro_disponibilita) $colore_libero_quadro_disponibilita = "#0cc80c";
+if (empty($mostra_quadro_disponibilita) and empty($colore_libero_quadro_disponibilita)) $colore_libero_quadro_disponibilita = "#0cc80c";
 else $colore_libero_quadro_disponibilita = htmlspecialchars($colore_libero_quadro_disponibilita);
-if (!$mostra_quadro_disponibilita and !$colore_occupato_quadro_disponibilita) $colore_occupato_quadro_disponibilita = "#f8011e";
+if (empty($mostra_quadro_disponibilita) and empty($colore_occupato_quadro_disponibilita)) $colore_occupato_quadro_disponibilita = "#f8011e";
 else $colore_occupato_quadro_disponibilita = htmlspecialchars($colore_occupato_quadro_disponibilita);
-#if (!$mostra_quadro_disponibilita and !$apertura_font_quadro_disponibilita) $apertura_font_quadro_disponibilita = "<font size=&quot;-2&quot;>";
-if (!$mostra_quadro_disponibilita and !$apertura_font_quadro_disponibilita) $apertura_font_quadro_disponibilita = "";
+#if (empty($mostra_quadro_disponibilita) and empty($apertura_font_quadro_disponibilita)) $apertura_font_quadro_disponibilita = "<font size=&quot;-2&quot;>";
+if (empty($mostra_quadro_disponibilita) and empty($apertura_font_quadro_disponibilita)) $apertura_font_quadro_disponibilita = "";
 else $apertura_font_quadro_disponibilita = htmlspecialchars($apertura_font_quadro_disponibilita);
-#if (!$mostra_quadro_disponibilita and !$chiusura_font_quadro_disponibilita) $chiusura_font_quadro_disponibilita = "</font>";
-if (!$mostra_quadro_disponibilita and !$chiusura_font_quadro_disponibilita) $chiusura_font_quadro_disponibilita = "";
+#if (empty($mostra_quadro_disponibilita) and empty($chiusura_font_quadro_disponibilita)) $chiusura_font_quadro_disponibilita = "</font>";
+if (empty($mostra_quadro_disponibilita) and empty($chiusura_font_quadro_disponibilita)) $chiusura_font_quadro_disponibilita = "";
 else $chiusura_font_quadro_disponibilita = htmlspecialchars($chiusura_font_quadro_disponibilita);
 echo "".mext_cal("Stile tabella",$pag).":
  <input type=\"text\" name=\"stile_tabella_cal\" size=\"75\" value=\"$stile_tabella_cal\"><br>
@@ -176,14 +176,14 @@ echo "".mext_cal("Stile tabella",$pag).":
  <input type=\"text\" name=\"apertura_font_quadro_disponibilita\" value=\"$apertura_font_quadro_disponibilita\" size=\"25\"><br>
 ".mex("Tag di chiusura dei font della tabella",$pag).":
  <input type=\"text\" name=\"chiusura_font_quadro_disponibilita\" value=\"$chiusura_font_quadro_disponibilita\" size=\"25\"><br>";
-if (!$mostra_numero_liberi_quadro_disponibilita or strtoupper($mostra_numero_liberi_quadro_disponibilita) == $NO) { $sel_SI = ""; $sel_NO = " selected"; }
+if (empty($mostra_numero_liberi_quadro_disponibilita) or strtoupper($mostra_numero_liberi_quadro_disponibilita) == $NO) { $sel_SI = ""; $sel_NO = " selected"; }
 else { $sel_NO = ""; $sel_SI = " selected"; }
 echo "".mex("Mostrare il numero di appartamenti liberi?",'unit.php')."
 <select name=\"mostra_numero_liberi_quadro_disponibilita\">
 <option value=\"SI\"$sel_SI>".mex("SI",$pag)."</option>
 <option value=\"NO\"$sel_NO>".mex("NO",$pag)."</option>
 </select><br>";
-if (!$allinea_disponibilita_con_arrivo and strtoupper($allinea_disponibilita_con_arrivo) != $SI and $allinea_disponibilita_con_arrivo != "SI") { $sel_SI = ""; $sel_NO = " selected"; }
+if (empty($allinea_disponibilita_con_arrivo) or (strtoupper($allinea_disponibilita_con_arrivo) != $SI and $allinea_disponibilita_con_arrivo != "SI")) { $sel_SI = ""; $sel_NO = " selected"; }
 else { $sel_NO = ""; $sel_SI = " selected"; }
 echo mex("Allineare la disponibilità con la data di arrivo?",$pag)."
 <select name=\"allinea_disponibilita_con_arrivo\">
@@ -201,7 +201,7 @@ $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
 $rigatariffe = esegui_query("select * from $tablenometariffe_modello where idntariffe = 1 ");
 $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
-if (strtoupper($tariffe_mostra[$numtariffa]) == $SI) $checked = " checked";
+if (isset($tariffe_mostra[$numtariffa]) and strtoupper($tariffe_mostra[$numtariffa]) == $SI) $checked = " checked";
 else $checked = "";
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or $checked) {
 if ($celle == 1) echo "<tr>";
@@ -213,7 +213,7 @@ $nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
 } # fine if ($nometariffa == "")
 else $nometariffa_vedi = $nometariffa;
 $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
-if (!$tariffe_mostra['array_esistente']) $checked = " checked";
+if (empty($tariffe_mostra['array_esistente'])) $checked = " checked";
 $val = "";
 if (!empty($nomi_tariffe_imposte[$numtariffa])) $val = $nomi_tariffe_imposte[$numtariffa];
 echo "<td><label><input type=\"checkbox\" name=\"$tariffa\" value=\"SI\"$checked> <b>$numtariffa</b>. $nometariffa_vedi</label>
@@ -282,20 +282,20 @@ echo "</table>
 $dati_struttura = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'dati_struttura' and idutente = '$id_utente'");
 $dati_struttura = explode("#@&",risul_query($dati_struttura,0,'valpersonalizza'));
 
-if (!$apertura_tag_font and $modello_esistente != "SI") $apertura_tag_font = htmlspecialchars("<small>");
+if (empty($apertura_tag_font) and $modello_esistente != "SI") $apertura_tag_font = htmlspecialchars("<small>");
 else $apertura_tag_font = htmlspecialchars($apertura_tag_font);
 #if (!$chiusura_tag_font and $modello_esistente != "SI") $chiusura_tag_font = "</font>";
-if (!$chiusura_tag_font and $modello_esistente != "SI") $chiusura_tag_font = htmlspecialchars("</small>");
+if (empty($chiusura_tag_font) and $modello_esistente != "SI") $chiusura_tag_font = htmlspecialchars("</small>");
 else $chiusura_tag_font = htmlspecialchars($chiusura_tag_font);
 echo "".mex("Tag html di apertura per la formattazione delle font",$pag).":
  <input type=\"text\" name=\"apertura_tag_font\" size=\"25\" value=\"$apertura_tag_font\"><br>
 ".mex("Tag html di chiusura per la formattazione delle font",$pag).":
  <input type=\"text\" name=\"chiusura_tag_font\" size=\"25\" value=\"$chiusura_tag_font\"><br>";
-if (!$file_css_frame) $file_css_frame = "https://";
+if (empty($file_css_frame)) $file_css_frame = "https://";
 else $file_css_frame = htmlspecialchars($file_css_frame);
 echo "".mex("Url del file css per la modalità frame",$pag).":
  <input type=\"text\" name=\"file_css_frame\" size=\"35\" value=\"$file_css_frame\"><br>";
-if (!$file_js_frame) $file_js_frame = "https://";
+if (empty($file_js_frame)) $file_js_frame = "https://";
 else $file_js_frame = htmlspecialchars($file_js_frame);
 echo mex("Url del file javascript per la modalità frame",$pag).":
  <input type=\"text\" name=\"file_js_frame\" size=\"35\" value=\"$file_js_frame\"> <small>(".mex("non deve contenere \"php\" e deve terminare con \".js\"",$pag).")</small><br>";
@@ -304,8 +304,8 @@ include("./includes/templates/$template_data_dir/themes.php");
 $num_temi = count($template_theme_name);
 $tema_sel = 0;
 $js_opz_tema = "";
-if (!$tema_modello and $modello_esistente != "SI") $tema_modello = "default";
-if (!$tema_modello) $sel = " selected";
+if (empty($tema_modello) and $modello_esistente != "SI") $tema_modello = "default";
+if (empty($tema_modello)) $sel = " selected";
 else $sel = "";
 echo "<br>".mex("Utilizza per l'aspetto della pagina",$pag).":
  <select name=\"tema_modello\" id=\"tema_sel\" onchange=\"agg_tema_sel()\">
@@ -324,7 +324,7 @@ $colori_tema = $template_theme_colors[$num1];
 $num_colori = count($colori_tema);
 for ($num2 = 1 ; $num2 <= $num_colori ; $num2++) {
 $colore_corr = $colori_tema[$num2]['default'];
-if ($sel and ${"colore_tema_".$num2}) $colore_corr = ${"colore_tema_".$num2};
+if ($sel and !empty(${"colore_tema_".$num2})) $colore_corr = ${"colore_tema_".$num2};
 $js_opz_tema .= "".mex("Colore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$colori_tema[$num2]['name']."\":\\
  <input type=\"text\" name=\"colore_tema_$num2\" id=\"coltxt$num2\" size=\"8\" value=\"$colore_corr\" onchange=\"agg_colore_sel_txt($num2)\">\\
 <select id=\"colsel$num2\" onchange=\"agg_colore_sel($num2)\" style=\"width: 80px; background-color: $colore_corr\"><option value=\"$colore_corr\" style=\"background-color: $colore_corr\">&nbsp;<\/option>'+options_colori+'<\/select><br>";
@@ -350,23 +350,23 @@ $colori_tema = array();
 if ($tema_sel) $valori_tema = $template_theme_values[$tema_sel];
 $num_valori = count($valori_tema);
 for ($num1 = 1 ; $num1 <= $num_valori ; $num1++) {
-if (!strcmp(${"valore_tema_".$num1},"")) ${"valore_tema_".$num1} = $valori_tema[$num1]['default'];
+if (!isset(${"valore_tema_".$num1}) or !strcmp(${"valore_tema_".$num1},"")) ${"valore_tema_".$num1} = $valori_tema[$num1]['default'];
 $valore_sost = ${"valore_tema_".$num1};
-if (!strcmp($valore_sost,"")) $valore_sost = $valori_tema[$num1]['null'];
-elseif (strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
+if (!strcmp($valore_sost,"")) $valore_sost = fixset($valori_tema[$num1]['null']);
+elseif (isset($valori_tema[$num1]['replace']) and strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
 $template_theme_html_pre[$tema_sel] = str_replace("[theme_value_$num1]",$valore_sost,$template_theme_html_pre[$tema_sel]);
 $template_theme_html_post[$tema_sel] = str_replace("[theme_value_$num1]",$valore_sost,$template_theme_html_post[$tema_sel]);
 } # fine for $num1
 if ($tema_sel) $colori_tema = $template_theme_colors[$tema_sel];
 $num_colori = count($colori_tema);
 for ($num1 = 1 ; $num1 <= $num_colori ; $num1++) {
-if (!${"colore_tema_".$num1}) ${"colore_tema_".$num1} = $colori_tema[$num1]['default'];
+if (empty(${"colore_tema_".$num1})) ${"colore_tema_".$num1} = $colori_tema[$num1]['default'];
 $template_theme_html_pre[$tema_sel] = str_replace("[theme_color_$num1]",${"colore_tema_".$num1},$template_theme_html_pre[$tema_sel]);
 $template_theme_html_post[$tema_sel] = str_replace("[theme_color_$num1]",${"colore_tema_".$num1},$template_theme_html_post[$tema_sel]);
 } # fine for $num1
-if (!$prima_parte_html) $prima_parte_html = htmlspecialchars($template_theme_html_pre[$tema_sel]);
+if (empty($prima_parte_html)) $prima_parte_html = htmlspecialchars($template_theme_html_pre[$tema_sel]);
 else $prima_parte_html = htmlspecialchars($prima_parte_html);
-if (!$ultima_parte_html) $ultima_parte_html = htmlspecialchars($template_theme_html_post[$tema_sel]);
+if (empty($ultima_parte_html)) $ultima_parte_html = htmlspecialchars($template_theme_html_post[$tema_sel]);
 else $ultima_parte_html = htmlspecialchars($ultima_parte_html);
 echo "<br>".mex("Parte html del file prima della form di disponibilità",$pag).":<br>
 <span id=\"html_nota\" style=\"font-size: smaller;\"> (".mex("selezionare \"html personalizzato\" nell'aspetto della pagina per modificarla",$pag).")<br></span>
@@ -419,9 +419,9 @@ agg_tema_sel();
 -->
 </script>
 
-<input type=\"hidden\" name=\"cambia_frasi\" value=\"$cambia_frasi\">
+<input type=\"hidden\" name=\"cambia_frasi\" value=\"".htmlspecialchars(fixset($cambia_frasi))."\">
 <input type=\"hidden\" name=\"modello_esistente\" value=\"$modello_esistente\">";
-if ($cambia_frasi) {
+if (!empty($cambia_frasi)) {
 echo "<br><table style=\"background-color: #000000; margin-left: auto; margin-right: auto;\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\">
 <tr><td><table border=\"0\" cellpadding=\"4\" cellspacing=\"1\" width=\"100%\">
 <tr><td bgcolor=\"#faffff\">
@@ -435,7 +435,7 @@ for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "".mext_cal($frase[$nu
 } # fine else if ($modello_esistente == "SI")
 echo "</td></tr></table>
 </td></tr></table>";
-} # fine if ($cambia_frasi)
+} # fine if (!empty($cambia_frasi))
 elseif ($modello_esistente == "SI") {
 for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "<input type=\"hidden\" name=\"".$fr_frase[$num_fr]."\" value=\"".str_replace("\"","&quot;",${$fr_frase[$num_fr]})."\">";
 } # fine elseif ($modello_esistente == "SI")
