@@ -274,6 +274,7 @@ else $$variabile = str_replace("\\\"","\"",$$variabile);
 } # fine for $num1
 
 
+$continua = "";
 if ($var_per_crea_mod == "SI") {
 if (!$anno_modello) $anno_modello = $anno_modello_presente;
 $tableanni = $PHPR_TAB_PRE."anni";
@@ -313,8 +314,8 @@ $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
 global $$tariffa,$$nome_tariffa_imposto;
 $$tariffa = "";
 $$nome_tariffa_imposto = "";
-if (strtoupper($tariffe_mostra[$numtariffa]) == $SI) $$tariffa = "SI";
-$$nome_tariffa_imposto = $nomi_tariffe_imposte[$numtariffa];
+if (isset($tariffe_mostra[$numtariffa]) and strtoupper($tariffe_mostra[$numtariffa]) == $SI) $$tariffa = "SI";
+$$nome_tariffa_imposto = fixset($nomi_tariffe_imposte[$numtariffa]);
 } # fine for $numtariffa
 
 global $mostra_quadro_disp;
@@ -379,6 +380,7 @@ $tableregole = $PHPR_TAB_PRE."regole".$anno_modello;
 $tableanni = $PHPR_TAB_PRE."anni";
 
 
+$continua = "";
 if (controlla_anno($anno_modello) != "SI") {
 $continua = "NO";
 $anno_modello = "";
@@ -591,12 +593,12 @@ global ${"valore_tema_".$num1};
 if (!empty($valori_tema[$num1]['pattern']) and !preg_match("/".$valori_tema[$num1]['pattern']."/i",${"valore_tema_".$num1})) ${"valore_tema_".$num1} = "";
 ${"valore_tema_".$num1} = formatta_input_var_x_file(${"valore_tema_".$num1});
 $valore_sost = ${"valore_tema_".$num1};
-if (!strcmp($valore_sost,"")) $valore_sost = $valori_tema[$num1]['null'];
-elseif (strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
+if (!strcmp($valore_sost,"")) $valore_sost = fixset($valori_tema[$num1]['null']);
+elseif (isset($valori_tema[$num1]['replace']) and strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
 $prima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$prima_parte_html);
 $ultima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$ultima_parte_html);
 $extra_head_frame = str_replace("[theme_value_$num1]",$valore_sost,$extra_head_frame);
-if ($valori_tema[$num1]['img'] and function_exists('upload_hd_img')) {
+if (!empty($valori_tema[$num1]['img']) and function_exists('upload_hd_img')) {
 $lingua_mex_orig = $lingua_mex;
 $lingua_mex = $lingua_orig;
 upload_hd_img(${"valore_tema_".$num1},$num1);
