@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -36,12 +36,13 @@ $tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
 $tableanni = $PHPR_TAB_PRE."anni";
 
 
-if ($framed) {
+if (!empty($framed)) {
 echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"
         \"http://www.w3.org/TR/html4/loose.dtd\">
 <html>
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
+<meta name=\"viewport\" content=\"initial-scale=1.0\">
 <title>$pag</title>
 ";
 if ($file_css_frame) echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"$file_css_frame\" media=\"all\">
@@ -51,7 +52,7 @@ elseif ($extra_head_frame) echo "$extra_head_frame
 echo "</head>
 <body>
 ";
-} # fine if ($framed)
+} # fine if (!empty($framed))
 
 
 
@@ -142,14 +143,14 @@ $max_periodo = risul_query($max_periodo,0,'idperiodi');
 $num_colonne_tab_disp = $numero_giorni;
 $limiti_var['idperiodocorrente'] = calcola_id_periodo_corrente($anno);
 
-if ((string) $id_data_inizio_tab_disp == "") {
+if (!isset($id_data_inizio_tab_disp) or (string) $id_data_inizio_tab_disp == "") {
 if (!$data_preselezionata) $id_data_inizio_tab_disp = $limiti_var['idperiodocorrente'];
 else {
 $id_data_inizio_tab_disp = esegui_query("select idperiodi from $tableperiodi where datainizio = '".aggslashdb($data_preselezionata)."'");
 if (numlin_query($id_data_inizio_tab_disp) == 1) $id_data_inizio_tab_disp = risul_query($id_data_inizio_tab_disp,0,'idperiodi');
 else $id_data_inizio_tab_disp = $limiti_var['idperiodocorrente'];
 } # fine else if (!$data_preselezionata)
-} # fine if ((string) $id_data_inizio_tab_disp == "")
+} # fine if (!isset($id_data_inizio_tab_disp) or (string) $id_data_inizio_tab_disp == "")
 if (controlla_num_pos($id_data_inizio_tab_disp) != "SI") $id_data_inizio_tab_disp = "0";
 if (($id_data_inizio_tab_disp + $num_colonne_tab_disp - 1) > $max_periodo) $id_data_inizio_tab_disp = ($max_periodo - $num_colonne_tab_disp + 1);
 if ($id_data_inizio_tab_disp < $min_periodo) $id_data_inizio_tab_disp = $min_periodo;
@@ -177,11 +178,12 @@ inserisci_prenota_fittizie($info_periodi_ag,$profondita,$app_prenota_id,$inizio_
 $app_orig_prenota_id = $app_prenota_id;
 } # fine if ($info_periodi_ag['numero'])
 
-if (is_array($motivazioni_regola1)) {
+if (!empty($motivazioni_regola1)) {
+$condizioni_regole1_consentite = "";
 foreach ($motivazioni_regola1 as $key => $val) if ($val == "SI") $condizioni_regole1_consentite .= "motivazione = '".aggslashdb($key)."' or ";
 if (!$condizioni_regole1_consentite) $condizioni_regole1_consentite = "idregole < '0'";
 else $condizioni_regole1_consentite = "(".str_replace("motivazione = ' '","motivazione = '' or motivazione is null",substr($condizioni_regole1_consentite,0,-4)).")";
-} # fine if (is_array($motivazioni_regola1))
+} # fine if (!empty($motivazioni_regola1))
 else $condizioni_regole1_consentite = "idregole < '0'";
 $app_agenzia = esegui_query("select * from $tableregole where app_agenzia != '' and $condizioni_regole1_consentite ");
 
@@ -199,7 +201,7 @@ for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
 $numtariffa_regola2 = str_replace("tariffa","",risul_query($regole2,$num1,'tariffa_per_app'));
 if ($tariffe_mostra[$numtariffa_regola2] == "SI") {
 $app_regola2_orig[$numtariffa_regola2] = risul_query($regole2,$num1,'motivazione');
-if ($dati_r2['napp']["tariffa$numtariffa_regola2"]) $app_regola2_orig['napp'][$numtariffa_regola2] = $dati_r2['napp']["tariffa$numtariffa_regola2"];
+if (!empty($dati_r2['napp']["tariffa$numtariffa_regola2"])) $app_regola2_orig['napp'][$numtariffa_regola2] = $dati_r2['napp']["tariffa$numtariffa_regola2"];
 } # fine if ($tariffe_mostra[$numtariffa_regola2] == "SI")
 } # fine for $num1
 
@@ -219,15 +221,15 @@ $nome_mese["12"] = $fr_Dicembre;
 
 # Calcolo i nomi delle tariffe
 for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
-if ($tariffe_mostra[$numtariffa] == "SI") {
+if (isset($tariffe_mostra[$numtariffa]) and $tariffe_mostra[$numtariffa] == "SI") {
 if ($mostra_quadro_disp == "reg2") {
-if ($n_tariffe_imposte[$numtariffa]) $nome_tariffa[$numtariffa] = $n_tariffe_imposte[$numtariffa];
+if (!empty($n_tariffe_imposte[$numtariffa])) $nome_tariffa[$numtariffa] = $n_tariffe_imposte[$numtariffa];
 else {
 $nome_tariffa[$numtariffa] = $dati_tariffe["tariffa$numtariffa"]['nome'];
 if ($nome_tariffa[$numtariffa] == "") $nome_tariffa[$numtariffa] = $fr_tariffa.$numtariffa;
-} # fine else if ($n_tariffe_imposte[$numtariffa])
+} # fine else if (!empty($n_tariffe_imposte[$numtariffa]))
 } # fine if ($mostra_quadro_disp == "reg2")
-} # fine if ($tariffe_mostra[$numtariffa] == "SI")
+} # fine if (isset($tariffe_mostra[$numtariffa]) and $tariffe_mostra[$numtariffa] == "SI")
 } # fine for $numtariffa
 
 if ($mostra_quadro_disp == "reg2") $tar_cons = "";
@@ -248,12 +250,15 @@ $righe_tab_disp
 } # fine if ($righe_tab_disp)
 
 
-if ($framed) {
+if (!empty($framed)) {
+if ($file_js_frame) echo "
+<script type=\"text/javascript\" src=\"$file_js_frame\">
+</script>";
 echo "
 </body>
 </html>
 ";
-} # fine if ($framed)
+} # fine if (!empty($framed))
 
 
 
