@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -24,7 +24,7 @@
 
 
 
-if (!$tablepersonalizza) $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
+if (empty($tablepersonalizza)) $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 $percorso_cartella_modello = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'percorso_cartella_modello' and idutente = '1'");
 $percorso_cartella_modello = risul_query($percorso_cartella_modello,0,'valpersonalizza');
 if (defined('C_CARTELLA_CREA_MODELLI') and C_CARTELLA_CREA_MODELLI != "") {
