@@ -72,39 +72,39 @@ $NO = mex2("NO",$pag,$lingua_mod_esist);
 echo "<form method=\"post\" action=\"crea_modelli.php\" enctype=\"multipart/form-data\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"id_transazione\" value=\"$id_transazione\">
+<input type=\"hidden\" name=\"id_transazione\" value=\"".htmlspecialchars(fixset($id_transazione))."\">
 <input type=\"hidden\" name=\"crea_modello\" value=\"SI\">
 <input type=\"hidden\" name=\"fonte_dati_conn\" value=\"$fonte_dati_conn\">
-<input type=\"hidden\" name=\"T_PHPR_DB_TYPE\" value=\"".htmlspecialchars($T_PHPR_DB_TYPE)."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_NAME\" value=\"".htmlspecialchars($T_PHPR_DB_NAME)."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_HOST\" value=\"".htmlspecialchars($T_PHPR_DB_HOST)."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_PORT\" value=\"".htmlspecialchars($T_PHPR_DB_PORT)."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_USER\" value=\"".htmlspecialchars($T_PHPR_DB_USER)."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_PASS\" value=\"".htmlspecialchars($T_PHPR_DB_PASS)."\">
-<input type=\"hidden\" name=\"T_PHPR_LOAD_EXT\" value=\"".htmlspecialchars($T_PHPR_LOAD_EXT)."\">
-<input type=\"hidden\" name=\"T_PHPR_TAB_PRE\" value=\"".htmlspecialchars($T_PHPR_TAB_PRE)."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_TYPE\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_TYPE))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_NAME\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_NAME))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_HOST\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_HOST))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_PORT\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_PORT))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_USER\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_USER))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_PASS\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_PASS))."\">
+<input type=\"hidden\" name=\"T_PHPR_LOAD_EXT\" value=\"".htmlspecialchars(fixset($T_PHPR_LOAD_EXT))."\">
+<input type=\"hidden\" name=\"T_PHPR_TAB_PRE\" value=\"".htmlspecialchars(fixset($T_PHPR_TAB_PRE))."\">
 <input type=\"hidden\" name=\"anno_modello\" value=\"$anno_modello\">
 <input type=\"hidden\" name=\"lingua_modello\" value=\"$lingua_modello\">
-<input type=\"hidden\" name=\"perc_cart_mod_sel\" value=\"".htmlspecialchars($perc_cart_mod_sel)."\">
+<input type=\"hidden\" name=\"perc_cart_mod_sel\" value=\"".htmlspecialchars(fixset($perc_cart_mod_sel))."\">
 <input type=\"hidden\" name=\"templ_data_dir\" value=\"$template_data_dir\">
 
 <div style=\"height: 4px;\"></div>
 <h5 id=\"h_rat\"><span>".mext_rat("Pagina della tabella con le tariffe",$pag)."</span></h5><br><br>
 <table><tr><td valign=\"top\">
 ".mext_rat("Mostra tariffe",$pag)."</td><td>";
-if (!$num_periodi_date or controlla_num_pos($num_periodi_date) == "NO") $num_periodi_date = 1;
-$numero_date_menu = $n_dates_menu;
+if (empty($num_periodi_date) or controlla_num_pos($num_periodi_date) == "NO") $num_periodi_date = 1;
+#$numero_date_menu = $n_dates_menu;
 $numero_data = 0;
 for ($num1 = 0 ; $num1 < $num_periodi_date ; $num1++) {
 echo mex("dal",$pag)." ";
-mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","inizioperiodo$num1",${"inizioperiodo".$num1},"","",$id_utente,$tema);
+mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","inizioperiodo$num1",fixset(${"inizioperiodo".$num1}),"","",$id_utente,$tema);
 echo " ".mex("al",$pag)." ";
-mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","fineperiodo$num1",${"fineperiodo".$num1},"","",$id_utente,$tema);
-if (!${"intervalloperiodo".$num1}) ${"intervalloperiodo".$num1} = 1;
+mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","fineperiodo$num1",fixset(${"fineperiodo".$num1}),"","",$id_utente,$tema);
+if (empty(${"intervalloperiodo".$num1})) ${"intervalloperiodo".$num1} = 1;
 echo ",&nbsp;".str_replace(" ","&nbsp;",mex("$parola_settimane di intervallo",$pag)).":&nbsp;
 <input type=\"text\" name=\"intervalloperiodo$num1\" value=\"".htmlspecialchars(${"intervalloperiodo".$num1})."\" size=\"2\" maxlength=\"2\"><br>";
 } # fine for $num1
-if (!$estendi_ultima_data or strtoupper($estendi_ultima_data) == $SI or $estendi_ultima_data == "SI") { $sel_SI = " selected"; $sel_NO = ""; }
+if (empty($estendi_ultima_data) or strtoupper($estendi_ultima_data) == $SI or $estendi_ultima_data == "SI") { $sel_SI = " selected"; $sel_NO = ""; }
 else { $sel_NO = " selected"; $sel_SI = ""; }
 echo "</td><td style=\"width: 20px;\"></td><td valign=\"bottom\">";
 if ($num_periodi_date > 1) echo "<input class=\"sbutton\" type=\"submit\" name=\"eliminadatemenu\" value=\"".mex("-",$pag)."\">&nbsp;";
@@ -117,7 +117,7 @@ echo "<input class=\"sbutton\" type=\"submit\" name=\"aggiungidatemenu\" value=\
 <option value=\"SI\"$sel_SI>".mex("SI",$pag)."</option>
 <option value=\"NO\"$sel_NO>".mex("NO",$pag)."</option>
 </select><br>";
-if (!$mostra_date_passate or strtoupper($mostra_date_passate) == $SI or $mostra_date_passate == "SI") { $sel_SI = " selected"; $sel_NO = ""; }
+if (empty($mostra_date_passate) or strtoupper($mostra_date_passate) == $SI or $mostra_date_passate == "SI") { $sel_SI = " selected"; $sel_NO = ""; }
 else { $sel_NO = " selected"; $sel_SI = ""; }
 echo "".mex("Mostrare le date passate?",$pag)."
 <select name=\"mostra_date_passate\">
@@ -125,14 +125,16 @@ echo "".mex("Mostrare le date passate?",$pag)."
 <option value=\"NO\"$sel_NO>".mex("NO",$pag)."</option>
 </select><br><br>";
 
-if (!$stile_soldi) {
+if (empty($stile_soldi)) {
 $stile_soldi = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'stile_soldi' and idutente = '$id_utente'");
 $stile_soldi = risul_query($stile_soldi,0,'valpersonalizza');
-} # fine if (!$stile_soldi)
+} # fine if (empty($stile_soldi))
 else {
 if ($stile_soldi == mex("usa",$pag)) $stile_soldi = "usa";
 else $stile_soldi = "europa";
-} # fine else if (!$stile_soldi)
+} # fine else if (empty($stile_soldi))
+$check_soldi_eu = "";
+$check_soldi_usa = "";
 if ($stile_soldi == "europa") $check_soldi_eu = " checked";
 if ($stile_soldi == "usa") $check_soldi_usa = " checked";
 echo "<table border=0 cellspacing=0 cellpadding=0><tr>
@@ -142,14 +144,16 @@ echo "<table border=0 cellspacing=0 cellpadding=0><tr>
 <label><input type=\"radio\" name=\"m_stile_soldi\" value=\"usa\"$check_soldi_usa>1,050,000.32</label>
 </td><td style=\"width: 50px;\"></td>";
 
-if (!$stile_data) {
+if (empty($stile_data)) {
 $stile_data = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'stile_data' and idutente = '$id_utente'");
 $stile_data = risul_query($stile_data,0,'valpersonalizza');
-} # fine if (!$stile_data)
+} # fine if (empty($stile_data))
 else {
 if ($stile_data == mex("usa",$pag)) $stile_data = "usa";
 else $stile_data = "europa";
-} # fine else if (!$stile_data)
+} # fine else if (empty($stile_data))
+$check_data_eu = "";
+$check_data_usa = "";
 if ($stile_data == "europa") $check_data_eu = " checked";
 if ($stile_data == "usa") $check_data_usa = " checked";
 echo "<td align=\"center\">".mex("Formato di visualizzazione delle date",$pag).":</td>
@@ -158,11 +162,11 @@ echo "<td align=\"center\">".mex("Formato di visualizzazione delle date",$pag)."
 <label><input type=\"radio\" name=\"m_stile_data\" value=\"usa\"$check_data_usa>08-27-2002</label>
 </td></tr><tr><td style=\"height: 2px;\" colspan=5></td></tr>";
 
-if ($fr_Valuta_sing) $val_s = $fr_Valuta_sing;
+if (!empty($fr_Valuta_sing)) $val_s = $fr_Valuta_sing;
 else $val_s = $Euro;
-if ($fr_Valuta_plur) $val_p = $fr_Valuta_plur;
+if (!empty($fr_Valuta_plur)) $val_p = $fr_Valuta_plur;
 else $val_p = $Euro;
-if (!$anteponi_nome_valuta or strtoupper($anteponi_nome_valuta) != $SI) { $sel_NO = " selected"; $sel_SI = ""; }
+if (empty($anteponi_nome_valuta) or strtoupper($anteponi_nome_valuta) != $SI) { $sel_NO = " selected"; $sel_SI = ""; }
 else { $sel_SI = " selected"; $sel_NO = ""; }
 echo "<tr><td colspan=2>
 ".mex("Nome della valuta al singolare",$pag).": <input type=\"text\" name=\"m_valuta_sing\" size=\"8\" value=\"$val_s\">
@@ -184,7 +188,7 @@ $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
 $rigatariffe = esegui_query("select * from $tablenometariffe_modello where idntariffe = 1 ");
 $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
-if (strtoupper($tariffe_mostra[$numtariffa]) == $SI) $checked = " checked";
+if (isset($tariffe_mostra[$numtariffa]) and strtoupper($tariffe_mostra[$numtariffa]) == $SI) $checked = " checked";
 else $checked = "";
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or $checked) {
 if ($celle == 1) echo "<tr>";
@@ -196,7 +200,7 @@ $nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
 } # fine if ($nometariffa == "")
 else $nometariffa_vedi = $nometariffa;
 $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
-if (!$tariffe_mostra['array_esistente']) $checked = " checked";
+if (empty($tariffe_mostra['array_esistente'])) $checked = " checked";
 $val = "";
 if (!empty($nomi_tariffe_imposte[$numtariffa])) $val = $nomi_tariffe_imposte[$numtariffa];
 echo "<td><label><input type=\"checkbox\" name=\"$tariffa\" value=\"SI\"$checked> <b>$numtariffa</b>. $nometariffa_vedi</label>
@@ -215,7 +219,7 @@ echo "</tr>";
 echo "</table>
 <input type=\"hidden\" name=\"num_tariffe\" value=\"$numero_tariffe\"><br>";
 
-if (!$mostra_caparra or strtoupper($mostra_caparra) == $NO) { $sel_NO = " selected"; $sel_SI = ""; }
+if (empty($mostra_caparra) or strtoupper($mostra_caparra) == $NO) { $sel_NO = " selected"; $sel_SI = ""; }
 else { $sel_SI = " selected"; $sel_NO = ""; }
 echo "".mex("Mostrare la caparra se presente?",$pag)."
 <select name=\"mostra_caparra\">
@@ -258,11 +262,11 @@ echo "</table><br>";
 $dati_struttura = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'dati_struttura' and idutente = '$id_utente'");
 $dati_struttura = explode("#@&",risul_query($dati_struttura,0,'valpersonalizza'));
 
-if (!$apertura_tag_font and $modello_esistente != "SI") $apertura_tag_font = "";
+if (empty($apertura_tag_font) and $modello_esistente != "SI") $apertura_tag_font = "";
 else $apertura_tag_font = htmlspecialchars($apertura_tag_font);
-if (!$chiusura_tag_font and $modello_esistente != "SI") $chiusura_tag_font = "";
+if (empty($chiusura_tag_font) and $modello_esistente != "SI") $chiusura_tag_font = "";
 else $chiusura_tag_font = htmlspecialchars($chiusura_tag_font);
-if (!$stile_tabella_tariffe and $stile_tabella_tariffe != "SI") $stile_tabella_tariffe = htmlspecialchars("cellspacing=\"0\" cellpadding=\"2\" border=\"1\" style=\"text-align: center; margin-left: auto;  margin-right: auto;\"");
+if (empty($stile_tabella_tariffe)) $stile_tabella_tariffe = htmlspecialchars("cellspacing=\"0\" cellpadding=\"2\" border=\"1\" style=\"text-align: center; margin-left: auto;  margin-right: auto;\"");
 else $stile_tabella_tariffe = htmlspecialchars($stile_tabella_tariffe);
 echo "".mex("Tag html di apertura per la formattazione delle font",$pag).":
  <input type=\"text\" name=\"apertura_tag_font\" size=\"25\" value=\"$apertura_tag_font\"><br>
@@ -270,11 +274,11 @@ echo "".mex("Tag html di apertura per la formattazione delle font",$pag).":
  <input type=\"text\" name=\"chiusura_tag_font\" size=\"25\" value=\"$chiusura_tag_font\"><br>
 ".mext_rat("Stile tabella tariffe",$pag).":
  <input type=\"text\" name=\"stile_tabella_tariffe\" size=\"75\" value=\"$stile_tabella_tariffe\"><br>";
-if (!$file_css_frame) $file_css_frame = "https://";
+if (empty($file_css_frame)) $file_css_frame = "https://";
 else $file_css_frame = htmlspecialchars($file_css_frame);
 echo "".mex("Url del file css per la modalità frame",$pag).":
  <input type=\"text\" name=\"file_css_frame\" size=\"35\" value=\"$file_css_frame\"><br>";
-if (!$file_js_frame) $file_js_frame = "https://";
+if (empty($file_js_frame)) $file_js_frame = "https://";
 else $file_js_frame = htmlspecialchars($file_js_frame);
 echo mex("Url del file javascript per la modalità frame",$pag).":
  <input type=\"text\" name=\"file_js_frame\" size=\"35\" value=\"$file_js_frame\"> <small>(".mex("non deve contenere \"php\" e deve terminare con \".js\"",$pag).")</small><br>";
@@ -283,8 +287,8 @@ include("./includes/templates/$template_data_dir/themes.php");
 $num_temi = count($template_theme_name);
 $tema_sel = 0;
 $js_opz_tema = "";
-if (!$tema_modello and $modello_esistente != "SI") $tema_modello = "default";
-if (!$tema_modello) $sel = " selected";
+if (empty($tema_modello) and $modello_esistente != "SI") $tema_modello = "default";
+if (empty($tema_modello)) $sel = " selected";
 else $sel = "";
 echo "<br>".mex("Utilizza per l'aspetto della pagina",$pag).":
  <select name=\"tema_modello\" id=\"tema_sel\" onchange=\"agg_tema_sel()\">
@@ -303,7 +307,7 @@ $colori_tema = $template_theme_colors[$num1];
 $num_colori = count($colori_tema);
 for ($num2 = 1 ; $num2 <= $num_colori ; $num2++) {
 $colore_corr = $colori_tema[$num2]['default'];
-if ($sel and ${"colore_tema_".$num2}) $colore_corr = ${"colore_tema_".$num2};
+if ($sel and !empty(${"colore_tema_".$num2})) $colore_corr = ${"colore_tema_".$num2};
 $js_opz_tema .= "".mex("Colore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$colori_tema[$num2]['name']."\":\\
  <input type=\"text\" name=\"colore_tema_$num2\" id=\"coltxt$num2\" size=\"8\" value=\"$colore_corr\" onchange=\"agg_colore_sel_txt($num2)\">\\
 <select id=\"colsel$num2\" onchange=\"agg_colore_sel($num2)\" style=\"width: 80px; background-color: $colore_corr\"><option value=\"$colore_corr\" style=\"background-color: $colore_corr\">&nbsp;<\/option>'+options_colori+'<\/select><br>";
@@ -329,23 +333,23 @@ $colori_tema = array();
 if ($tema_sel) $valori_tema = $template_theme_values[$tema_sel];
 $num_valori = count($valori_tema);
 for ($num1 = 1 ; $num1 <= $num_valori ; $num1++) {
-if (!strcmp(${"valore_tema_".$num1},"")) ${"valore_tema_".$num1} = $valori_tema[$num1]['default'];
+if (!isset(${"valore_tema_".$num1}) or !strcmp(${"valore_tema_".$num1},"")) ${"valore_tema_".$num1} = $valori_tema[$num1]['default'];
 $valore_sost = ${"valore_tema_".$num1};
-if (!strcmp($valore_sost,"")) $valore_sost = $valori_tema[$num1]['null'];
-elseif (strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
+if (!strcmp($valore_sost,"")) $valore_sost = fixset($valori_tema[$num1]['null']);
+elseif (isset($valori_tema[$num1]['replace']) and strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
 $template_theme_html_pre[$tema_sel] = str_replace("[theme_value_$num1]",$valore_sost,$template_theme_html_pre[$tema_sel]);
 $template_theme_html_post[$tema_sel] = str_replace("[theme_value_$num1]",$valore_sost,$template_theme_html_post[$tema_sel]);
 } # fine for $num1
 if ($tema_sel) $colori_tema = $template_theme_colors[$tema_sel];
 $num_colori = count($colori_tema);
 for ($num1 = 1 ; $num1 <= $num_colori ; $num1++) {
-if (!${"colore_tema_".$num1}) ${"colore_tema_".$num1} = $colori_tema[$num1]['default'];
+if (empty(${"colore_tema_".$num1})) ${"colore_tema_".$num1} = $colori_tema[$num1]['default'];
 $template_theme_html_pre[$tema_sel] = str_replace("[theme_color_$num1]",${"colore_tema_".$num1},$template_theme_html_pre[$tema_sel]);
 $template_theme_html_post[$tema_sel] = str_replace("[theme_color_$num1]",${"colore_tema_".$num1},$template_theme_html_post[$tema_sel]);
 } # fine for $num1
-if (!$prima_parte_html) $prima_parte_html = htmlspecialchars($template_theme_html_pre[$tema_sel]);
+if (empty($prima_parte_html)) $prima_parte_html = htmlspecialchars($template_theme_html_pre[$tema_sel]);
 else $prima_parte_html = htmlspecialchars($prima_parte_html);
-if (!$ultima_parte_html) $ultima_parte_html = htmlspecialchars($template_theme_html_post[$tema_sel]);
+if (empty($ultima_parte_html)) $ultima_parte_html = htmlspecialchars($template_theme_html_post[$tema_sel]);
 else $ultima_parte_html = htmlspecialchars($ultima_parte_html);
 echo "<br>".mex("Parte html del file prima della form di disponibilità",$pag).":<br>
 <span id=\"html_nota\" style=\"font-size: smaller;\"> (".mex("selezionare \"html personalizzato\" nell'aspetto della pagina per modificarla",$pag).")<br></span>
@@ -399,9 +403,9 @@ agg_tema_sel();
 </script>
 
 
-<input type=\"hidden\" name=\"cambia_frasi\" value=\"$cambia_frasi\">
+<input type=\"hidden\" name=\"cambia_frasi\" value=\"".htmlspecialchars(fixset($cambia_frasi))."\">
 <input type=\"hidden\" name=\"modello_esistente\" value=\"$modello_esistente\">";
-if ($cambia_frasi) {
+if (!empty($cambia_frasi)) {
 echo "<br><table style=\"background-color: #000000; margin-left: auto; margin-right: auto;\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\">
 <tr><td><table border=\"0\" cellpadding=\"4\" cellspacing=\"1\" width=\"100%\">
 <tr><td bgcolor=\"#faffff\">
@@ -415,7 +419,7 @@ for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "".mext_rat($frase[$nu
 } # fine else if ($modello_esistente == "SI")
 echo "</td></tr></table>
 </td></tr></table>";
-} # fine if ($cambia_frasi)
+} # fine if (!empty($cambia_frasi))
 elseif ($modello_esistente == "SI") {
 for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "<input type=\"hidden\" name=\"".$fr_frase[$num_fr]."\" value=\"".str_replace("\"","&quot;",${$fr_frase[$num_fr]})."\">";
 } # fine elseif ($modello_esistente == "SI")
