@@ -269,6 +269,7 @@ else $$variabile = str_replace("\\\"","\"",$$variabile);
 } # fine for $num1
 
 
+$continua = "";
 if ($var_per_crea_mod == "SI") {
 if (!$anno_modello) $anno_modello = $anno_modello_presente;
 $tableanni = $PHPR_TAB_PRE."anni";
@@ -312,8 +313,8 @@ $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
 global $$tariffa,$$nome_tariffa_imposto;
 $$tariffa = "";
 $$nome_tariffa_imposto = "";
-if (strtoupper($tariffe_mostra[$numtariffa]) == $SI) $$tariffa = "SI";
-$$nome_tariffa_imposto = $nomi_tariffe_imposte[$numtariffa];
+if (isset($tariffe_mostra[$numtariffa]) and strtoupper($tariffe_mostra[$numtariffa]) == $SI) $$tariffa = "SI";
+$$nome_tariffa_imposto = fixset($nomi_tariffe_imposte[$numtariffa]);
 } # fine for $numtariffa
 $dati_ca = dati_costi_agg_ntariffe($tablenometariffe_modello,"NO");
 for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
@@ -322,7 +323,7 @@ $nome_costo_imposto = "nome_costo_imposto".$dati_ca[$numca]['id'];
 global $$attiva_costo,$$nome_costo_imposto;
 $$attiva_costo = "";
 if (strtoupper($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) == $SI) $$attiva_costo = "SI";
-$$nome_costo_imposto = $nomi_costi_agg_imposti[$dati_ca[$numca]['id']];
+$$nome_costo_imposto = fixset($nomi_costi_agg_imposti[$dati_ca[$numca]['id']]);
 } # fine for $numca
 if (strtoupper($mostra_caparra) == $SI) $mostra_caparra = "SI";
 else $mostra_caparra = "NO";
@@ -353,6 +354,7 @@ $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
 $tableperiodi_modello = $PHPR_TAB_PRE."periodi".$anno_modello;
 $tableanni = $PHPR_TAB_PRE."anni";
 
+$continua = "";
 if (controlla_anno($anno_modello) != "SI") {
 $continua = "NO";
 $anno_modello = "";
@@ -507,8 +509,8 @@ if ($$nome_tariffa_imposto) $nomi_tariffe_imposte .= "$numtariffa => \"".$$nome_
 if ($tariffe_mostra) $tariffe_mostra = substr($tariffe_mostra,0,-1);
 if ($nomi_tariffe_imposte) $nomi_tariffe_imposte = substr($nomi_tariffe_imposte,0,-1);
 
-unset($nomi_costi_imposti);
-unset($costi_attivati);
+$nomi_costi_imposti = "";
+$costi_attivati = "";
 for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
 if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$numca]['id']] == "SI" or strtoupper($costi_aggiuntivi_mostra_tr[$dati_ca[$numca]['id']]) == $SI) {
 global ${"attiva_costo".$dati_ca[$numca]['id']};
@@ -550,12 +552,12 @@ global ${"valore_tema_".$num1};
 if (!empty($valori_tema[$num1]['pattern']) and !preg_match("/".$valori_tema[$num1]['pattern']."/i",${"valore_tema_".$num1})) ${"valore_tema_".$num1} = "";
 ${"valore_tema_".$num1} = formatta_input_var_x_file(${"valore_tema_".$num1});
 $valore_sost = ${"valore_tema_".$num1};
-if (!strcmp($valore_sost,"")) $valore_sost = $valori_tema[$num1]['null'];
-elseif (strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
+if (!strcmp($valore_sost,"")) $valore_sost = fixset($valori_tema[$num1]['null']);
+elseif (isset($valori_tema[$num1]['replace']) and strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
 $prima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$prima_parte_html);
 $ultima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$ultima_parte_html);
 $extra_head_frame = str_replace("[theme_value_$num1]",$valore_sost,$extra_head_frame);
-if ($valori_tema[$num1]['img'] and function_exists('upload_hd_img')) {
+if (!empty($valori_tema[$num1]['img']) and function_exists('upload_hd_img')) {
 $lingua_mex_orig = $lingua_mex;
 $lingua_mex = $lingua_orig;
 upload_hd_img(${"valore_tema_".$num1},$num1);
@@ -806,7 +808,7 @@ if (strtoupper(\$val) == \"$SI\") \$tariffe_mostra[\$key] = \"SI\";
 if (strtoupper(\$val) == \"$NO\") \$tariffe_mostra[\$key] = \"NO\";
 } # fine foreach
 \$n_tariffe_imposte = \$".mex("var_nomi_tariffe_imposte",$pag).";
-unset(\$costi_agg_mostra);
+\$costi_agg_mostra = array();
 reset (\$".mex("var_costi_aggiuntivi_mostra",$pag).");
 foreach (\$".mex("var_costi_aggiuntivi_mostra",$pag)." as \$key => \$val) {
 if (strtoupper(\$val) == \"$SI\") \$costi_agg_mostra[\$key] = \"SI\";
