@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -36,12 +36,13 @@ $tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
 $tableanni = $PHPR_TAB_PRE."anni";
 
 
-if ($framed) {
+if (!empty($framed)) {
 echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"
         \"http://www.w3.org/TR/html4/loose.dtd\">
 <html>
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
+<meta name=\"viewport\" content=\"initial-scale=1.0\">
 <title>$pag</title>
 ";
 if ($file_css_frame) echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"$file_css_frame\" media=\"all\">
@@ -51,7 +52,7 @@ elseif ($extra_head_frame) echo "$extra_head_frame
 echo "</head>
 <body>
 ";
-} # fine if ($framed)
+} # fine if (!empty($framed))
 
 
 
@@ -158,7 +159,7 @@ $nometariffa[$num_tariffe_mostra] = $tariffa[$num_tariffe_mostra];
 $nometariffa_vedi[$num_tariffe_mostra] = $fr_tariffa.${"numtariffa".$num_tariffe_mostra};
 } # fine if ($nometariffa == "")
 else $nometariffa_vedi[$num_tariffe_mostra] = $nometariffa[$num_tariffe_mostra];
-if ($n_tariffe_imposte[$num1]) $nometariffa_vedi[$num_tariffe_mostra] = $n_tariffe_imposte[$num1];
+if (!empty($n_tariffe_imposte[$num1])) $nometariffa_vedi[$num_tariffe_mostra] = $n_tariffe_imposte[$num1];
 if (num_caratteri_testo($nometariffa_vedi[$num_tariffe_mostra]) > 10) $nometariffa_vedi[$num_tariffe_mostra] = "<small>".$nometariffa_vedi[$num_tariffe_mostra]."</small>";
 if ($dati_tariffe[$tariffa[$num_tariffe_mostra]]['moltiplica'] == "p") $per_persona[$num_tariffe_mostra] = 1;
 else $per_persona[$num_tariffe_mostra] = 0;
@@ -187,22 +188,22 @@ for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if ($tariffe_mostra[${"numtariffa".$num1}] == "SI") {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = (double) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]);
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] = (double) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]."p");
-if ($dati_r2['napp'][$tariffa[$num1]] > 1) {
+if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1) {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = $tariffa_colonna_periodo[$num1][$num_colonne_periodi] * (double) $dati_r2['napp'][$tariffa[$num1]];
 #$tariffap_colonna_periodo[$num1][$num_colonne_periodi] = $tariffap_colonna_periodo[$num1][$num_colonne_periodi] * (double) $dati_r2['napp'][$tariffa[$num1]];
-} # fine if ($dati_r2['napp'][$tariffa[$num1]] > 1)
-if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)]) {
+} # fine if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1)
+if (!empty($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)])) {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = "c";
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] = "c";
-} # fine if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)])
+} # fine if (!empty($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)]))
 for ($num_i = 1 ; $num_i < $intervalloperiodi[$num_p] ; $num_i++) {
 if ($tariffa_colonna_periodo[$num1][$num_colonne_periodi] == "c") break;
 $tar_corr = (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]);
 $tarp_corr = (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]."p");
-if ($dati_r2['napp'][$tariffa[$num1]] > 1) {
+if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1) {
 $tar_corr = $tar_corr * (double) $dati_r2['napp'][$tariffa[$num1]];
 #$tarp_corr = $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num1]];
-} # fine if ($dati_r2['napp'][$tariffa[$num1]] > 1)
+} # fine if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1)
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] += $tar_corr;
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] += $tarp_corr;
 if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + $num_i + 1)]) {
@@ -219,22 +220,22 @@ for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
 if ($tariffe_mostra[${"numtariffa".$num2}] == "SI") {
 ${$tariffa[$num2]} = (double) risul_query($periodi,$num1,$tariffa[$num2]);
 ${$tariffa[$num2]."p"} = (double) risul_query($periodi,$num1,$tariffa[$num2]."p");
-if ($dati_r2['napp'][$tariffa[$num2]] > 1) {
+if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1) {
 ${$tariffa[$num2]} = ${$tariffa[$num2]} * (double) $dati_r2['napp'][$tariffa[$num2]];
 #${$tariffa[$num2]."p"} = ${$tariffa[$num2]."p"} * (double) $dati_r2['napp'][$tariffa[$num2]];
-} # fine if ($dati_r2['napp'][$tariffa[$num2]] > 1)
-if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)]) {
+} # fine if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1)
+if (!empty($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)])) {
 ${$tariffa[$num2]} = "c";
 ${$tariffa[$num2]."p"} = "c";
-} # fine if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)])
+} # fine if (!empty($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)]))
 for ($num_i = 1 ; $num_i < $intervalloperiodi[$num_p] ; $num_i++) {
 if (${$tariffa[$num2]} == "c") break;
 $tar_corr = (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]);
 $tarp_corr = (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]."p");
-if ($dati_r2['napp'][$tariffa[$num2]] > 1) {
+if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1) {
 $tar_corr = $tar_corr * (double) $dati_r2['napp'][$tariffa[$num2]];
 #$tarp_corr = $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num2]];
-} # fine if ($dati_r2['napp'][$tariffa[$num2]] > 1)
+} # fine if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1)
 ${$tariffa[$num2]} += $tar_corr;
 ${$tariffa[$num2]."p"} += $tarp_corr;
 if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + $num_i + 1)]) {
@@ -334,14 +335,11 @@ $testo_costi_agg = "";
 for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
 $idcostoagg = $dati_ca[$numca]['id'];
 if ($costi_agg_mostra[$idcostoagg] == "SI") {
-if ($n_costi_agg_imposti[$idcostoagg]) $nomecosto_imposto = $n_costi_agg_imposti[$idcostoagg];
+if (!empty($n_costi_agg_imposti[$idcostoagg])) $nomecosto_imposto = $n_costi_agg_imposti[$idcostoagg];
 else $nomecosto_imposto = $dati_ca[$numca]['nome'];
 $numcostoagg = "costoagg".($numca + 1);
 $nome_idcostoagg = "idcostoagg".($numca + 1);
-if (${$nome_idcostoagg."_".$n_t} == $idcostoagg and ${$numcostoagg."_".$n_t} == "SI") $checked = " checked";
-else $checked = "";
-$testo_costi_agg .= "<li>$apertura_tag_font<input type=\"hidden\" name=\"$nome_idcostoagg"."_$n_t\" value=\"$idcostoagg\">
- <b>$nomecosto_imposto</b>:";
+$testo_costi_agg .= "<li>$apertura_tag_font <b>$nomecosto_imposto</b>:";
 if ($dati_ca[$numca]['tipo_val'] == "f" or $dati_ca[$numca]['valore']) {
 if ($anteponi_nome_valuta != "SI") $testo_costi_agg .= " ".$dati_ca[$numca]['valore'];
 if ($dati_ca[$numca]['valore'] != 1) $testo_costi_agg .= " $fr_Euros";
@@ -382,12 +380,15 @@ $testo_costi_agg
 } # fine if ($testo_costi_agg)
 
 
-if ($framed) {
+if (!empty($framed)) {
+if ($file_js_frame) echo "
+<script type=\"text/javascript\" src=\"$file_js_frame\">
+</script>";
 echo "
 </body>
 </html>
 ";
-} # fine if ($framed)
+} # fine if (!empty($framed))
 
 
 
