@@ -38,10 +38,10 @@ $template_theme_colors[1][2]['default'] = "#ffffff";
 $template_theme_colors[1][3]['name'] = "background 2";
 $template_theme_colors[1][3]['default'] = "#ebebeb";
 $template_theme_values[1][1]['name'] = mex("URL della home",$pag);
-$template_theme_values[1][1]['default'] = $dati_struttura[4];
+$template_theme_values[1][1]['default'] = fixset($dati_struttura[4]);
 $template_theme_values[1][1]['replace'] = "<div class=\"homebox\"><a href=\"[theme_value_1]\" style=\"color: [theme_color_1];\" target=\"_top\">[theme_value_2]</a></div>";
 $template_theme_values[1][2]['name'] = mex("URL del logo",$pag);
-$template_theme_values[1][2]['default'] = $dati_struttura[15];
+$template_theme_values[1][2]['default'] = fixset($dati_struttura[15]);
 $template_theme_values[1][2]['replace'] = "<img style=\"text-decoration: none; border: 0px;\" src=\"[theme_value_2]\" alt=\"[theme_value_3]\">";
 $template_theme_values[1][2]['null'] = "[theme_value_3]";
 $template_theme_values[1][2]['img'] = 1;
@@ -52,7 +52,7 @@ $template_theme_values[1][4]['default'] = "";
 $template_theme_values[1][4]['replace'] = "
 <link rel=\"stylesheet\" type=\"text/css\" href=\"[theme_value_4]\" media=\"all\">";
 $template_theme_values[1][5]['name'] = mex("titolo html",$pag);
-if ($dati_struttura[0]) $template_theme_values[1][5]['default'] = $dati_struttura[0]." - ".mext_rat("Tabella Tariffe",$pag,$lingua_modello);
+if (!empty($dati_struttura[0])) $template_theme_values[1][5]['default'] = $dati_struttura[0]." - ".mext_rat("Tabella Tariffe",$pag,$lingua_modello);
 else $template_theme_values[1][5]['default'] = mext_rat("Tabella Tariffe",$pag,$lingua_modello);
 $template_theme_values[1][5]['null'] = "[theme_value_6]";
 $template_theme_values[1][6]['name'] = mex("titolo",$pag);
