@@ -27,6 +27,7 @@ $titolo = "HotelDruid";
 
 $var_pag = array();
 $var_pag[0] = 'nuovo_mess';
+$var_pag[1] = 'mos_tut_dat';
 $n_var_pag = 1;
 
 include("./costanti.php");
@@ -855,6 +856,7 @@ $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB
 $tableanni = $PHPR_TAB_PRE."anni";
 $tipo_periodi_esistenti = esegui_query("select * from $tableanni order by idanni desc");
 if (numlin_query($tipo_periodi_esistenti) != 0) $tipo_periodi_prec = risul_query($tipo_periodi_esistenti,0,'tipo_periodi');
+else $tipo_periodi_prec = "";
 if ($tipo_periodi_prec == "s") $checked_s = " checked";
 else $checked_g = " checked";
 if (defined('C_CAMBIA_TIPO_PERIODI') and C_CAMBIA_TIPO_PERIODI == "NO") $tipo_periodi_obbligati = $tipo_periodi_prec;
