@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,45 @@
 $pag = "interconnessioni.php";
 $titolo = "HotelDruid: Interconnessioni";
 
+$var_pag = array();
+$var_pag[0] = 'user';
+$var_pag[1] = 'password';
+$var_pag[2] = 'modifica_interconnessione';
+$var_pag[3] = 'modulo';
+$var_pag[4] = 'modifica';
+$var_pag[5] = 'utente_mess';
+$var_pag[6] = 'email_mess';
+$var_pag[7] = 'chiudi_periodi_pieni';
+$var_pag[8] = 'restrizioni_per_sola_lettura';
+$var_pag[9] = 'prenota_vicine';
+$var_pag[10] = 'origine_prenota';
+$var_pag[11] = 'conferma_prenota';
+$var_pag[12] = 'utente_ins_prenota';
+$var_pag[13] = 'utente_chiusura_arrpart';
+$var_pag[14] = 'tariffe_uso_singola';
+$var_pag[15] = 'importa_prezzo_sbagliato';
+$var_pag[16] = 'cancella_prenota_permanente';
+$var_pag[17] = 'nuova_pass';
+$var_pag[18] = 'cancella';
+$var_pag[19] = 'hotel_id_1';
+$var_pag[20] = 'aggiorna_prezzi';
+$var_pag[21] = 'aggiorna_disponibilita';
+$var_pag[22] = 'aggiorna_restrizioni';
+$var_pag[23] = 'aggiorna';
+$var_pag[24] = 'data_agg';
+$n_var_pag = 25;
+if (@is_array($_POST)) {
+reset($_POST);
+for ($num1 = 0 ; $num1 < count($_POST); $num1++) {
+$var_POST = key($_POST);
+if (!isset($$var_POST)) {
+if (substr($var_POST,0,12) == "tipotariffa_" or substr($var_POST,0,16) == "tipo_ro_tariffa_" or substr($var_POST,0,14) == "costolettoagg_" or substr($var_POST,0,17) == "tariffa_hotel_id_" or substr($var_POST,0,13) == "app_hotel_id_" or substr($var_POST,0,8) == "num_cond"
+ or substr($var_POST,0,8) == "ic_user_" or substr($var_POST,0,11) == "ic_orgpass_" or substr($var_POST,0,12) == "ic_password_" or substr($var_POST,0,7) == "ic_org_" or substr($var_POST,0,11) == "ic_hotelid_") $var_pag[$n_var_pag++] = $var_POST;
+} # fine if (!isset($$var_POST))
+next($_POST);
+} # fine for $num1
+} # fine if (@is_array($_POST))
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -52,15 +91,20 @@ $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 $tableinterconnessioni = $PHPR_TAB_PRE."interconnessioni";
 $tablecache = $PHPR_TAB_PRE."cache";
 $tabletransazioni = $PHPR_TAB_PRE."transazioni";
+$tablemessaggi = $PHPR_TAB_PRE."messaggi";
+$tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
 
-if ($user) $nome_utente_phpr = $user;
-if ($password) $password_phpr = $password;
+if (isset($user)) $nome_utente_phpr = $user;
+if (isset($password)) $password_phpr = $password;
 $id_utente_azione_ic = "";
+fixset($mostra_form_iniziale);
+fixset($nuova_pass);
 
-if (defined("C_UTENTE_AZIONE_IC") and C_UTENTE_AZIONE_IC != "" and $utente_azione_ic == C_UTENTE_AZIONE_IC) {
+if (defined('C_UTENTE_AZIONE_IC') and C_UTENTE_AZIONE_IC != "" and $utente_azione_ic == C_UTENTE_AZIONE_IC) {
 if (defined('C_FILE_SCADENZA_ACCOUNT') and C_FILE_SCADENZA_ACCOUNT != "") {
 $scadenza = trim(@implode("",@file("./".C_FILE_SCADENZA_ACCOUNT)));
-$adesso = date("YmdHis");
+#$adesso = date("YmdHis");
+$adesso = date("Ymd")."000000";
 if (!$scadenza or $scadenza < $adesso) exit();
 } # fine if (defined('C_FILE_SCADENZA_ACCOUNT') and C_FILE_SCADENZA_ACCOUNT != "")
 #$id_utente_az = esegui_query("select idlocale from $tableinterconnessioni where tipoid = 'id_utente_az' ");
@@ -115,7 +159,7 @@ $tariffe_consentite = risul_query($privilegi_annuali_utente,0,'tariffe_consentit
 $attiva_tariffe_consentite = substr($tariffe_consentite,0,1);
 if ($attiva_tariffe_consentite == "s") {
 $tariffe_consentite = explode(",",substr($tariffe_consentite,2));
-unset($tariffe_consentite_vett);
+$tariffe_consentite_vett = array();
 for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
 } # fine if ($attiva_tariffe_consentite == "s")
 } # fine if else if (numlin_query($privilegi_annuali_utente) == 0)
@@ -225,7 +269,7 @@ return $errore;
 
 
 
-if ($azione_ic == "SI" or $id_utente_azione_ic) {
+if ((isset($azione_ic) and $azione_ic == "SI") or $id_utente_azione_ic) {
 $mostra_form_iniziale = "NO";
 $modifica_interconnessione = "NO";
 
@@ -301,13 +345,41 @@ $funz_import_reservations = "import_reservations_".$interconnection_func_name;
 $id_utente_origi = $id_utente;
 $id_utente = 1;
 $testo = $funz_import_reservations("",$id_ric,$file_interconnessioni,$anno,$PHPR_TAB_PRE,2,$id_utente,$HOSTNAME);
-$id_utente = $id_utente_origi;
 echo $testo;
+
+$ultimo_aggiornamento_tariffe = esegui_query("select idremoto1 from $tableinterconnessioni where tipoid = 'u_agg_tar' and nome_ic = '$interconnection_name' ");
+if (numlin_query($ultimo_aggiornamento_tariffe)) $ultimo_aggiornamento_tariffe = risul_query($ultimo_aggiornamento_tariffe,0,"idremoto1");
+else {
+$ultimo_aggiornamento_tariffe = "19820711215100";
+esegui_query("insert into $tableinterconnessioni (tipoid,nome_ic,idremoto1) values ('u_agg_tar','$interconnection_name','$ultimo_aggiornamento_tariffe') ");
+} # fine else if (numlin_query($ultimo_aggiornamento_tariffe))
+# Aggiorno ogni 2 giorni
+$limite = date("YmdHis",mktime(date("H"),date("i"),(date("s") + (C_DIFF_ORE * 3600)),date("m"),(date("d") - 2),date("Y")));
+if ($ultimo_aggiornamento_tariffe < $limite) {
+$agg_tariffe_da_remoto = 1;
+include("./includes/interconnect/$mod_ext/form.php");
+$ultimo_aggiornamento_tariffe = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
+esegui_query("update $tableinterconnessioni set idremoto1 = '$ultimo_aggiornamento_tariffe' where tipoid = 'u_agg_tar' and nome_ic = '$interconnection_name' ");
+} # fine if ($ultimo_aggiornamento_tariffe < $limite)
+
+$id_utente = $id_utente_origi;
 } # fine if ($ic_present[$interconnection_name] == "SI" and (!$id_ric or...
 } # fine if ($modello_ext != "." and $modello_ext != ".." and...
 } # fine while ($mod_ext = readdir($interconn_dir))
 closedir($interconn_dir);
 
+if (!$agg_disp or !$agg_tar) {
+$minuti_aspetta_agg = 25;
+$limite_aspetta_aggiornamento = date("Y-m-d H:i:s",(time() - ($minuti_aspetta_agg * 60) + (C_DIFF_ORE * 3600)));
+$errore_aggiornamento = esegui_query("select * from $tablecache where (numero = '11' or numero = '12') and tipo = 'error_ic' and data_modifica < '$limite_aspetta_aggiornamento' ");
+$num_err = numlin_query($errore_aggiornamento);
+for ($num1 = 0 ; $num1 < $num_err ; $num1++) {
+$tipo_err = risul_query($errore_aggiornamento,$num1,'numero');
+if ($tipo_err == '11') $agg_disp = 1;
+if ($tipo_err == '12') $agg_tar = 1;
+} # fine for $num1
+} # fine if (!$agg_disp or !$agg_tar)
+else $num_err = 0;
 if ($agg_disp or $agg_tar) {
 $lock = 1;
 if ($agg_disp) $aggiorna_disp = 1;
@@ -317,6 +389,10 @@ else $aggiorna_tar = 0;
 if (@function_exists('pcntl_fork')) include("./includes/interconnect/aggiorna_ic_fork.php");
 else include("./includes/interconnect/aggiorna_ic.php");
 } # fine if ($agg_disp or $agg_tar)
+if ($num_err) {
+if ($agg_disp) esegui_query("delete from $tablecache where numero = '11' and tipo = 'error_ic' ");
+if ($agg_tar) esegui_query("delete from $tablecache where numero = '12' and tipo = 'error_ic' ");
+} # fine if ($num_err)
 
 } # fine if (@is_array($ic_present))
 } # fine if (@is_file($file_interconnessioni))
@@ -332,7 +408,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./inizio.php\"><di
 } # fine if ($mostra_form_iniziale == "NO")
 
 
-} # fine if ($azione_ic == "SI" or $id_utente_azione_ic)
+} # fine if ((isset($azione_ic) and $azione_ic == "SI") or $id_utente_azione_ic)
 
 
 
@@ -382,7 +458,7 @@ $lista_regola4[$tariffa] = risul_query($regole4,$num1,'iddatainizio');
 
 
 
-if ($modifica_interconnessione == "SI") {
+if (fixset($modifica_interconnessione) == "SI") {
 $mostra_form_iniziale = "NO";
 
 
@@ -393,6 +469,7 @@ while ($mod_ext = readdir($interconn_dir)) {
 if ($mod_ext != "." and $mod_ext != ".." and @is_dir("./includes/interconnect/$mod_ext")) {
 include("./includes/interconnect/$mod_ext/name.php");
 if ($modulo == $interconnection_name) {
+$agg_tariffe_da_remoto = 0;
 include("./includes/interconnect/$mod_ext/form.php");
 } # fine if ($modulo == $interconnection_name)
 } # fine if ($modello_ext != "." and $modello_ext != ".." and...
@@ -506,13 +583,14 @@ echo "<div style=\"text-align: center;\">
 </div></form><br></div>";
 } # fine if ($mostra_form_iniziale == "NO")
 
-} # fine if ($modifica_interconnessione == "SI")
+} # fine if (fixset($modifica_interconnessione) == "SI")
 
 
 
 
 if ($mostra_form_iniziale != "NO") {
- 
+include("./includes/sett_gio.php");
+
 # Pagina iniziale
 echo "<h3 id=\"h_intc\"><span>".mex("Interconnessioni con sorgenti esterne di dati",$pag).".</span></h3>
 <hr style=\"width: 95%\">";
@@ -526,7 +604,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./interconnessioni
 <input type=\"hidden\" name=\"modifica_utente_agg\" value=\"SI\">
 ".mex("Utente per l'aggiornamento remoto delle interconnessioni",$pag).":
  <select name=\"n_utente_agg\">";
-echo "<option value=\"\"$sel_tutti>----</option>";
+echo "<option value=\"\">----</option>";
 $tutti_utenti = esegui_query("select idutenti,nome_utente from $tableutenti where idutenti != '1' order by idutenti");
 $num_tutti_utenti = numlin_query($tutti_utenti);
 for ($num1 = 0 ; $num1 < $num_tutti_utenti ; $num1++) {
@@ -599,6 +677,7 @@ include("./includes/interconnect/$mod_ext/name.php");
 if ($interconnection_name_show[$lingua_mex]) $titolo = $interconnection_name_show[$lingua_mex];
 else $titolo = $interconnection_name_show['en'];
 echo "<hr style=\"width: 95%\"><div id=\"h$interconnection_data_dir\" style=\"text-align: center;\"><b>$titolo</b></div><br>";
+$agg_tariffe_da_remoto = 0;
 include("./includes/interconnect/$mod_ext/form.php");
 } # fine foreach ($interconnessioni as $mod_ext => $val_i)
 closedir($interconn_dir);
@@ -613,7 +692,7 @@ ksort($modelli);
 reset($modelli);
 foreach ($modelli as $modello_ext => $val_i) {
 include("./includes/templates/$modello_ext/name.php");
-if ($template_name_show['tpl_type'] == "interconnection") {
+if (fixset($template_name_show['tpl_type']) == "interconnection") {
 if (!function_exists('mex2')) {
 $perc_cart_mod_sel = "";
 include("./includes/templates/funzioni_modelli.php");
@@ -633,8 +712,9 @@ if ($messaggio) $titolo = $messaggio;
 else $titolo = $template_name_show['en'];
 } # fine else if ($template_name_show[$lingua_mex])
 echo "<hr style=\"width: 95%\"><div id=\"h".$modello_ext."\" style=\"text-align: center;\"><b>$titolo</b></div><br>";
+$agg_tariffe_da_remoto = 0;
 include("./includes/templates/$modello_ext/form.php");
-} # fine if ($template_name_show['tpl_type'] == "interconnection")
+} # fine if (fixset($template_name_show['tpl_type']) == "interconnection")
 } # fine foreach ($modelli as $modello_ext => $val_i)
 closedir($templates_dir);
 
