@@ -28,7 +28,12 @@ $var_pag[0] = 'origine';
 $var_pag[1] = 'tipo_tabella';
 $var_pag[2] = 'idmag';
 $var_pag[3] = 'url_enc';
-$n_var_pag = 4;
+$var_pag[4] = 'origine_vecchia';
+$var_pag[5] = 'aggiorna_inventario';
+$var_pag[6] = 'manda_form_tab';
+$var_pag[7] = 'tipo_nuova_quantita';
+$var_pag[8] = 'modifica_quantita';
+$n_var_pag = 9;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -203,7 +208,7 @@ else include("./includes/head.php");
 $Euro = nome_valuta();
 $frase_modifica = "";
 
-if (!$url_enc) $idmag = htmlspecialchars($idmag);
+if (empty($url_enc)) $idmag = htmlspecialchars($idmag);
 $idmag = aggslashdb($idmag);
 $idmag_orig = $idmag;
 if (substr($idmag,0,1) == "a") {
@@ -228,6 +233,7 @@ $tipo_tabella = htmlspecialchars($tipo_tabella);
 $id_esist = esegui_query("select * from $tablemag where $tipoidmag = '$idmag' ");
 if (numlin_query($id_esist) and (($tipoid == "idappartamento" and $priv_vedi_inv_app != "n") or ($tipoid == "idmagazzino" and $priv_vedi_inv_mag != "n"))) {
 
+$priv_vedi_inv = "";
 if ($tipoid == "idmagazzino" and ($priv_vedi_inv_mag != "s" or $priv_ins_beni != "s" or $priv_mod_beni != "s")) {
 $id_utente_esist = risul_query($id_esist,0,'utente_inserimento');
 $utente_trovato = "NO";
@@ -272,7 +278,7 @@ $condizione_beni_propri .= " )";
 else $condizione_beni_propri = "";
 
 
-if ($aggiorna_inventario and $priv_vedi_beni_inv != "n") {
+if (!empty($aggiorna_inventario) and $priv_vedi_beni_inv != "n") {
 $beni_inv = esegui_query("select * from $tablebeniinventario $condizione_beni_propri order by idbeniinventario");
 $num_beni_inv = numlin_query($beni_inv);
 unset($bene_permesso);
@@ -281,9 +287,9 @@ $idinv = risul_query($beni_inv,$num1,'idbeniinventario');
 $bene_permesso[$idinv] = 1;
 } # fine for $num1
 
-if ($manda_form_tab) {
+if (!empty($manda_form_tab)) {
 
-if ($aggiungi_bene) {
+if (!empty($aggiungi_bene)) {
 if ($priv_ins_beni != "n") {
 if (!strcmp($n_quantita_min_predef,"")) $n_quantita_min_predef = 0;
 if (controlla_num_pos($n_quantita_min_predef) == "SI") {
@@ -421,7 +427,7 @@ unlock_tabelle($tabelle_lock);
 } # fine if (controlla_num_pos($n_quantita) == "SI")
 } # fine if (controlla_num_pos($n_quantita_min_predef) == "SI")
 } # fine if ($priv_ins_beni != "n")
-} # fine if ($aggiungi_bene)
+} # fine if (!empty($aggiungi_bene))
 
 else {
 if ($priv_mod_beni != "n") {
@@ -459,12 +465,12 @@ $frasi_quantita .= "<b>$nome_bene</b>: $quantita $diff = $n_quant<br>";
 unlock_tabelle($tabelle_lock);
 if ($frasi_quantita) $frase_modifica .= "<b>".mex("Quantità aggiornate",$pag)."</b>:<br>$frasi_quantita";
 } # fine if ($priv_mod_beni != "n")
-} # fine else if ($aggiungi_bene)
+} # fine else if (!empty($aggiungi_bene))
 
-} # fine if ($manda_form_tab)
+} # fine if (!empty($manda_form_tab))
 
 
-if ($ricarica and $id_bene and $priv_mod_beni != "n") {
+if (!empty($ricarica) and $id_bene and $priv_mod_beni != "n") {
 $id_bene = aggslashdb($id_bene);
 if ($bene_permesso[$id_bene]) {
 $tabelle_lock = array($tablerelinventario);
@@ -641,10 +647,10 @@ if ($ricaricato == "SI") $frase_modifica .= "<b>".mex("Bene ricaricato",$pag)."<
 } # fine if (numlin_query($bene_in_mag) == 1)
 unlock_tabelle($tabelle_lock);
 } # fine if ($bene_permesso[$id_bene])
-} # fine if ($ricarica and $id_bene and $priv_mod_beni != "n")
+} # fine if (!empty($ricarica) and $id_bene and $priv_mod_beni != "n")
 
 
-if ($elimina and $id_bene and $priv_ins_beni != "n") {
+if (!empty($elimina) and $id_bene and $priv_ins_beni != "n") {
 $id_bene = aggslashdb($id_bene);
 if ($bene_permesso[$id_bene]) {
 $tabelle_lock = array("$tablerelinventario");
@@ -681,14 +687,14 @@ $frase_modifica .= "<b>".mex("Bene",$pag)." \"<em>$nome_bene</em>\" ".mex("cance
 } # fine if (numlin_query($id_bene_in_mag))
 unlock_tabelle($tabelle_lock);
 } # fine if ($bene_permesso[$id_bene])
-} # fine if ($elimina and $id_bene and $priv_ins_beni != "n")
+} # fine if (!empty($elimina) and $id_bene and $priv_ins_beni != "n")
 
-} # fine if ($aggiorna_inventario and $priv_vedi_beni_inv != "n")
+} # fine if (!empty($aggiorna_inventario) and $priv_vedi_beni_inv != "n")
 
 
 
 # Form per modificare l'inventario.
-if ($mostra_form_inventario != "NO") {
+if (!isset($mostra_form_inventario) or $mostra_form_inventario != "NO") {
 
 $ordine_inventario = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'ordine_inventario' and idutente = '$id_utente' ");
 $ordine_inventario = risul_query($ordine_inventario,0,'valpersonalizza');
@@ -727,9 +733,9 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#tab_inventari
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
-<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars($origine_vecchia)."\">
-<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
-<input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
+<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars(fixset($origine_vecchia))."\">
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars($tipo_tabella)."\">
+<input type=\"hidden\" name=\"idmag\" value=\"".htmlspecialchars($idmag_orig)."\">
 <input type=\"hidden\" name=\"aggiorna_inventario\" value=\"SI\">
 <input type=\"hidden\" name=\"manda_form_tab\" value=\"SI\">
 <div class=\"tab_cont\">
@@ -858,11 +864,11 @@ echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">";
-if ($origine_vecchia) echo "<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine_vecchia)."\">";
+if (!empty($origine_vecchia)) echo "<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine_vecchia)."\">";
 echo "<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br>$a_bottom</div>";
 
-} # fine if ($mostra_form_inventario != "NO")
+} # fine if (!isset($mostra_form_inventario) or $mostra_form_inventario != "NO")
 
 
 
