@@ -29,7 +29,17 @@ $var_pag[1] = 'tipo_tabella';
 $var_pag[2] = 'num_app_modifica';
 $var_pag[3] = 'modificaappartamento';
 $var_pag[4] = 'form_tabella';
-$n_var_pag = 5;
+$var_pag[5] = 'cancella_app';
+$var_pag[6] = 'cancella_sicuro';
+$var_pag[7] = 'modificadescr';
+$var_pag[8] = 'n_descrizione_ita';
+$var_pag[9] = 'aggurlfoto';
+$var_pag[10] = 'n_urlfoto';
+$var_pag[11] = 'commentofoto';
+$var_pag[12] = 'numfoto';
+$var_pag[13] = 'n_commento_ita';
+$var_pag[14] = 'cancurlfoto';
+$n_var_pag = 15;
 $num2 = 0;
 if (isset($_POST['num_app_modifica'])) $num2 = (int) $_POST['num_app_modifica'];
 elseif (isset($_GET['num_app_modifica'])) $num2 = (int) $_GET['num_app_modifica'];
@@ -49,6 +59,13 @@ $var_pag[$n_var_pag++] = "d_priorita$num1";
 $var_pag[$n_var_pag++] = "d_app_vicini$num1";
 $var_pag[$n_var_pag++] = "d_commento$num1";
 } # fine for $num1
+$num2 = opendir("./includes/lang/");
+while ($num1 = readdir($num2)) {
+if ($num1 != "." and $num1 != ".." and strlen($num1) <= 3 and preg_replace("/[a-z]/","",$num1) == "") {
+$var_pag[$n_var_pag++] = "n_descrizione_$num1";
+$var_pag[$n_var_pag++] = "n_commento_$num1";
+} # fine if ($num1 != "." and $num1 != ".." and...
+} # fine while ($num1 = readdir($num2))
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -83,7 +100,7 @@ if (strstr($idapp_contr,">") or strstr($idapp_contr,"<") or strstr($idapp_contr,
 $dest = "";
 
 
-if ($cancella_app) {
+if (!empty($cancella_app)) {
 $mostra_form_modifica = "NO";
 $modificaappartamento = "";
 $modificadescr = "";
@@ -93,6 +110,7 @@ $aggurlfoto = "";
 
 $oggi = date("Y-m-d",(time() + (C_DIFF_ORE * 3600)));
 $anno_attuale = date("Y",(time() + (C_DIFF_ORE * 3600)));
+$cancellare = "";
 
 $anni_esistenti = esegui_query("select * from $tableanni order by idanni");
 $num_anni_esistenti = numlin_query($anni_esistenti);
@@ -137,7 +155,15 @@ if ($anno_esistente != $anno_esistente2) $cancellare = "NO";
 } # fine for $num1
 if ($cancellare == "NO") echo mex("<b>L'appartamento non è stato cancellato</b> perchè il database è cambiato nel frattempo",'unit.php').".<br>";
 
-$anni_da_controllare = esegui_query("select * from $tableanni where idanni >= $anno_attuale");
+$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."'");
+$num_app_esiste = numlin_query($app_esiste);
+if ($num_app_esiste != 1) {
+echo "<br>".mex("L'appartamento",'unit.php')." $idappartamenti ".mex("è già stato cancellato",'unit.php').".<br><br>";
+$cancellare = "NO";
+} # fine if ($num_app_esiste != 1)
+
+if ($cancellare != "NO") {
+$anni_da_controllare = esegui_query("select * from $tableanni where idanni >= '$anno_attuale' ");
 $num_anni_da_controllare = numlin_query($anni_da_controllare);
 include("./includes/liberasettimane.php");
 unset($app_richiesti);
@@ -147,7 +173,7 @@ $anno_controlla = risul_query($anni_da_controllare,$num1,'idanni');
 $tableprenota_controlla = $PHPR_TAB_PRE."prenota".$anno_controlla;
 $tableperiodi_controlla = $PHPR_TAB_PRE."periodi".$anno_controlla;
 unset($limiti_var);
-unset($profondita);
+$profondita = null;
 unset($app_prenota_id);
 unset($app_orig_prenota_id);
 unset($inizio_prenota_id);
@@ -170,22 +196,16 @@ break;
 } # fine if ($num_prenota_presenti != 0)
 } # fine for $num1
 
-$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."'");
-$num_app_esiste = numlin_query($app_esiste);
-if ($num_app_esiste != 1) {
-echo "<br>".mex("L'appartamento",'unit.php')." $idappartamenti ".mex("è già stato cancellato",'unit.php').".<br><br>";
-$cancellare = "NO";
-} # fine if ($num_app_esiste != 1)
-
 $ultimo_app = esegui_query("select idappartamenti from $tableappartamenti ");
 $ultimo_app = numlin_query($ultimo_app);
 if ($ultimo_app == 1) {
 echo "<br>".mex("Rimane solo",$pag)." ".mex("un appartamento",'unit.php').".<br><br>";
 $cancellare = "NO";
 } # fine if ($ultimo_app == 1)
+} # fine if ($cancellare != "NO")
 
 if ($cancellare != "NO") {
-if ($cancella_sicuro != "SI") {
+if (!isset($cancella_sicuro) or $cancella_sicuro != "SI") {
 echo mex("Sei sicuro di voler <b>cancellare</b> l'appartamento",'unit.php')." <b>$idappartamenti</b>?<br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_app.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -195,7 +215,7 @@ echo mex("Sei sicuro di voler <b>cancellare</b> l'appartamento",'unit.php')." <b
 <button class=\"croo\" type=\"submit\" name=\"cancella_app\" value=\"".mex("SI",$pag)."\"><div>".mex("SI",$pag)."</div></button>
 <button class=\"gobk\" type=\"submit\" name=\"non_cancellare\" value=\"".mex("NO",$pag)."\"><div>".mex("NO",$pag)."</div></button>
 <br></div></form>";
-} # fine if ($cancella_sicuro != "SI")
+} # fine if (!isset($cancella_sicuro) or $cancella_sicuro != "SI")
 
 else {
 $d_app_vicini = esegui_query("select app_vicini from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."' ");
@@ -264,7 +284,7 @@ $aggiorna_tar = 0;
 if (@function_exists('pcntl_fork')) include("./includes/interconnect/aggiorna_ic_fork.php");
 else include("./includes/interconnect/aggiorna_ic.php");
 
-} # fine else if ($cancella_sicuro != "SI")
+} # fine else if (!isset($cancella_sicuro) or $cancella_sicuro != "SI")
 } # fine if ($cancellare != "NO")
 
 else {
@@ -277,12 +297,12 @@ echo "
 <br></div></form>";
 } # fine else if ($cancellare != "NO")
 
-if ($tabelle_lock) unlock_tabelle($tabelle_lock);
-} # fine if ($cancella_app)
+if (!empty($tabelle_lock)) unlock_tabelle($tabelle_lock);
+} # fine if (!empty($cancella_app))
 
 
 
-if ($modificaappartamento) {
+if (!empty($modificaappartamento)) {
 $mostra_form_modifica = "NO";
 $modificadescr = "";
 $commentofoto = "";
@@ -713,12 +733,12 @@ echo "<div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">";
 echo "<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 <br></div></form><br></div>";
-} # fine if ($modificaappartamento)
+} # fine if (!empty($modificaappartamento))
 
 
 
 
-if ($modificadescr) {
+if (!empty($modificadescr)) {
 $mostra_form_modifica = "NO";
 $tabelle_lock = array($tabledescrizioni);
 $altre_tab_lock = array($tableappartamenti);
@@ -754,10 +774,10 @@ echo "<br>".ucfirst(mex("descrizione dell'appartamento",'unit.php'))." $idappart
 unlock_tabelle($tabelle_lock);
 $mostra_torna_indietro = "SI";
 $dest = "#descrcocont";
-} # fine if ($modificadescr)
+} # fine if (!empty($modificadescr))
 
 
-if ($commentofoto) {
+if (!empty($commentofoto)) {
 $mostra_form_modifica = "NO";
 $app_esist = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 if ($numfoto and controlla_num_pos($numfoto) == "SI" and numlin_query($app_esist)) {
@@ -795,10 +815,10 @@ unlock_tabelle($tabelle_lock);
 } # fine if ($numfoto and controlla_num_pos($numfoto) == "SI" and...
 $mostra_torna_indietro = "SI";
 $dest = "#fotocont";
-} # fine if ($commentofoto)
+} # fine if (!empty($commentofoto))
 
 
-if ($cancurlfoto) {
+if (!empty($cancurlfoto)) {
 $mostra_form_modifica = "NO";
 if ($numfoto and controlla_num_pos($numfoto) == "SI") {
 esegui_query("delete from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and (tipo = 'appfoto' or tipo = 'appcommfoto') and numero = '$numfoto' ");
@@ -806,12 +826,13 @@ echo "".ucfirst(mex("foto eliminata",$pag)).".<br>";
 } # fine if ($numfoto and controlla_num_pos($numfoto) == "SI")
 $mostra_torna_indietro = "SI";
 $dest = "#fotocont";
-} # fine if ($aggurlfoto)
+} # fine if (!empty($cancurlfoto))
 
 
-if ($aggurlfoto) {
+if (!empty($aggurlfoto)) {
 $mostra_form_modifica = "NO";
 $dest = "#aggfoto";
+$errore = "";
 if (@get_magic_quotes_gpc()) $n_urlfoto = stripslashes($n_urlfoto);
 $lowurl = strtolower($n_urlfoto);
 if (substr($lowurl,-4) != ".jpg" and substr($lowurl,-5) != ".jpeg" and substr($lowurl,-4) != ".gif" and substr($lowurl,-4) != ".png" and substr($lowurl,-5) != ".webp") $errore = "SI";
@@ -832,11 +853,11 @@ $dest = "#ultimafoto";
 } # fine if ($errore != "SI")
 else echo "".ucfirst(mex("l'url della foto è sbagliata",$pag)).".<br>";
 $mostra_torna_indietro = "SI";
-} # fine if ($aggurlfoto)
+} # fine if (!empty($aggurlfoto))
 
 
 
-if ($mostra_torna_indietro == "SI") {
+if (isset($mostra_torna_indietro) and $mostra_torna_indietro == "SI") {
 echo "<div style=\"text-align: center;\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag$dest\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -844,12 +865,12 @@ echo "<div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">";
 echo "<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 <br></div></form><br></div>";
-} # fine if ($mostra_torna_indietro == "SI")
+} # fine if (isset($mostra_torna_indietro) and $mostra_torna_indietro == "SI")
 
 
 
 
-if ($mostra_form_modifica != "NO") {
+if (!isset($mostra_form_modifica) or $mostra_form_modifica != "NO") {
 
 
 # Form per modificare l'appartamento.
@@ -862,9 +883,9 @@ $d_priorita = risul_query($appartamento,0,'priorita');
 $d_letto = risul_query($appartamento,0,'letto');
 $d_app_vicini = risul_query($appartamento,0,'app_vicini');
 $d_commento = risul_query($appartamento,0,'commento');
-} # fine if (numlin_query($appartamento))
 
-if ($d_letto) $fr1 = "[1]";
+
+if (!empty($d_letto)) $fr1 = "[1]";
 else $fr1 = "";
 
 echo "<h3 id=\"h_mroo\"><span>".mex($fr1."Modifica l'appartamento",'unit.php')." $idappartamenti.</span></h3>";
@@ -948,7 +969,7 @@ closedir($lang_dir);
 echo "</tr></table>
 <button class=\"edit\" type=\"submit\"><div>".ucfirst(mex("modifica",$pag))."</div></button></div></form></div><br><br>";
 
-$foto = esegui_query("select * from $tabledescrizioni where nome = '".$idappartamenti."' and tipo = 'appfoto' order by numero ");
+$foto = esegui_query("select * from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appfoto' order by numero ");
 $num_foto = numlin_query($foto);
 echo "<div id=\"fotocont\" class=\"rbox\"><div style=\"padding-top: 2px;\">".ucfirst(mex($fr1."foto dell'appartamento",'unit.php'))." <em>".$idappartamenti."</em>:<br>";
 for ($num1 = 1 ; $num1 <= $num_foto ; $num1++) {
@@ -998,7 +1019,7 @@ echo "<br><form id=\"aggfoto\" accept-charset=\"utf-8\" method=\"post\" action=\
 <input type=\"hidden\" name=\"idappartamenti\" value=\"".$idappartamenti."\">
 <input type=\"hidden\" name=\"aggurlfoto\" value=\"SI\">
 ".ucfirst(mex("url di una nuova foto",$pag)).":
-<input id=\"n_urlf\" type=\"text\" name=\"n_urlfoto\" size=\"30\" value=\"http://\"$readonly>
+<input id=\"n_urlf\" type=\"text\" name=\"n_urlfoto\" size=\"30\" value=\"https://\"$readonly>
 <button class=\"apho\" type=\"submit\"><div>".ucfirst(mex("aggiungi",$pag))."</div></button><br>
 ".upload_hd_img_form('n_urlf',$tablepersonalizza)."</div></form><br></div></div>";
 
@@ -1009,9 +1030,11 @@ echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">
 <input type=\"hidden\" name=\"cancella_app\" value=\"1\">
 <button class=\"croo\" id=\"canc\" type=\"submit\"><div>".mex($fr1."Cancella l'appartamento",'unit.php')." $idappartamenti</div></button>
-</div><br></form></div>
+</div><br></form></div>";
 
-<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
+} # fine if (numlin_query($appartamento))
+
+echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_tabelle.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -1020,7 +1043,8 @@ echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 </div></form><br></div>";
 
 
-} # fine if ($mostra_form_modifica != "NO")
+
+} # fine if (!isset($mostra_form_modifica) or $mostra_form_modifica != "NO")
 
 
 
