@@ -135,7 +135,7 @@ $num_contratto_int = (integer) $num_contratto;
 
 
 
-if ($cambia_qualcosa) {
+if (!empty($cambia_qualcosa)) {
 $anchor = "";
 
 
@@ -146,7 +146,7 @@ $input_utente = str_replace("\"","\\\"",$input_utente);
 return $input_utente;
 } # fine function formatta_input_var_x_file
 
-if ($cambia_formato) {
+if (!empty($cambia_formato)) {
 $formato = "";
 if ($nuovo_formato == "HTML") $formato = "contrhtm";
 if ($nuovo_formato == "EMAIL") $formato = "contreml";
@@ -213,9 +213,9 @@ echo "".mex("Formato del documento cambiato",$pag).".<br>";
 } # fine if (numlin_query($vecchio_formato) == 1)
 unlock_tabelle($tabelle_lock);
 } # fine if ($formato)
-} # fine if ($cambia_formato)
+} # fine if (!empty($cambia_formato))
 
-if ($cambia_formati_dati) {
+if (!empty($cambia_formati_dati)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $mostra_form_iniziale = "NO";
@@ -232,9 +232,9 @@ else esegui_query("delete from $tablecontratti where numero = '$num_contratto' a
 elseif ($formati) esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','formati','".aggslashdb($formati)."') ");
 echo "".mex("Formati predefiniti del documento cambiati",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
-} # fine if ($cambia_formati_dati)
+} # fine if (!empty($cambia_formati_dati))
 
-if ($cambia_dir_salva) {
+if (!empty($cambia_dir_salva)) {
 if (@get_magic_quotes_gpc()) $nuova_dir_salva = stripslashes($nuova_dir_salva);
 $nuova_dir_salva = htmlspecialchars($nuova_dir_salva);
 $nuova_dir_salva = aggslashdb($nuova_dir_salva);
@@ -278,9 +278,9 @@ echo "".mex("I documenti non verranno salvati",$pag).".<br>";
 } # fine if ($dir_salva)
 } # fine if ($tipo_contratto == "contrrtf" or..
 unlock_tabelle($tabelle_lock);
-} # fine if ($cambia_dir_salva)
+} # fine if (!empty($cambia_dir_salva))
 
-if ($cambia_compress) {
+if (!empty($cambia_compress)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $dir_esistente = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
@@ -299,9 +299,9 @@ echo "".mex("Il documento verrà salvato compresso su disco",$pag).".<br>";
 } # fine else if (!$compress)
 } # fine if (numlin_query($dir_esistente))
 unlock_tabelle($tabelle_lock);
-} # fine if ($cambia_compress)
+} # fine if (!empty($cambia_compress))
 
-if ($cambia_autosalv) {
+if (!empty($cambia_autosalv)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $dir_esistente = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
@@ -325,9 +325,9 @@ echo ".<br>";
 } # fine else if (!$n_autosalv)
 } # fine if (numlin_query($dir_esistente))
 unlock_tabelle($tabelle_lock);
-} # fine if ($cambia_autosalv)
+} # fine if (!empty($cambia_autosalv))
 
-if ($cambia_incr_np) {
+if (!empty($cambia_incr_np)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $dir_esistente = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
@@ -345,9 +345,9 @@ echo "".mex("Il numero progressivo verrà incrementato ogni volta che compare ne
 } # fine else if (!$incr_np)
 } # fine if (numlin_query($dir_esistente))
 unlock_tabelle($tabelle_lock);
-} # fine if ($cambia_incr_np)
+} # fine if (!empty($cambia_incr_np))
 
-if ($cambia_num_prog) {
+if (!empty($cambia_num_prog)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $dir_esistente = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
@@ -379,9 +379,9 @@ echo ucfirst(mex("il documento",$pag))." $num_contratto ".mex("condividerà il n
 } # fine else if (!strcmp($contr_num_prog,""))
 } # fine if (numlin_query($dir_esistente))
 unlock_tabelle($tabelle_lock);
-} # fine if ($cambia_num_prog)
+} # fine if (!empty($cambia_num_prog))
 
-if ($cambia_nome_file) {
+if (!empty($cambia_nome_file)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $dir_esistente = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
@@ -403,9 +403,9 @@ echo "".mex("I file verranno salvati con il nome",$pag)." \"$nome_file_salva\".<
 } # fine else if ($tipo_nome_file != "pers")
 } # fine if (numlin_query($dir_esistente))
 unlock_tabelle($tabelle_lock);
-} # fine if ($cambia_nome_file)
+} # fine if (!empty($cambia_nome_file))
 
-if ($priv_mod_doc_api == "s" and ($cambia_cons_api or strcmp($pass_api,"") or $id_utente_api)) {
+if ($priv_mod_doc_api == "s" and (!empty($cambia_cons_api) or (isset($pass_api) and strcmp($pass_api,"")) or !empty($id_utente_api))) {
 $tabelle_lock = array($tablecontratti);
 $altre_tab_lock = array($tableutenti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
@@ -458,9 +458,9 @@ echo mex("Il documento non verrà più considerato come una API",$pag).".<br>";
 } # fine else if (strcmp($pass_api,"") or $id_utente_api)
 } # fine if ($tipo_contratto == "contrrtf" or..
 unlock_tabelle($tabelle_lock);
-} # fine if ($priv_mod_doc_api == "s" and ($cambia_cons_api or strcmp($pass_api,"") or $id_utente_api))
+} # fine if ($priv_mod_doc_api == "s" and (!empty($cambia_cons_api) or (isset($pass_api) and...
 
-if ($cambia_intestazione_pers) {
+if (!empty($cambia_intestazione_pers)) {
 $tipo_contratto = esegui_query("select tipo from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
 $tipo_contratto = risul_query($tipo_contratto,0,'tipo');
 if ($tipo_contratto == "contrhtm") {
@@ -477,9 +477,9 @@ esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_cont
 echo "".mex("Intestazione html cambiata",$pag).".<br>";
 } # fine if (($intestazione_html and !$intestazione_pers) or...
 } # fine if ($tipo_contratto == "contrhtm")
-} # fine if ($cambia_intestazione_pers)
+} # fine if (!empty($cambia_intestazione_pers))
 
-if ($cambia_estenstione_pers) {
+if (!empty($cambia_estenstione_pers)) {
 $tipo_contratto = esegui_query("select tipo from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
 $tipo_contratto = risul_query($tipo_contratto,0,'tipo');
 if ($tipo_contratto == "contrtxt") {
@@ -499,9 +499,9 @@ else esegui_query("update $tablecontratti set testo = '$estensione_pers_txt' whe
 echo "".mex("Estensione cambiata",$pag).".<br>";
 } # fine if (($tipo_estensione_txt == "pers" and $estensione_pers_txt and...
 } # fine if ($tipo_contratto == "contrtxt")
-} # fine if ($cambia_estenstione_pers)
+} # fine if (!empty($cambia_estenstione_pers))
 
-if ($cambia_oggetto) {
+if (!empty($cambia_oggetto)) {
 if (@get_magic_quotes_gpc()) $nuovo_oggetto = stripslashes($nuovo_oggetto);
 if (strlen($nuovo_oggetto) > 120) $nuovo_oggetto = substr($nuovo_oggetto,0,120);
 $nuovo_oggetto = htmlspecialchars($nuovo_oggetto);
@@ -516,9 +516,9 @@ esegui_query("update $tablecontratti set testo = '$nuovo_oggetto' where numero =
 echo "".mex("Oggetto cambiato",$pag).".<br>";
 } # fine if ($tipo_contratto == "contreml")
 unlock_tabelle($tabelle_lock);
-} # fine if ($cambia_oggetto)
+} # fine if (!empty($cambia_oggetto))
 
-if ($upload_allegato) {
+if (!empty($upload_allegato)) {
 $errore = "NO";
 $file_tmp = C_DATI_PATH."/allegato_contr$num_contratto.tmp";
 if (!$file_allegato_upload) {
@@ -568,18 +568,18 @@ unlock_tabelle($tabelle_lock);
 } # fine if (!defined("C_MASSIMO_NUM_BYTE_UPLOAD") or...
 else unlink($file_tmp);
 } # fine if ($errore == "NO")
-} # fine if ($upload_allegato)
+} # fine if (!empty($upload_allegato))
 
-if ($aggiungi_allegato) {
+if (!empty($aggiungi_allegato)) {
 $all_esistente = @esegui_query("select * from $tablecontratti where numero = '".aggslashdb($num_allegato)."' and tipo = 'file_all' ");
 if (numlin_query($all_esistente)) {
 $mostra_form_iniziale = "NO";
 esegui_query("update $tablecontratti set testo = '$num_allegato' where numero = '$num_contratto' and tipo = 'allegato'");
 echo "".mex("Allegato salvato",$pag).".<br>";
 } # fine if(numlin_query($all_esistente))
-} # fine if ($aggiungi_allegato)
+} # fine if (!empty($aggiungi_allegato))
 
-if ($elimina_allegato) {
+if (!empty($elimina_allegato)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $tipo_contratto = esegui_query("select tipo from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
@@ -598,9 +598,9 @@ echo "".mex("Allegato eliminato",$pag).".<br>";
 } # fine if ($num_all)
 } # fine if ($tipo_contratto == "contreml")
 unlock_tabelle($tabelle_lock);
-} # fine if ($elimina_allegato)
+} # fine if (!empty($elimina_allegato))
 
-if ($cambia_formato_email or $cambia_bcc) {
+if (!empty($cambia_formato_email) or !empty($cambia_bcc)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $contratto = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
@@ -632,9 +632,9 @@ echo "".mex("Copie bcc da spedire cambiate",$pag).".<br>";
 } # fine if ($cambia_bcc)
 } # fine if ($tipo_contratto == "contreml")
 unlock_tabelle($tabelle_lock);
-} # fine if ($cambia_formato_email or $cambia_bcc)
+} # fine if (!empty($cambia_formato_email) or !empty($cambia_bcc))
 
-if ($lingua_predef) {
+if (!empty($lingua_predef)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $testo_contr = esegui_query("select testo from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
@@ -645,9 +645,9 @@ esegui_query("update $tablecontratti set testo = '#!mln!#$lingua_contr' where nu
 } # fine if ($lingua_contr == "ita" or...
 } # fine if (substr($testo_contr,0,7) == "#!mln!#")
 unlock_tabelle($tabelle_lock);
-} # fine if ($lingua_predef)
+} # fine if (!empty($lingua_predef))
 
-if ($salva_head) {
+if (!empty($salva_head)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $vecchio_head = esegui_query("select numero from $tablecontratti where numero = '$num_contratto' and tipo = 'headhtm' ");
@@ -659,9 +659,9 @@ esegui_query("update $tablecontratti set testo = '$n_head' where numero = '$num_
 echo "".mex("Intestazione html cambiata",$pag).".<br>";
 } # fine if (numlin_query($vecchio_head))
 unlock_tabelle($tabelle_lock);
-} # fine if ($salva_head)
+} # fine if (!empty($salva_head))
 
-if ($salva_modifiche) {
+if (!empty($salva_modifiche)) {
 $mostra_form_iniziale = "NO";
 $errore = "NO";
 if (@get_magic_quotes_gpc()) $n_contratto = stripslashes($n_contratto);
@@ -741,9 +741,9 @@ echo "".mex("Documento salvato",$pag).".<br>";
 } # fine else if ($errore == "SI")
 } # fine if (numlin_query($vecchio_contr))
 unlock_tabelle($tabelle_lock);
-} # fine if ($salva_modifiche)
+} # fine if (!empty($salva_modifiche))
 
-if ($aggiungi_var or $aggiungi_var2) {
+if (!empty($aggiungi_var) or !empty($aggiungi_var2)) {
 if ($aggiungi_var2) $var_agg = $var_agg2;
 if ($var_agg and preg_replace("/[A-Za-z0-9\(\)_]/","",$var_agg) == "") {
 if (@get_magic_quotes_gpc()) $n_contratto = stripslashes($n_contratto);
@@ -756,9 +756,9 @@ $pos_curs += (2 * substr_count(substr($n_contratto,0,$pos_curs),"–"));
 $testo_contratto_mod = substr($n_contratto,0,$pos_curs)."[".$var_agg."]".substr($n_contratto,$pos_curs);
 } # fine else if (!strcmp($pos_curs,""))
 } # fine if ($var_agg and preg_replace("/[A-Za-z0-9\(\)_]/","",$var_agg) == "")
-} # fine if ($aggiungi_var or $aggiungi_var2)
+} # fine if (!empty($aggiungi_var) or !empty($aggiungi_var2))
 
-if ($aggiungi_ripetizione or $aggiungi_ripetizione2) {
+if (!empty($aggiungi_ripetizione) or !empty($aggiungi_ripetizione2)) {
 if (@get_magic_quotes_gpc()) $n_contratto = stripslashes($n_contratto);
 if ($aggiungi_ripetizione2) $tipo_rip = $tipo_rip2;
 $testo_agg1 = "";
@@ -813,9 +813,9 @@ $pos_fine_sel = strlen(utf8_encode(substr(utf8_decode($n_contratto),0,$pos_fine_
 $testo_contratto_mod = substr($n_contratto,0,$pos_curs).$testo_agg1.substr($n_contratto,$pos_curs,($pos_fine_sel - $pos_curs)).$testo_agg3.substr($n_contratto,$pos_fine_sel);
 } # fine else if (!strcmp($pos_fine_sel,""))
 } # fine else if (!strcmp($pos_curs,""))
-} # fine if ($aggiungi_ripetizione or $aggiungi_ripetizione2)
+} # fine if (!empty($aggiungi_ripetizione) or !empty($aggiungi_ripetizione2))
 
-if ($salva_foot) {
+if (!empty($salva_foot)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $vecchio_foot = esegui_query("select numero from $tablecontratti where numero = '$num_contratto' and tipo = 'foothtm' ");
@@ -827,7 +827,7 @@ esegui_query("update $tablecontratti set testo = '$n_foot' where numero = '$num_
 echo "".mex("Chiusura html cambiata",$pag).".<br>";
 } # fine if (numlin_query($vecchio_foot))
 unlock_tabelle($tabelle_lock);
-} # fine if ($salva_foot)
+} # fine if (!empty($salva_foot))
 
 
 if ($mostra_form_iniziale == "NO") {
@@ -839,17 +839,17 @@ echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag$anchor\">
 </div></form>";
 } # fine if ($mostra_form_iniziale == "NO")
 
-} # fine if ($cambia_qualcosa)
+} # fine if (!empty($cambia_qualcosa))
 
 
 
 
 
-if ($mostra_form_iniziale != "NO") {
+if (!isset($mostra_form_iniziale) or $mostra_form_iniziale != "NO") {
 
 include("./includes/funzioni_contratti.php");
 $nomi_contratti = trova_nomi_contratti($max_contr,$id_utente,$tablecontratti,$tablepersonalizza,$LIKE,$pag);
-if (!strcmp($nomi_contratti['pers'][$num_contratto_int],"")) $nome_contratto = "";
+if (!isset($nomi_contratti['pers'][$num_contratto_int]) or !strcmp($nomi_contratti['pers'][$num_contratto_int],"")) $nome_contratto = "";
 else $nome_contratto = " (".$nomi_contratti['pers'][$num_contratto_int].")";
 
 unset($trad_var);
@@ -877,7 +877,7 @@ if ($max_contr > 1) {
 echo "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"./personalizza.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"id_utente_mod\" value=\"$id_utente_mod\">
+<input type=\"hidden\" name=\"id_utente_mod\" value=\"".htmlspecialchars(fixset($id_utente_mod))."\">
 <input type=\"hidden\" name=\"aggiorna_qualcosa\" value=\"SI\">
 <input type=\"hidden\" name=\"elimina_contratto\" value=\"SI\">
 <input type=\"hidden\" name=\"num_contr_elimina\" value=\"$num_contratto_int\">
@@ -940,6 +940,11 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"cambia_formati_dati\" value=\"1\">
 <table border=0 cellspacing=0 cellpadding=0><tr>
 <td align=\"center\">".mex("Formato dei soldi",$pag).":</td>";
+$check_soldi_ut = "";
+$check_soldi_eu = "";
+$check_soldi_usa = "";
+$check_data_eu = "";
+$check_data_usa = "";
 if ($stile_soldi_contr != "europa" and $stile_soldi_contr != "usa") $check_soldi_ut = " selected";
 if ($stile_soldi_contr == "europa") $check_soldi_eu = " selected";
 if ($stile_soldi_contr == "usa") $check_soldi_usa = " selected";
@@ -1336,6 +1341,7 @@ echo "<table cellspacing=\"0\"><tr><td>
 </div></form></td></tr>";
 $allegati = esegui_query("select * from $tablecontratti where tipo = 'file_all'");
 $num_allegati = numlin_query($allegati);
+$opt_allegati = "";
 for ($num1 = 0 ; $num1 < $num_allegati ; $num1++) {
 $num_all = risul_query($allegati,$num1,'numero');
 $nome_all = explode(",",risul_query($allegati,$num1,'testo'));
@@ -1383,8 +1389,8 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 } # fine ($tipo_contratto == "eml")
 
 
+$lingue = array();
 if ($multilingua) {
-unset($lingue);
 $num_lingue = 0;
 if ($lingua_default != "ita" and (preg_replace("/[a-z]{2,3}/","",$lingua_default) != "" or !@is_file("./includes/lang/$lingua_default/l_n"))) $lingua_default = $lingua_mex;
 $lingue[$num_lingue] = $lingua_default;
@@ -1444,9 +1450,9 @@ else echo "<input class=\"smallsbutton\" type=\"submit\" value=\"".mex("fai pred
 } # fine if ($multilingua)
 
 echo "<table><tr><td style=\"height: 3px;\"></td></tr></table>";
-if ($testo_contratto_mod and (!$multilingua or $lingua_contr == $lingue[$num_lingua])) $testo_contratto = $testo_contratto_mod;
+if (!empty($testo_contratto_mod) and (!$multilingua or $lingua_contr == $lingue[$num_lingua])) $testo_contratto = $testo_contratto_mod;
 echo "<div style=\"text-align: center;\">
-<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#contr_txtbox".$lingue[$num_lingua]."\" onSubmit=\"agg_pos_curs($num_lingua)\"><div>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#contr_txtbox".fixset($lingue[$num_lingua])."\" onSubmit=\"agg_pos_curs($num_lingua)\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">";
@@ -1455,7 +1461,7 @@ echo "<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
 <input type=\"hidden\" name=\"pos_curs\" value=\"\" id=\"pos_curs$num_lingua\">
 <input type=\"hidden\" name=\"pos_fine_sel\" value=\"\" id=\"pos_fine_sel$num_lingua\">
 <table class=\"nomob\" style=\"margin-left: auto; margin-right: auto;\">";
-$linea_mod = "<tr><td><a name=\"contr_txtbox".$lingue[$num_lingua]."\"></a>
+$linea_mod = "<tr><td><a name=\"contr_txtbox".fixset($lingue[$num_lingua])."\"></a>
 ".mex("Variabili",$pag).":
  <select name=\"var_agg\">";
 
@@ -1493,6 +1499,7 @@ $num_var_predef++;
 } # fine for $num1
 $array_pers = esegui_query("select * from $tablecontratti where tipo = 'vett' or tipo = 'vett$num_contr_cond' order by tipo, numero");
 $num_array_pers = numlin_query($array_pers);
+$option_array = "";
 for ($num1 = 0 ; $num1 < $num_array_pers ; $num1++) {
 $arr_pers_vett = explode(";",risul_query($array_pers,$num1,'testo'));
 $arr_pers = $arr_pers_vett[0];
@@ -1616,16 +1623,16 @@ echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"contr_cond\" value=\"$num_int_contr\">
-<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Variabili personalizzate e condizioni del documento",$pag)." $num_contratto\">
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Variabili personalizzate e condizioni del documento",$pag)." $num_contratto\">
 </div></form><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"personalizza.php#contratti\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Torna indietro",$pag)."\">
 </div></form><br></div>";
 
 
-} # fine if ($mostra_form_iniziale != "NO")
+} # fine if (!isset($mostra_form_iniziale) or $mostra_form_iniziale != "NO")
 
 
 
