@@ -148,6 +148,7 @@ for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) $utenti_gruppi[risul_quer
 } # fine if ($id_utente != 1)
 else {
 $anno_utente_attivato = "SI";
+$priv_ins_clienti = "";
 $inserimento_nuovi_clienti = "SI";
 $modifica_clienti = "SI";
 $vedi_clienti = "SI";
@@ -256,8 +257,9 @@ else $app_letto_idpr[$num_idpr] = 0;
 
 
 
-if ($modifica == "SI") {
+if (isset($modifica) and $modifica == "SI") {
 $form_modifica_ospiti = "NO";
+$mess_letto = 0;
 
 
 $continua = 1;
@@ -276,8 +278,8 @@ for ($num_idpr = 0 ; $num_idpr < $num_id_prenota ; $num_idpr++) {
 $id_prenota = $id_prenota_idpr[$num_idpr];
 $idclienti = $idclienti_idpr[$id_prenota];
 $num_persone_tot = $num_persone_tot_idpr[$num_idpr];
-$num_ospiti_inviati = ${"num_ospiti_inviati".$id_prenota};
-$principale = ${"principale".$id_prenota};
+$num_ospiti_inviati = fixset(${"num_ospiti_inviati".$id_prenota});
+$principale = fixset(${"principale".$id_prenota});
 
 if ($num_ospiti_inviati > $num_persone_tot + 30) $num_ospiti_inviati = $num_persone_tot + 30;
 
@@ -287,9 +289,9 @@ $utente_cliente = risul_query($utente_cliente,0,'utente_inserimento');
 if ($id_utente == 1) $id_utente_ins = $utente_cliente;
 else $id_utente_ins = $id_utente;
 
-unset($osp_presente);
-unset($lista_ospiti);
-unset($presente_id);
+$osp_presente = array();
+$lista_ospiti = array('lista' => null);
+$presente_id = array();
 $idclienti_compagni = "";
 $num_ospiti = 0;
 if (${"cliente_ospite".$id_prenota."_".$idclienti} == "SI") {
@@ -322,7 +324,7 @@ else $principale = "";
 unset($n_parentela);
 unset($lista_parentela_cambiata);
 for ($num1 = 1 ; $num1 <= $num_ospiti_inviati ; $num1++) {
-$id_clienti_osp = aggslashdb(${"id_osp_num".$id_prenota."_".$num1});
+$id_clienti_osp = aggslashdb(fixset(${"id_osp_num".$id_prenota."_".$num1}));
 if ($id_clienti_osp and $id_clienti_osp != $principale) {
 if ($osp_presente[$id_clienti_osp]) {
 $dati_ospite = esegui_query("select idclienti_compagni from $tableclienti where idclienti = '$id_clienti_osp' ");
@@ -403,12 +405,12 @@ $idclienti_compagni = explode(",",substr($idclienti_compagni,0,-1));
 $num_idclienti_compagni = count($idclienti_compagni);
 for ($num1 = 0 ; $num1 < $num_idclienti_compagni ; $num1++) {
 $id_clienti_osp = $idclienti_compagni[$num1];
-if (${"altro_ospite".$id_prenota."_".$id_clienti_osp} == "SI" and $presente_id[$id_clienti_osp] != "SI") {
+if (isset(${"altro_ospite".$id_prenota."_".$id_clienti_osp}) and ${"altro_ospite".$id_prenota."_".$id_clienti_osp} == "SI" and (!isset($presente_id[$id_clienti_osp]) or $presente_id[$id_clienti_osp] != "SI")) {
 $num_ospiti++;
 $lista_ospiti[$num_ospiti] = $id_clienti_osp;
 $lista_ospiti['lista'] .= $id_clienti_osp.",";
 $presente_id[$id_clienti_osp] = "SI";
-} # fine if (${"altro_ospite".$id_prenota."_".$id_clienti_osp} == "SI" and...
+} # fine if (isset(${"altro_ospite".$id_prenota."_".$id_clienti_osp}) and ${"altro_ospite".$id_prenota."_".$id_clienti_osp} == "SI" and...
 } # fine for $num1
 
 $max_num_ordine = 2;
@@ -461,12 +463,12 @@ echo " ".mex("sono stati modificati",$pag).".<br><br>
 } # fine if ($continua)
 
 
-} # fine if ($modifica == "SI")
+} # fine if (isset($modifica) and $modifica == "SI")
 
 
 
 
-if ($form_modifica_ospiti != "NO") {
+if (!isset($form_modifica_ospiti) or $form_modifica_ospiti != "NO") {
 
 # Form per modificare gli ospiti.
 if ($num_id_prenota == 1) echo "<h3 id=\"h_mgst\"><span>".mex("Modifica gli ospiti della prenotazione",$pag)." $id_prenota</span></h3><br>";
@@ -478,8 +480,8 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_ospiti.ph
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"id_prenota\" value=\"$id_prenota_int\">
 <input type=\"hidden\" name=\"modifica\" value=\"SI\">
-<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
-<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">";
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars(fixset($tipo_tabella))."\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixset($origine))."\">";
 
 if ($inserimento_nuovi_clienti == "SI") {
 mostra_funzjs_cpval();
@@ -508,19 +510,18 @@ if ($dregionenascita) $regione_def = $dregionenascita;
 elseif ($dregione) $regione_def = $dregione;
 elseif ($dregionedoc) $regione_def = $dregionedoc;
 elseif ($dregionenascita) $regione_def = $dregionenascita;
-$regione_def = addslashes($regione_def);
+$regione_def = addslashes(fixset($regione_def));
 if ($dcittanascita) $citta_def = $dcittanascita;
 elseif ($dcitta) $citta_def = $dcitta;
 elseif ($dcittadoc) $citta_def = $dcittadoc;
 elseif ($dcittanascita) $citta_def = $dcittanascita;
-$citta_def = addslashes($citta_def);
+$citta_def = addslashes(fixset($citta_def));
 
 $ospiti = esegui_query("select * from $tablerclientiprenota where idprenota = '$id_prenota' order by num_ordine ");
 $num_ospiti = numlin_query($ospiti);
 $mostra_osp = "SI";
 $agg_num = 1;
-unset($presente_id);
-$presente_id[$idclienti] = "SI";
+$presente_id = array($idclienti => "SI");
 $idclienti_compagni = "";
 for ($num1 = 0 ; $num1 < $num_ospiti ; $num1++) {
 $id_clienti_osp = risul_query($ospiti,$num1,'idclienti');
@@ -730,7 +731,7 @@ echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <button class=\"gobk\" id=\"indi\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form></div><br>";
 
-} # fine if ($form_modifica_ospiti != "NO")
+} # fine if (!isset($form_modifica_ospiti) or $form_modifica_ospiti != "NO")
 
 
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/foot.php");
