@@ -90,7 +90,14 @@ $var_pag[62] = 'solo_contr_cond';
 $var_pag[63] = 'nuovo_arr_pers';
 $var_pag[64] = 'aggiungi_arr_pers';
 $var_pag[65] = 'var_arr';
-$n_var_pag = 66;
+$var_pag[66] = 'elimina_var_pers';
+$var_pag[67] = 'var_se2';
+$var_pag[68] = 'cond2';
+$var_pag[69] = 'sposta_su';
+$var_pag[70] = 'num_cond';
+$var_pag[71] = 'salta_a';
+$var_pag[72] = 'sposta_giu';
+$n_var_pag = 73;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -151,7 +158,7 @@ $stile_soldi = stile_soldi();
 $stile_data = stile_data();
 
 
-if (controlla_num_pos($contr_cond) == "NO" or $contr_cond < 1) $contr_cond = "";
+if (!isset($contr_cond) or controlla_num_pos($contr_cond) == "NO" or $contr_cond < 1) $contr_cond = "";
 if ($attiva_contratti_consentiti != "n" and $contratti_consentiti_vett[$contr_cond] != "SI") $contr_cond = "";
 if (strcmp($contr_cond,"")) {
 $contr_cond_esist = esegui_query("select numero from $tablecontratti where numero = '".aggslashdb($contr_cond)."' and tipo $LIKE 'contr%' ");
@@ -162,25 +169,30 @@ if (numlin_query($api_esistente)) $contr_cond = "";
 } # fine elseif ($priv_mod_doc_api != "s")
 } # fine if (strcmp($contr_cond,""))
 
-unset($trad_var);
+$trad_var = array();
 function mex2 ($messaggio) {
 global $trad_var,$lingua_mex;
-if (!$trad_var and $lingua_mex != "ita") include("./includes/lang/$lingua_mex/visualizza_contratto_var.php");
+if (empty($trad_var)) {
+if ($lingua_mex != "ita") include("./includes/lang/$lingua_mex/visualizza_contratto_var.php");
+if (empty($trad_var['commento_personalizzato'])) $trad_var['commento_personalizzato'] = 'commento_personalizzato';
+if (empty($trad_var['campo_personalizzato'])) $trad_var['campo_personalizzato'] = 'campo_personalizzato';
+if (empty($trad_var['num_persone_tipo'])) $trad_var['num_persone_tipo'] = 'num_persone_tipo';
+} # fine if (empty($trad_var))
 if (!empty($trad_var[$messaggio])) $messaggio = $trad_var[$messaggio];
 else {
 if (substr($messaggio,-1) == ")") {
 $mess_vett = explode("(",substr($messaggio,0,-1));
 if (!empty($trad_var[$mess_vett[1]])) $messaggio = $mess_vett[0]."(".$trad_var[$mess_vett[1]].")";
 else {
-if (substr($mess_vett[1],0,24) == "commento_personalizzato_") $messaggio =  $mess_vett[0]."(".$trad_var["commento_personalizzato"].substr($mess_vett[1],23).")";
-elseif (substr($mess_vett[1],0,21) == "campo_personalizzato_") $messaggio =  $mess_vett[0]."(".$trad_var["campo_personalizzato"].substr($mess_vett[1],20).")";
+if (substr($mess_vett[1],0,24) == "commento_personalizzato_") $messaggio =  $mess_vett[0]."(".$trad_var['commento_personalizzato'].substr($mess_vett[1],23).")";
+elseif (substr($mess_vett[1],0,21) == "campo_personalizzato_") $messaggio =  $mess_vett[0]."(".$trad_var['campo_personalizzato'].substr($mess_vett[1],20).")";
 } # fine else if (!empty($trad_var[$mess_vett[1]]))
 } # fine if (substr($messaggio,-1) == ")")
 else {
-if (substr($messaggio,0,24) == "commento_personalizzato_") $messaggio = $trad_var["commento_personalizzato"].substr($messaggio,23);
+if (substr($messaggio,0,24) == "commento_personalizzato_") $messaggio = $trad_var['commento_personalizzato'].substr($messaggio,23);
 else {
-if (substr($messaggio,0,21) == "campo_personalizzato_") $messaggio = $trad_var["campo_personalizzato"].substr($messaggio,20);
-elseif (substr($messaggio,0,17) == "num_persone_tipo_") $messaggio = $trad_var["num_persone_tipo"].substr($messaggio,16);
+if (substr($messaggio,0,21) == "campo_personalizzato_") $messaggio = $trad_var['campo_personalizzato'].substr($messaggio,20);
+elseif (substr($messaggio,0,17) == "num_persone_tipo_") $messaggio = $trad_var['num_persone_tipo'].substr($messaggio,16);
 } # fine else if (substr($messaggio,0,24) == "commento_personalizzato_")
 } # fine else if (substr($messaggio,-1) == ")")
 } # fine else if ($trad_var[$messaggio])
@@ -279,7 +291,7 @@ return $continua;
 } # fine function elimina_arr_pers
 
 
-if ($aggiungi_var_pers) {
+if (!empty($aggiungi_var_pers)) {
 $mostra_form_iniziale = "NO";
 $continua = "SI";
 if (@get_magic_quotes_gpc()) $nuova_var_pers = stripslashes($nuova_var_pers);
@@ -290,7 +302,7 @@ if (preg_replace("/[A-Za-z0-9_]/","",$nuova_var_pers) != "") $continua = "NO";
 $ultima_parte = explode("_",$nuova_var_pers);
 $ultima_parte = (string) $ultima_parte[(count($ultima_parte) - 1)];
 if ($ultima_parte != "" and preg_replace("/[0-9]/","",$ultima_parte) == "") $continua = "NO";
-if ($var_riserv[$nuova_var_pers] or substr($nuova_var_pers,0,20) == "campo_personalizzato" or substr($nuova_var_pers,0,23) == "commento_personalizzato" or substr($nuova_var_pers,0,16) == "num_persone_tipo") $continua = "NO";
+if (!empty($var_riserv[$nuova_var_pers]) or substr($nuova_var_pers,0,20) == "campo_personalizzato" or substr($nuova_var_pers,0,23) == "commento_personalizzato" or substr($nuova_var_pers,0,16) == "num_persone_tipo") $continua = "NO";
 if ($continua == "SI") {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
@@ -324,10 +336,10 @@ echo mex("Nuova variabile personalizzata inserita",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
 } # fine if ($continua == "SI")
 if ($continua != "SI") echo mex("I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>",$pag).".<br>";
-} # fine if ($aggiungi_var_pers)
+} # fine if (!empty($aggiungi_var_pers))
 
 
-if ($elimina_var_pers) {
+if (!empty($elimina_var_pers)) {
 $mostra_form_iniziale = "NO";
 $var_pers_elimina = aggslashdb($var_pers_elimina);
 $continua = "SI";
@@ -386,10 +398,10 @@ echo mex("Variabile personalizzata eliminata",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
 } # fine if ($continua == "SI")
 if ($continua != "SI") echo mex("I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>",$pag).".<br>";
-} # fine if ($elimina_var_pers)
+} # fine if (!empty($elimina_var_pers))
 
 
-if ($aggiungi_arr_pers) {
+if (!empty($aggiungi_arr_pers)) {
 $mostra_form_iniziale = "NO";
 $continua = "SI";
 if (@get_magic_quotes_gpc()) $nuovo_arr_pers = stripslashes($nuovo_arr_pers);
@@ -473,20 +485,20 @@ echo mex("Nuovo array personalizzato inserito",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
 } # fine if ($continua == "SI")
 if ($continua != "SI") echo mex("I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>",$pag).".<br>";
-} # fine if ($aggiungi_arr_pers)
+} # fine if (!empty($aggiungi_arr_pers))
 
 
-if ($elimina_arr_pers) {
+if (!empty($elimina_arr_pers)) {
 $mostra_form_iniziale = "NO";
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $continua = elimina_array_pers($arr_pers_elimina);
 unlock_tabelle($tabelle_lock);
 if ($continua != "SI") echo mex("I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>",$pag).".<br>";
-} # fine if ($elimina_arr_pers)
+} # fine if (!empty($elimina_arr_pers))
 
 
-if ($mod_contr_importa and $contr_cond) {
+if (!empty($mod_contr_importa) and !empty($contr_cond)) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 if ($contr_imp) {
@@ -525,10 +537,10 @@ esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_imp'
 } # fine if ($contr_imp)
 else esegui_query("delete from $tablecontratti where numero = '$contr_cond' and tipo = 'impor_vc' ");
 unlock_tabelle($tabelle_lock);
-} # fine if ($mod_contr_importa and $contr_cond)
+} # fine if (!empty($mod_contr_importa) and !empty($contr_cond))
 
 
-if ($aggiungi_cond) {
+if (!empty($aggiungi_cond)) {
 $mostra_form_iniziale = "NO";
 $continua = "SI";
 if (substr($inizializza,0,1) == "a") {
@@ -538,7 +550,7 @@ $arr_esistente = esegui_query("select * from $tablecontratti where (tipo = 'vett
 if (numlin_query($arr_esistente) != 1) $continua = "NO";
 } # fine if (substr($inizializza,0,1) == "a")
 if ($inizializza != "rpt" and $inizializza != "inr" and $inizializza != "ind" and $inizializza != "ros" and $inizializza != "rca" and $inizializza != "rpa" and $inizializza != "run" and $inizializza != "rds" and preg_replace("/rar[1-9][0-9]*/","",$inizializza) != "") $continua = "NO";
-if (strcmp($cond_sempre,"") and $cond_sempre != "SI" and $cond_sempre != "NO") $continua = "NO";
+if (isset($cond_sempre) and strcmp($cond_sempre,"") and $cond_sempre != "SI" and $cond_sempre != "NO") $continua = "NO";
 if ($azione != "set" and $azione != "trunc" and $azione != "oper" and $azione != "date" and $azione != "unset" and $azione != "array" and $azione != "break" and $azione != "cont") $continua = "NO";
 if ($oper_data and $azione = "date") $azione = "opdat";
 if ($num_se < 1 or $num_se > 80) $continua = "NO";
@@ -589,7 +601,7 @@ if ($num_cond_mod) {
 $cond_esist = @esegui_query("select numero from $tablecontratti where numero = '".aggslashdb($num_cond_mod)."' and tipo = 'cond$contr_cond' ");
 if (!numlin_query($cond_esist)) $continua = "NO";
 } # fine if ($num_cond_mod)
-if ($cond_sempre != "SI") {
+if (!isset($cond_sempre) or $cond_sempre != "SI") {
 if ($num_se > 1) $testo .= $and_or;
 for ($num1 = 1 ; $num1 <= $num_se ; $num1++) {
 controlla_var_se(${"var_se".$num1},$continua,$var_predef,$num_var_predef,$contr_cond);
@@ -603,7 +615,7 @@ if (${"tipo_val_se".$num1} == "txt") $val_se = controlla_testo_input(${"val_se_t
 else $val_se = controlla_var_se(${"val_se_sel".$num1},$continua,$var_predef,$num_var_predef,$contr_cond);
 $testo .= "#$?".${"var_se".$num1}."#%?".${"cond".$num1}."#%?".${"tipo_val_se".$num1}."#%?$val_se";
 } # fine for $num1
-} # fine if ($cond_sempre != "SI")
+} # fine if (!isset($cond_sempre) or $cond_sempre != "SI")
 $testo .= "#@?";
 if ($azione == "set") {
 if ($oper_str != "=" and $oper_str != ".=") $continua = "NO";
@@ -711,10 +723,10 @@ else echo ucfirst(mex("condizione modificata",$pag)).".<br>";
 unlock_tabelle($tabelle_lock);
 } # fine if ($continua == "SI")
 if ($continua != "SI") echo mex("I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>",$pag).".<br>";
-} # fine if ($aggiungi_cond)
+} # fine if (!empty($aggiungi_cond))
 
 
-if ($elimina_cond) {
+if (!empty($elimina_cond)) {
 $mostra_form_iniziale = "NO";
 $continua = "SI";
 if (controlla_num_pos($num_cond) == "NO") $continua = "NO";
@@ -726,7 +738,7 @@ echo mex("Condizione eliminata",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
 } # fine if ($continua == "SI")
 if ($continua != "SI") echo mex("I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>",$pag).".<br>";
-} # fine if ($elimina_cond)
+} # fine if (!empty($elimina_cond))
 
 
 if ($mostra_form_iniziale == "NO") {
@@ -750,7 +762,7 @@ $condizioni = esegui_query("select * from $tablecontratti where tipo = 'cond$con
 $num_condizioni = numlin_query($condizioni);
 $errore = 0;
 if ($num_cond == $salta_a) $errore = 1;
-if (!$sposta_giu and !$sposta_su) $errore = 1;
+if (!empty($sposta_giu) and !empty($sposta_su)) $errore = 1;
 unset($cond_vett);
 $num_cond_trovato = 0;
 $salta_a_trovato = 0;
@@ -769,25 +781,25 @@ $pos_salta_a = $num1;
 if (!$tipo_cond) $tipo_cond = substr(risul_query($condizioni,$num1,'testo'),0,3);
 elseif ($tipo_cond != substr(risul_query($condizioni,$num1,'testo'),0,3)) $errore = 1;
 } # fine if ($cond_vett[$num1] == $salta_a)
-if ($sposta_giu and !$num_cond_trovato and $salta_a_trovato) $errore = 1;
-if ($sposta_su and $num_cond_trovato and !$salta_a_trovato) $errore = 1;
+if (!empty($sposta_giu) and !$num_cond_trovato and $salta_a_trovato) $errore = 1;
+if (!empty($sposta_su) and $num_cond_trovato and !$salta_a_trovato) $errore = 1;
 } # fine for $num1
 if (!$num_cond_trovato or !$salta_a_trovato) $errore = 1;
 if (!$errore) {
 esegui_query("update $tablecontratti set numero = '-1' where numero = '$num_cond' and tipo = 'cond$contr_cond' ");
 $ultima_cond = $num_cond;
-if ($sposta_giu) {
+if (!empty($sposta_giu)) {
 for ($num1 = ($pos_num_cond + 1) ; $num1 <= $pos_salta_a ; $num1++) {
 esegui_query("update $tablecontratti set numero = '$ultima_cond' where numero = '".$cond_vett[$num1]."' and tipo = 'cond$contr_cond' ");
 $ultima_cond = $cond_vett[$num1];
 } # fine for $num1
-} # fine if ($sposta_giu)
-if ($sposta_su) {
+} # fine if (!empty($sposta_giu))
+if (!empty($sposta_su)) {
 for ($num1 = ($pos_num_cond - 1) ; $num1 >= $pos_salta_a ; $num1--) {
 esegui_query("update $tablecontratti set numero = '$ultima_cond' where numero = '".$cond_vett[$num1]."' and tipo = 'cond$contr_cond' ");
 $ultima_cond = $cond_vett[$num1];
 } # fine for $num1
-} # fine if ($sposta_su)
+} # fine if (!empty($sposta_su))
 esegui_query("update $tablecontratti set numero = '$salta_a' where numero = '-1' and tipo = 'cond$contr_cond' ");
 } # fine if (!$errore)
 unlock_tabelle($tabelle_lock);
@@ -1828,14 +1840,14 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./modifica_contrat
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"num_contratto\" value=\"$contr_cond\">
-<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Modifica il documento",$pag)." $contr_cond\">
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Modifica il documento",$pag)." $contr_cond\">
 </div></form><br>";
 } # fine if ($contr_cond)
 
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"personalizza.php#contratti\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Torna indietro",$pag)."\">
 </div></form><br></div>";
 
 
