@@ -35,7 +35,28 @@ $var_pag[6] = 'incassa';
 $var_pag[7] = 'valuta_pagamento_sel';
 $var_pag[8] = 'metodo_pagamento_sel';
 $var_pag[9] = 'id_cassa_sel';
-$n_var_pag = 10;
+$var_pag[10] = 'num_costi_passa';
+$var_pag[11] = 'ini_periodo_passa';
+$var_pag[12] = 'fine_periodo_passa';
+$var_pag[13] = 'aggiungi';
+$var_pag[14] = 'sottrai';
+$n_var_pag = 15;
+$num2 = 0;
+if (isset($_POST['num_costi_passa'])) $num2 = (int) $_POST['num_costi_passa'];
+elseif (isset($_GET['num_costi_passa'])) $num2 = (int) $_GET['num_costi_passa'];
+$num6 = 0;
+if (isset($_POST['ini_periodo_passa'])) $num6 = (int) $_POST['ini_periodo_passa'];
+elseif (isset($_GET['ini_periodo_passa'])) $num6 = (int) $_GET['ini_periodo_passa'];
+$num7 = 0;
+if (isset($_POST['fine_periodo_passa'])) $num7 = (int) $_POST['fine_periodo_passa'];
+elseif (isset($_GET['fine_periodo_passa'])) $num7 = (int) $_GET['fine_periodo_passa'];
+for ($num1 = 0 ; $num1 < $num2 ; $num1++) {
+$var_pag[$n_var_pag++] = "id_periodi_costo$num1";
+$num3 = "";
+if (isset($_POST["id_periodi_costo$num1"])) $num3 = $_POST["id_periodi_costo$num1"];
+elseif (isset($_GET["id_periodi_costo$num1"])) $num3 = $_GET["id_periodi_costo$num1"];
+if ($num3 == "inserire") for ($num5 = $num6 ; $num5 <= $num7 ; $num5++) $var_pag[$n_var_pag++] = "sett$num5"."costo$num1";
+} # fine for $num1
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -359,7 +380,7 @@ $errore_cassa = 0;
 $errore_prenota = 0;
 unset($errori_costi);
 $errori_costi[-1] = 0;
-unset($val_costo);
+$val_costo = array(-1 => 0);
 unset($settimane_costo);
 unset($n_moltiplica_costo);
 unset($moltiplica_costo);
@@ -390,6 +411,7 @@ if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$id_costo]
 
 $molt_costo_orig = $molt_costo;
 if (!$molt_costo) $molt_costo = 1;
+$errori_costi[$num_costo] = "";
 
 if ($id_prenota) {
 if (str_replace(",$app_prenota,","",",".$dati_ca[$numca]['appincompatibili'].",") != ",".$dati_ca[$numca]['appincompatibili'].",") {
@@ -412,17 +434,18 @@ $id_periodi_costo = "id_periodi_costo".$num_costo;
 if (isset($$id_periodi_costo) and $$id_periodi_costo == "inserire") {
 $$id_periodi_costo = "";
 for ($num2 = $idinizioperiodo; $num2 <= $idfineperiodo; $num2++) {
-if (${"sett".$num2."costo".$num_costo} == "SI") $$id_periodi_costo .= ",".$num2;
+if (isset(${"sett".$num2."costo".$num_costo}) and ${"sett".$num2."costo".$num_costo} == "SI") $$id_periodi_costo .= ",".$num2;
 } # fine for $num2
 if ($$id_periodi_costo) $$id_periodi_costo .= ",";
 else $$id_periodi_costo = "nessuno";
 } # fine if (isset($$id_periodi_costo) and $$id_periodi_costo == "inserire")
-if ($dati_ca[$numca]['numsett'] == "c" and $dati_ca[$numca]['associasett'] == "s" and !$$id_periodi_costo) {
+if ($dati_ca[$numca]['numsett'] == "c" and $dati_ca[$numca]['associasett'] == "s" and empty($$id_periodi_costo)) {
 echo "<hr style=\"width: 30%; margin-left: 0; text-align: left;\">
-".mex("Scegliere $parola_le $parola_settimane in cui applicare il costo aggiuntivo",$pag)." ".$dati_ca[$numca]['nome']."$per_la_prenotazione:<br>
+".mex("Scegliere $parola_le $parola_settimane in cui applicare il costo aggiuntivo",$pag)." ".$dati_ca[$numca]['nome'].":<br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"punto_vendita.php#finetab\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_costi_passa\" value=\"$num_costi\">
 <table style=\"text-align: center;\">";
 for ($num2 = $idinizioperiodo; $num2 <= $idfineperiodo; $num2++) {
 $periodo_costo_trovato = "NO";
@@ -442,8 +465,10 @@ echo "<tr><td style=\"height: 50px; width: 30px\">
 } # fine for $num2
 echo "</table>";
 $$id_periodi_costo = "inserire";
-for ($numca2 = 0 ; $numca2 <= $num_costo ; $numca2++) if (${"id_periodi_costo".$numca2}) echo "<input type=\"hidden\" name=\"id_periodi_costo$numca2\" value=\"".${"id_periodi_costo".$numca2}."\">";
-echo "<input type=\"hidden\" name=\"id_costi\" value=\"$id_costi_orig\">
+for ($numca2 = 0 ; $numca2 <= $num_costo ; $numca2++) if (!empty(${"id_periodi_costo".$numca2})) echo "<input type=\"hidden\" name=\"id_periodi_costo$numca2\" value=\"".${"id_periodi_costo".$numca2}."\">";
+echo "<input type=\"hidden\" name=\"ini_periodo_passa\" value=\"$idinizioperiodo\">
+<input type=\"hidden\" name=\"fine_periodo_passa\" value=\"$idfineperiodo\">
+<input type=\"hidden\" name=\"id_costi\" value=\"$id_costi_orig\">
 <input type=\"hidden\" name=\"id_prenota\" value=\"$id_prenota\">
 <input type=\"hidden\" name=\"categoria\" value=\"".htmlspecialchars($categoria)."\">
 <button class=\"pos\" type=\"submit\" style=\"height: 60px; width: 140px; margin: 2px;\"><b>".mex("Continua",$pag)."</b></button>
@@ -1070,6 +1095,7 @@ if (!empty($no_categoria)) $categoria = "";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"punto_vendita.php#finetab\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_costi_passa\" value=\"$num_costi\">
 <input type=\"hidden\" id=\"id_costi\" name=\"id_costi\" value=\"$id_costi\">
 <input type=\"hidden\" name=\"id_prenota\" value=\"$id_prenota\">
 <input type=\"hidden\" id=\"nomecat\" name=\"categoria\" value=\"".htmlspecialchars(fixset($categoria))."\">";
