@@ -116,12 +116,12 @@ $stile_soldi = stile_soldi();
 $stile_data = stile_data();
 $Euro = nome_valuta();
 
-if ($senza_colori) $senza_colori = "SI";
-if ($pagina_prenota and controlla_num_pos($pagina_prenota) != "SI") $pagina_prenota = "";
+if (!empty($senza_colori)) $senza_colori = "SI";
+if (!empty($pagina_prenota) and controlla_num_pos($pagina_prenota) != "SI") $pagina_prenota = "";
 
 
-if ($azzera_soldi == "SI" and $id_utente == 1) {
-if (!$continua) {
+if (isset($azzera_soldi) and $azzera_soldi == "SI" and $id_utente == 1) {
+if (empty($continua)) {
 $mostra_tabella = "NO";
 $tabelle_lock = array("$tableversioni","$tabletransazioni");
 $altre_tab_lock = array("$tablepersonalizza");
@@ -154,7 +154,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"storia_soldi.php\"
 <input type=\"hidden\" name=\"senza_colori\" value=\"$senza_colori\">
 <button class=\"gobk\" type=\"submit\"><div>".mex("NO",$pag)."</div></button>
 </div></form></tr></td></table>";
-} # fine if (!$continua)
+} # fine if (empty($continua))
 else {
 $tabelle_lock = array($tablecosti,$tablesoldi,$tabletransazioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
@@ -165,16 +165,17 @@ esegui_query("update $tablecosti set val_costo = '0' where idcosti = '0'");
 esegui_query("delete from $tabletransazioni where idtransazioni = '".aggslashdb($id_transazione)."' and idsessione = '".aggslashdb($id_sessione)."' and tipo_transazione = 'can_s'");
 } # fine if (numlin_query($transazione_presente) == 1)
 unlock_tabelle($tabelle_lock);
-} # fine else if (!$continua)
-} # fine if ($azzera_soldi == "SI" and $id_utente == 1)
+} # fine else if (empty($continua))
+} # fine if (isset($azzera_soldi) and $azzera_soldi == "SI" and $id_utente == 1)
 
 
 
-if ($mostra_tabella != "NO") {
+if (!isset($mostra_tabella) or $mostra_tabella != "NO") {
 
 
-unset($periodo_query);
-unset($cond_metodo);
+$periodo_query = "";
+$cond_metodo = "";
+$frase_periodo = "";
 if (!isset($cerca_prenota)) $cerca_prenota = null;
 if ($priv_mod_prenota_iniziate != "s") $id_periodo_corrente = calcola_id_periodo_corrente($anno);
 
@@ -183,8 +184,8 @@ echo "<table class=\"buttonbar\"><tr><td align=\"left\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"storia_soldi.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"senza_colori\" value=\"$senza_colori\">
-<input type=\"hidden\" name=\"metodo_selezionato\" value=\"".htmlspecialchars($metodo_selezionato)."\">
+<input type=\"hidden\" name=\"senza_colori\" value=\"".htmlspecialchars(fixset($senza_colori))."\">
+<input type=\"hidden\" name=\"metodo_selezionato\" value=\"".htmlspecialchars(fixset($metodo_selezionato))."\">
 <input class=\"sbutton\" type=\"submit\" name=\"cerca_prenota\" value=\"".mex("Vedi le modifiche",$pag)."\">
  ".mex("dal",$pag)." <select name=\"cerca_inizioperiodo\">
 <option value=\"\">----</option>";
@@ -240,8 +241,8 @@ echo "<td align=\"right\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"storia_soldi.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"pagina_prenota\" value=\"$pagina_prenota\">
-<input type=\"hidden\" name=\"metodo_selezionato\" value=\"".htmlspecialchars($metodo_selezionato)."\">";
+<input type=\"hidden\" name=\"pagina_prenota\" value=\"".htmlspecialchars(fixset($pagina_prenota))."\">
+<input type=\"hidden\" name=\"metodo_selezionato\" value=\"".htmlspecialchars(fixset($metodo_selezionato))."\">";
 if (!$senza_colori) {
 echo "<input type=\"hidden\" name=\"senza_colori\" value=\"SI\">
 <input class=\"sbutton\" type=\"submit\" name=\"cambia_colori\" value=\"".mex("Senza colori",$pag)."\">";
@@ -523,7 +524,7 @@ $stringa_pagine
 </div></form><table><tr><td style=\"height: 20px;\"></td></tr></table>";
 
 
-} # fine if ($mostra_tabella != "NO")
+} # fine if (!isset($mostra_tabella) or $mostra_tabella != "NO")
 
 
 
