@@ -39,7 +39,8 @@ $var_pag[11] = 'origine';
 $var_pag[12] = 'solo_sel';
 $var_pag[13] = 'numtariffa1';
 $var_pag[14] = 'tariffa_sel1';
-$n_var_pag = 15;
+$var_pag[15] = 'cambia_mostra_tab';
+$n_var_pag = 16;
 $num2 = 0;
 if (isset($_POST['num_tariffe_mostra'])) $num2 = (int) $_POST['num_tariffe_mostra'];
 elseif (isset($_GET['num_tariffe_mostra'])) $num2 = (int) $_GET['num_tariffe_mostra'];
@@ -69,6 +70,8 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 if ($id_utente) {
+$tariffe_consentite_vett = array();
+$costi_agg_consentiti_vett = array();
 
 if ($id_utente != 1) {
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
@@ -96,14 +99,12 @@ $tariffe_consentite = risul_query($privilegi_annuali_utente,0,'tariffe_consentit
 $attiva_tariffe_consentite = substr($tariffe_consentite,0,1);
 if ($attiva_tariffe_consentite == "s") {
 $tariffe_consentite = explode(",",substr($tariffe_consentite,2));
-unset($tariffe_consentite_vett);
 for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
 } # fine if ($attiva_tariffe_consentite == "s")
 $costi_agg_consentiti = risul_query($privilegi_annuali_utente,0,'costi_agg_consentiti');
 $attiva_costi_agg_consentiti = substr($costi_agg_consentiti,0,1);
 if ($attiva_costi_agg_consentiti == "s") {
 $costi_agg_consentiti = explode(",",substr($costi_agg_consentiti,2));
-unset($costi_agg_consentiti_vett);
 for ($num1 = 0 ; $num1 < count($costi_agg_consentiti) ; $num1++) if ($costi_agg_consentiti[$num1]) $costi_agg_consentiti_vett[$costi_agg_consentiti[$num1]] = "SI";
 } # fine if ($attiva_costi_agg_consentiti == "s")
 $priv_ins_tariffe = risul_query($privilegi_annuali_utente,0,'priv_ins_tariffe');
@@ -258,7 +259,7 @@ dati_regole2($dati_r2,$app_regola2_predef,"","","",$id_periodo_corrente,$tipo_pe
 unlock_tabelle($tabelle_lock);
 
 $numero_tariffe = $dati_tariffe['num'];
-if (!$num_tariffe_mostra or controlla_num_pos($num_tariffe_mostra) != "SI") $num_tariffe_mostra = 1;
+if (empty($num_tariffe_mostra) or controlla_num_pos($num_tariffe_mostra) != "SI") $num_tariffe_mostra = 1;
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if (${"numtariffa".$num1} < 1 or ${"numtariffa".$num1} > $numero_tariffe or controlla_num_pos(${"numtariffa".$num1}) != "SI") {
 if ($num1 == 1) ${"numtariffa".$num1} = 1;
@@ -273,7 +274,7 @@ $costi_agg_consentiti_vett_ut = $costi_agg_consentiti_vett;
 if ($priv_vedi_tab_periodi == "g") {
 $priv_vedi_tab_periodi = "p";
 foreach ($attiva_tariffe_consentite_gr as $val) if ($val == "n") $attiva_tariffe_consentite = "n";
-unset($tariffe_consentite_vett);
+$tariffe_consentite_vett = array();
 foreach ($tariffe_consentite_vett_gr as $idut_gr => $val) {
 if (is_array($val)) {
 $tar_cons_vett_tmp = $val;
@@ -286,7 +287,7 @@ $costi_agg_consentiti_vett = $costi_agg_consentiti_vett_gr;
 
 
 
-if ($azione) {
+if (!empty($azione)) {
 $mostra_tab_tariffe = "NO";
 
 
@@ -402,31 +403,31 @@ echo "<br><div style=\"text-align: center;\">
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form></div>";
 
-} # fine if ($azione)
+} # fine if (!empty($azione))
 
 
 
-if ($mostra_tab_tariffe != "NO") {
+if (!isset($mostra_tab_tariffe) or $mostra_tab_tariffe != "NO") {
 
-if ($cambia_mostra_tab) {
-if ($mostra_disp != "s") $mostra_disp = "n";
-if ($mostra_pmm != "s") $mostra_pmm = "n";
-if ($raggruppa_date != "s") $raggruppa_date = "n";
-} # fine if ($cambia_mostra_tab)
-if ($mostra_disp != "n") $mostra_disp = "s";
-if ($mostra_pmm != "n") $mostra_pmm = "s";
-if ($raggruppa_date != "n") $raggruppa_date = "s";
+if (!empty($cambia_mostra_tab)) {
+if (!isset($mostra_disp) or $mostra_disp != "s") $mostra_disp = "n";
+if (!isset($mostra_pmm) or $mostra_pmm != "s") $mostra_pmm = "n";
+if (!isset($raggruppa_date) or $raggruppa_date != "s") $raggruppa_date = "n";
+} # fine if (!empty($cambia_mostra_tab))
+if (!isset($mostra_disp) or $mostra_disp != "n") $mostra_disp = "s";
+if (!isset($mostra_pmm) or $mostra_pmm != "n") $mostra_pmm = "s";
+if (!isset($raggruppa_date) or $raggruppa_date != "n") $raggruppa_date = "s";
 
 include(C_DATI_PATH."/selperiodimenu$anno.$id_utente.php");
 $raggr_per = 0;
 $date_menu = array();
 for ($num1 = 0 ; $num1 <  count($d_increment) ; $num1++) if ($d_increment[$num1] != 1) $raggr_per = 1;
-if ($raggr_per = 1 and $mos_per_sing != "SI") {
+if ($raggr_per = 1 and (!isset($mos_per_sing) or $mos_per_sing != "SI")) {
 $datafine_periodi = explode("<option value=\"",$dates_options_list);
 $num_dp = count($datafine_periodi);
 for ($num1 = 1 ; $num1 < $num_dp ; $num1++) $date_menu[substr($datafine_periodi[$num1],0,10)] = 1;
 $datafine_periodi = substr($datafine_periodi[($num_dp - 1)],0,10);
-} # fine if ($raggr_per = 1 and $mos_per_sing != "SI")
+} # fine if ($raggr_per = 1 and (!isset($mos_per_sing) or $mos_per_sing != "SI"))
 else $datafine_periodi = "1970-01-01";
 $max_periodo = risul_query($periodi,(numlin_query($periodi) - 1),'idperiodi');
 
@@ -491,7 +492,7 @@ else $nometariffa_vedi[$num1] = $nometariffa[$num1];
 } # fine else if (!strcmp($nometariffa[$num1],""))
 $nome_tariffa[${"numtariffa".$num1}] = $tariffa[$num1];
 if (($priv_vedi_tab_periodi == "s" and $priv_vedi_tab_regole == "s" and $priv_vedi_tab_mesi == "s") or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI") {
-if (!$dati_r2[$tariffa[$num1]]) $app_regola2_orig[${"numtariffa".$num1}] = substr($dati_app['lista'],1,-1);
+if (empty($dati_r2[$tariffa[$num1]])) $app_regola2_orig[${"numtariffa".$num1}] = substr($dati_app['lista'],1,-1);
 else $app_regola2_orig[${"numtariffa".$num1}] = $dati_r2[$tariffa[$num1]];
 } # fine if (($priv_vedi_tab_periodi == "s" and $priv_vedi_tab_regole == "s" and $priv_vedi_tab_mesi == "s") or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI")
 } # fine for $num1
@@ -520,7 +521,7 @@ $nome_mese["10"] = "10";
 $nome_mese["11"] = "11";
 $nome_mese["12"] = "12";
 $colonna_destra_tab_disp = "";
-unset($condizioni_regole1_consentite);
+$condizioni_regole1_consentite = "";
 if ($attiva_regole1_consentite == "s") {
 for ($num1 = 0 ; $num1 < count($regole1_consentite) ; $num1++) if ($regole1_consentite[$num1]) $condizioni_regole1_consentite .= "motivazione = '".aggslashdb($regole1_consentite[$num1])."' or ";
 if (!$condizioni_regole1_consentite) $condizioni_regole1_consentite = "app_agenzia = ''";
@@ -762,8 +763,8 @@ echo "<br><div style=\"text-align: center; font-size: 80%;\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"cambia_mostra_tab\" value=\"1\">
-<input type=\"hidden\" name=\"mos_per_sing\" value=\"".htmlspecialchars($mos_per_sing)."\">
-<input type=\"hidden\" name=\"form_tabella\" value=\"".htmlspecialchars($form_tabella)."\">
+<input type=\"hidden\" name=\"mos_per_sing\" value=\"".htmlspecialchars(fixset($mos_per_sing))."\">
+<input type=\"hidden\" name=\"form_tabella\" value=\"".htmlspecialchars(fixset($form_tabella))."\">
 <input type=\"hidden\" name=\"num_tariffe_mostra\" value=\"$num_tariffe_mostra\">";
 $lista_tariffe_sel = "";
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
@@ -996,27 +997,27 @@ $select_tariffe</select>
 
 if ($num_tariffe_mostra == 1) {
 
-if ($dati_r2[$tariffa[1]]) {
+if (!empty($dati_r2[$tariffa[1]])) {
 $num_app = explode(",",$dati_r2[$tariffa[1]]);
 $num_app = count($num_app);
-} # fine if ($dati_r2[$tariffa[1]])
+} # fine if (!empty($dati_r2[$tariffa[1]]))
 else {
 if ($dati_app) $num_app = $dati_app['totapp'];
 else {
 $num_app = esegui_query("select idappartamenti from $tableappartamenti ");
 $num_app = numlin_query($num_app);
 } # fine else if ($dati_app)
-} # fine else if ($dati_r2[$tariffa[1]])
-if ($dati_r2['napp'][$tariffa[1]] > 1) {
+} # fine else if (!empty($dati_r2[$tariffa[1]]))
+if (isset($dati_r2['napp'][$tariffa[1]]) and $dati_r2['napp'][$tariffa[1]] > 1) {
 echo "<em><b>".$dati_r2['napp'][$tariffa[1]]."</b> ";
 if ($dati_r2['napp']['v'][$tariffa[1]]) echo strtolower(mex("Appartamenti vicini",'unit.php'));
 else echo mex("appartamenti",'unit.php');
 echo "</em>"." ".mex("tra",'crearegole.php')." ";
-} # fine if ($dati_r2['napp'][$tariffa[1]] > 1)
+} # fine if (isset($dati_r2['napp'][$tariffa[1]]) and $dati_r2['napp'][$tariffa[1]] > 1)
 if ($num_app != 1) echo "$num_app ".strtolower(mex("Appartamenti disponibili",'unit.php'));
 else echo "$num_app ".strtolower(mex("Appartamento disponibile",'unit.php'));
 echo " ".mex("in modo predefinito per la tariffa",$pag)." \"".$nometariffa_vedi[1]."\": ";
-if (!$dati_r2[$tariffa[1]]) echo "<span class=\"colwarn\"><em>".mex("tutti gli appartamenti",'unit.php')."</em></span>.";
+if (empty($dati_r2[$tariffa[1]])) echo "<span class=\"colwarn\"><em>".mex("tutti gli appartamenti",'unit.php')."</em></span>.";
 else echo "<em>".str_replace(",","</em>, <em>",$dati_r2[$tariffa[1]])."</em>.";
 if ($priv_mod_reg2 == "s") echo " <a style=\"display: inline-block; margin-bottom: 2px;\" href=\"./crearegole.php?id_sessione=$id_sessione&amp;anno=$anno&amp;tipotariffa_regola2=".$tariffa[1]."&amp;origine=tab_tariffa\">".mex("Modifica la regola di assegnazione",'interconnessioni.php')." 2</a>";
 echo "<br><br>";
@@ -1153,7 +1154,7 @@ echo "<div style=\"text-align: center;\">
 <button id=\"indi\" class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br></div>";
 
-} # fine if ($mostra_tab_tariffe != "NO")
+} # fine if (!isset($mostra_tab_tariffe) or $mostra_tab_tariffe != "NO")
 
 
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/foot.php");
