@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -25,6 +25,33 @@ $titolo = "HotelDruid: Tabella Mese";
 $base_js = 1;
 $drag_drop = 1;
 
+$var_pag = array();
+$n_var_pag = 0;
+
+$var_pag[0] = 'mese';
+$var_pag[1] = 'modificaprenotazione';
+$var_pag[2] = 'anno_succ';
+$var_pag[3] = 'idg_agg';
+$var_pag[4] = 'tipo_n_app';
+$var_pag[5] = 'tipo_tabella';
+$var_pag[6] = 'origine';
+$var_pag[7] = 'idprenota_origine';
+$var_pag[8] = 'id_prenota';
+$var_pag[9] = 'pcanc';
+$var_pag[10] = 'id_transazione';
+$var_pag[11] = 'id_nuovo_utente_inserimento';
+$var_pag[12] = 'n_stima_checkin';
+$var_pag[13] = 'n_valuta_caparra';
+$var_pag[14] = 'n_met_paga_caparra';
+$var_pag[15] = 'n_origine_prenota';
+$var_pag[16] = 'n_pagato';
+$var_pag[17] = 'n_confermato';
+$var_pag[18] = 'tipo_commento';
+$var_pag[19] = 'n_commento';
+$var_pag[20] = 'n_cancella_commento';
+$var_pag[21] = 'tableprenota_da_aggiornare';
+$n_var_pag = 22;
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -134,7 +161,7 @@ $utenti_gruppo = esegui_query("select idutente from $tablerelgruppi where idgrup
 $num_utenti_gruppo = numlin_query($utenti_gruppo);
 for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) {
 $idutente_gruppo = risul_query($utenti_gruppo,$num2,'idutente');
-if ($idutente_gruppo != $id_utente and !$utenti_gruppi[$idutente_gruppo]) {
+if ($idutente_gruppo != $id_utente and !isset($utenti_gruppi[$idutente_gruppo])) {
 $utenti_gruppi[$idutente_gruppo] = 1;
 
 if ($priv_app_gruppi == "SI") {
@@ -170,7 +197,7 @@ $priv_mod_prenotazioni_gr[$idutente_gruppo] = "n";
 } # fine else if (numlin_query($priv_anno_ut_gr) == 1)
 } # fine if ($priv_app_gruppi == "SI")
 
-} # fine if ($idutente_gruppo != $id_utente)
+} # fine if ($idutente_gruppo != $id_utente and !isset($utenti_gruppi[$idutente_gruppo]))
 } # fine for $num2
 } # fine for $num1
 } # fine if ($prendi_gruppi == "SI")
@@ -194,6 +221,7 @@ $priv_mod_orig_prenota = "s";
 $priv_vedi_commento = "s";
 $priv_vedi_commenti_pers = "s";
 $priv_vedi_tab_mesi = "s";
+$priv_oscura_tab_mesi = "";
 $attiva_contratti_consentiti = "n";
 $attiva_tariffe_consentite = "n";
 $attiva_regole1_consentite = "n";
@@ -245,6 +273,7 @@ $giorno_vedi_ini_sett = esegui_query("select valpersonalizza_num from $tablepers
 if (numlin_query($giorno_vedi_ini_sett) == 1) $giorno_vedi_ini_sett = risul_query($giorno_vedi_ini_sett,0,'valpersonalizza_num');
 else $giorno_vedi_ini_sett = 0;
 } # fine if ($tipo_periodi == "g")
+else $giorno_vedi_ini_sett = "";
 
 function ins_nome_giorno (&$var,$g_corr) {
 $var .= "<small>";
@@ -486,7 +515,7 @@ for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
 $id_appartamento = risul_query($appartamenti,$num1,'idappartamenti');
 if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO") {
 if (!strstr($dati_prenota,"<app id=\"$id_appartamento\">")) {
-if ($reg1_chiuso and $reg1_chiuso[$id_appartamento][$idg_agg]) {
+if (isset($reg1_chiuso) and $reg1_chiuso[$id_appartamento][$idg_agg]) {
 $dati_prenota .= "<app id=\"$id_appartamento\">
 <ln>1</ln><idpr>-1</idpr>
 <cogn>&amp;nbsp;</cogn>
@@ -494,7 +523,7 @@ $dati_prenota .= "<app id=\"$id_appartamento\">
 <apas>k</apas>
 <dain>1</dain>
 </app>";
-} # fine if ($reg1_chiuso and $reg1_chiuso[$id_appartamento][$idg_agg])
+} # fine if (isset($reg1_chiuso) and $reg1_chiuso[$id_appartamento][$idg_agg])
 } # fine if (!strstr($dati_prenota,"<app id=\"$id_appartamento\">"))
 } # fine if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO")
 } # fine for $num1
@@ -668,7 +697,7 @@ else include("./includes/head.php");
 
 
 
-if ($modificaprenotazione == "Continua") {
+if (isset($modificaprenotazione) and $modificaprenotazione == "Continua") {
 include_once("./includes/funzioni_mod_prenota.php");
 controlla_id_prenota($id_prenota,$id_prenota_idpr,$num_id_prenota,$id_prenota_int,$priv_mod_prenotazioni,$anno,$PHPR_TAB_PRE);
 if ($priv_mod_prenotazioni != "n") {
@@ -677,7 +706,7 @@ $cancellata = "NO";
 prepara_modifiche_prenotazione($id_prenota_idpr,$num_id_prenota,$prenota_in_anno_succ,$dati_da_anno_prec,$tra_anni,$anno,$PHPR_TAB_PRE,"");
 esegui_modifiche_prenotazione($inserire,$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_valuta_caparra,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$tipo_commento,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,$tipo_sposta,$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE,"");
 } # fine if ($priv_mod_prenotazioni != "n")
-} # fine if ($modificaprenotazione == "Continua")
+} # fine if (isset($modificaprenotazione) and $modificaprenotazione == "Continua")
 
 
 
@@ -692,6 +721,7 @@ unlock_tabelle($tabelle_lock);
 
 
 unset($tabelle_lock);
+$tabelle_lock = array();
 #$tabelle_lock = array($tableprenota);
 $altre_tab_lock = array($tableanni,$tableprenota,$tablenometariffe,$tableperiodi,$tableappartamenti,$tableclienti,$tableregole,$tablepersonalizza);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
@@ -702,10 +732,10 @@ $oggi = date("j/n/Y",(time() + (C_DIFF_ORE * 3600)));
 $ora = date("H:i",(time() + (C_DIFF_ORE * 3600)));
 echo "<small><small>".mex("situazione alle",$pag)." $ora ".mex("del",$pag)." $oggi</small></small><br>";
 
-unset($lista_prenota_contr);
+$lista_prenota_contr = "";
 
 if (controlla_num_pos($mese) != "SI") $mese = 1;
-if ($anno_succ == "SI") $mese = $mese + 12;
+if (isset($anno_succ) and $anno_succ == "SI") $mese = $mese + 12;
 
 $data_inizio_periodi = esegui_query("select * from $tableperiodi where idperiodi = 1");
 $data_inizio_periodi = risul_query($data_inizio_periodi,0,'datainizio');
@@ -887,7 +917,7 @@ if (numlin_query($allinea_tab_mesi) == 1) $allinea_tab_mesi = risul_query($allin
 else $allinea_tab_mesi = "NO";
 
 $linea_date = "<tr class=\"rd_r\"><td style=\"padding: 0 2px 0 2px\">";
-if ($inserire != "NO") $linea_date .= "<a name=\"\"></a>";
+if (!isset($inserire) or $inserire != "NO") $linea_date .= "<a name=\"\"></a>";
 $linea_date .= "<button type=\"button\" onclick=\"scorri_date('sx')\">
 <img src=\"./img/dir1_sin.png\" alt=\"&lt;\"></button><br>
 <button type=\"button\" onclick=\"scorri_date('7sx')\">
@@ -1028,7 +1058,8 @@ else $esiste = 0;
 if ($esiste == 1) $utente_inserimento = risul_query($prenotazione_presente,$prenota_corr,'utente_inserimento',$tableprenota);
 else $utente_inserimento = $id_utente;
 
-if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) or ($periodo_consentito_app[$id_appartamento][$id_settimana] == "NO" and $esiste != 1))) {
+#if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) or ($periodo_consentito_app[$id_appartamento][$id_settimana] == "NO" and $esiste != 1))) {
+if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])))) {
 $freccia_sx = "";
 $freccia_dx = "";
 if ($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) {
@@ -1088,12 +1119,13 @@ if (($id_data_inizio_tab + $num_colonne + 1) > $ini_prenota_succ) $ini_prenota_s
 else $fatto = "SI";
 } # fine if (numlin_query($prenotazione_successiva) == 1)
 else {
-if ($periodo_consentito_app[$id_appartamento][$id_inizio2] == "NO") {
+/*if ($periodo_consentito_app[$id_appartamento][$id_inizio2] == "NO") {
 $id_fine++;
 if ($id_fine == $id_data_fine_tab) $fatto = "SI";
 $colonne++;
 } # fine if ($periodo_consentito_app[$id_appartamento][$$id_inizio2] == "NO")
-else $fatto = "SI";
+else $fatto = "SI";*/
+$fatto = "SI";
 } # fine else if (numlin_query($prenotazione_successiva) == 1)
 } # fine while ($fatto == "NO")
 if ($controlla_pren_succ) {
@@ -1258,6 +1290,12 @@ else $num_ripeti++;
 
 unlock_tabelle($tabelle_lock);
 
+if ($allinea_tab_mesi != "SI") {
+echo "<tr class=\"ra_r\"><td style=\"height: 0; padding: 0; border: 0;\"></td>";
+for ($num1 = 0 ; $num1 < $num_colonne ; $num1++) echo "<td style=\"height: 0; padding: 0; border: 0;\"></td><td style=\"height: 0; padding: 0; border: 0;\"></td>";
+echo "<td style=\"height: 0; padding: 0; border: 0;\"></td></tr>";
+} # fine if ($allinea_tab_mesi != "SI")
+
 echo "</tbody></table></td></tr></table></div></div>
 <form id=\"mod_pren\" accept-charset=\"utf-8\" method=\"post\" action=\"modifica_prenota.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -1363,7 +1401,7 @@ $max_contr = risul_query($max_contr,0,0);
 $option_num_contr = "";
 for ($num_contratto = 1 ; $num_contratto <= $max_contr ; $num_contratto++) {
 if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contratto] == "SI") {
-if ($nome_contratto[$num_contratto]) $num_contratto_vedi = $nome_contratto[$num_contratto];
+if (isset($nome_contratto[$num_contratto])) $num_contratto_vedi = $nome_contratto[$num_contratto];
 else $num_contratto_vedi = $num_contratto;
 $option_num_contr .= "<option value=\"$num_contratto\">$num_contratto_vedi</option>";
 } # fine if ($attiva_contratti_consentiti == "n" or...
