@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,11 @@
 $pag = "tabella2.php";
 $titolo = "HotelDruid: Tabelle Mesi";
 
+$var_pag = array();
+$var_pag[0] = 'mese';
+$var_pag[1] = 'anno_succ';
+$n_var_pag = 2;
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -156,6 +161,7 @@ $priv_mod_prenotazioni = "s";
 $priv_mod_prenota_iniziate = "s";
 $priv_mod_prenota_ore = "000";
 $priv_vedi_tab_mesi = "s";
+$priv_oscura_tab_mesi = "";
 } # fine else if ($id_utente != 1)
 if ($anno_utente_attivato == "SI" and $priv_vedi_tab_mesi != "n") {
 
@@ -175,6 +181,7 @@ if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$t
 else include("./includes/head.php");
 
 
+$tabelle_lock = array();
 #$tabelle_lock = array("$tableprenota");
 $altre_tab_lock = array($tableprenota,$tablenometariffe,$tableperiodi,$tableappartamenti,$tableclienti,$tableregole,$tablepersonalizza);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
@@ -186,7 +193,7 @@ $ora = date("H:i",(time() + (C_DIFF_ORE * 3600)));
 echo "<small><small>".mex("situazione alle",$pag)." $ora ".mex("del",$pag)." $oggi</small></small><br>";
 
 if (controlla_num_pos($mese) != "SI") $mese = 1;
-if ($anno_succ == "SI") { $mese = $mese + 12; }
+if (isset($anno_succ) and $anno_succ == "SI") { $mese = $mese + 12; }
 
 $data_inizio_periodi = esegui_query("select * from $tableperiodi where idperiodi = 1");
 $data_inizio_periodi = risul_query($data_inizio_periodi,0,'datainizio');
@@ -249,11 +256,12 @@ if ($mese_da_aggiungere == "prima") $mese_da_aggiungere = "dopo";
 else $mese_da_aggiungere = "prima";
 } # fine for $num1
 
-if ($tutti_mesi) {
+if (fixset($tutti_mesi)) {
 $mese_ini_for = $mese_inizio_periodi;
 $mese_fine_for = $mese_fine_periodi;
 $orig_tutti_mesi = "&amp;tutti_mesi=SI";
-} # fine if ($tutti_mesi)
+} # fine if (fixset($tutti_mesi))
+else $orig_tutti_mesi = "";
 
 for ($mese2 = $mese_ini_for ; $mese2 <= $mese_fine_for ; $mese2 = $mese2 + 1) {
 
@@ -441,7 +449,8 @@ else $esiste = 0;
 if ($esiste == 1) $utente_inserimento = risul_query($prenotazione_presente,$prenota_corr,'utente_inserimento');
 else $utente_inserimento = $id_utente;
 
-if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) or ($periodo_consentito_app[$id_appartamento][$id_settimana] == "NO" and $esiste != 1))) {
+#if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) or ($periodo_consentito_app[$id_appartamento][$id_settimana] == "NO" and $esiste != 1))) {
+if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])))) {
 if ($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) {
 $id_inizio_prenota = risul_query($prenotazione_presente,$prenota_corr,'iddatainizio');
 $id_fine_prenota = risul_query($prenotazione_presente,$prenota_corr,'iddatafine');
@@ -482,12 +491,13 @@ if (($id_data_inizio_tab + $num_colonne + 1) > $ini_prenota_succ) $ini_prenota_s
 else $fatto = "SI";
 } # fine if ($id_inizio2 >= $ini_prenota_succ)
 else {
-if ($periodo_consentito_app[$id_appartamento][$id_inizio2] == "NO") {
+/*if ($periodo_consentito_app[$id_appartamento][$id_inizio2] == "NO") {
 $id_fine++;
 if ($id_fine == $id_data_fine_tab) $fatto = "SI";
 $colonne++;
 } # fine if ($periodo_consentito_app[$id_appartamento][$$id_inizio2] == "NO")
-else $fatto = "SI";
+else $fatto = "SI";*/
+$fatto = "SI";
 } # fine else if (numlin_query($prenotazione_successiva) == 1)
 } # fine while ($fatto == "NO")
 if ($priv_oscura_tab_mesi != "v" and $priv_oscura_tab_mesi != "f") {
