@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -24,6 +24,127 @@ $pag = "visualizza_contratto.php";
 $titolo = "HotelDruid: Documento";
 $extra_head = "";
 
+$var_pag = array();
+$var_pag[0] = 'origine';
+$var_pag[1] = 'id_prenota';
+$var_pag[2] = 'numero_contratto';
+$var_pag[3] = 'num_costo_agg_sel';
+$var_pag[4] = 'num_ripeti';
+$var_pag[5] = 'lista_prenota';
+$var_pag[6] = 'lista_clienti';
+$var_pag[7] = 'lista_cassa';
+$var_pag[8] = 'id_transazione';
+$var_pag[9] = 'n_file';
+$var_pag[10] = 'sovrascrivi';
+$var_pag[11] = 'origine_vecchia';
+$var_pag[12] = 'cancella';
+$var_pag[13] = 'pcanc';
+$var_pag[14] = 'data_inizio_selezione';
+$var_pag[15] = 'data_fine_selezione';
+$var_pag[16] = 'idclienti';
+$var_pag[17] = 'cont_salva';
+$var_pag[18] = 'contr_corr';
+$n_var_pag = 19;
+$num2 = 1;
+if (isset($_POST['num_ripeti'])) $num2 = (int) $_POST['num_ripeti'];
+elseif (isset($_GET['num_ripeti'])) $num2 = (int) $_GET['num_ripeti'];
+for ($num1 = 1 ; $num1 <= $num2 ; $num1++) {
+$var_pag[$n_var_pag++] = "cognome_$num1";
+$var_pag[$n_var_pag++] = "nome_$num1";
+$var_pag[$n_var_pag++] = "soprannome_$num1";
+$var_pag[$n_var_pag++] = "titolo_$num1";
+$var_pag[$n_var_pag++] = "sesso_$num1";
+$var_pag[$n_var_pag++] = "data_nascita_$num1";
+$var_pag[$n_var_pag++] = "documento_$num1";
+$var_pag[$n_var_pag++] = "tipo_documento_$num1";
+$var_pag[$n_var_pag++] = "citta_documento_$num1";
+$var_pag[$n_var_pag++] = "regione_documento_$num1";
+$var_pag[$n_var_pag++] = "nazione_documento_$num1";
+$var_pag[$n_var_pag++] = "scadenza_documento_$num1";
+$var_pag[$n_var_pag++] = "citta_nascita_$num1";
+$var_pag[$n_var_pag++] = "regione_nascita_$num1";
+$var_pag[$n_var_pag++] = "nazione_nascita_$num1";
+$var_pag[$n_var_pag++] = "cittadinanza_$num1";
+$var_pag[$n_var_pag++] = "codice_lingua_$num1";
+$var_pag[$n_var_pag++] = "nazione_$num1";
+$var_pag[$n_var_pag++] = "regione_$num1";
+$var_pag[$n_var_pag++] = "citta_$num1";
+$var_pag[$n_var_pag++] = "via_$num1";
+$var_pag[$n_var_pag++] = "numcivico_$num1";
+$var_pag[$n_var_pag++] = "telefono_$num1";
+$var_pag[$n_var_pag++] = "telefono2_$num1";
+$var_pag[$n_var_pag++] = "telefono3_$num1";
+$var_pag[$n_var_pag++] = "codice_fiscale_$num1";
+$var_pag[$n_var_pag++] = "partita_iva_$num1";
+$var_pag[$n_var_pag++] = "fax_$num1";
+$var_pag[$n_var_pag++] = "cap_$num1";
+$var_pag[$n_var_pag++] = "email_$num1";
+$var_pag[$n_var_pag++] = "email2_$num1";
+$var_pag[$n_var_pag++] = "email_certificata_$num1";
+$var_pag[$n_var_pag++] = "id_data_inizio_$num1";
+$var_pag[$n_var_pag++] = "data_inizio_$num1";
+$var_pag[$n_var_pag++] = "id_data_fine_$num1";
+$var_pag[$n_var_pag++] = "num_periodi_$num1";
+$var_pag[$n_var_pag++] = "data_fine_$num1";
+$var_pag[$n_var_pag++] = "orario_entrata_stimato_$num1";
+$var_pag[$n_var_pag++] = "orario_registrazione_entrata_$num1";
+$var_pag[$n_var_pag++] = "orario_registrazione_uscita_$num1";
+$var_pag[$n_var_pag++] = "origine_prenotazione_$num1";
+$var_pag[$n_var_pag++] = "nome_tariffa_$num1";
+$var_pag[$n_var_pag++] = "costo_tariffa_$num1";
+$var_pag[$n_var_pag++] = "tariffesettimanali_$num1";
+$var_pag[$n_var_pag++] = "percentuale_tasse_tariffa_$num1";
+$var_pag[$n_var_pag++] = "sconto_$num1";
+$var_pag[$n_var_pag++] = "caparra_$num1";
+$var_pag[$n_var_pag++] = "commissioni_$num1";
+$var_pag[$n_var_pag++] = "num_persone_$num1";
+$var_pag[$n_var_pag++] = "unita_occupata_$num1";
+$var_pag[$n_var_pag++] = "unita_assegnabili_$num1";
+$var_pag[$n_var_pag++] = "num_persone_tipo_1_$num1";
+$var_pag[$n_var_pag++] = "num_persone_tipo_2_$num1";
+$var_pag[$n_var_pag++] = "num_persone_tipo_3_$num1";
+$var_pag[$n_var_pag++] = "pagato_$num1";
+$var_pag[$n_var_pag++] = "costo_tot_$num1";
+$var_pag[$n_var_pag++] = "n_letti_agg_$num1";
+$var_pag[$n_var_pag++] = "numero_prenotazione_$num1";
+$var_pag[$n_var_pag++] = "codice_prenotazione_$num1";
+$var_pag[$n_var_pag++] = "id_anni_prec_$num1";
+$var_pag[$n_var_pag++] = "data_inserimento_prenotazione_$num1";
+$var_pag[$n_var_pag++] = "utente_inserimento_prenotazione_$num1";
+$var_pag[$n_var_pag++] = "commento_$num1";
+$var_pag[$n_var_pag++] = "promemoria_entrata_$num1";
+$var_pag[$n_var_pag++] = "promemoria_uscita_$num1";
+$var_pag[$n_var_pag++] = "metodo_pagamento_caparra_$num1";
+$var_pag[$n_var_pag++] = "num_costi_aggiuntivi_$num1";
+$num4 = 0;
+if (isset($_POST["num_costi_aggiuntivi_$num1"])) $num4 = (int) $_POST["num_costi_aggiuntivi_$num1"];
+elseif (isset($_GET["num_costi_aggiuntivi_$num1"])) $num4 = (int) $_GET["num_costi_aggiuntivi_$num1"];
+for ($num3 = 0 ; $num3 < $num4 ; $num3++) {
+$var_pag[$n_var_pag++] = "nome_costo_agg$num3"."_$num1";
+$var_pag[$n_var_pag++] = "moltiplica_max_costo_agg$num3"."_$num1";
+$var_pag[$n_var_pag++] = "giorni_costo_agg$num3"."_$num1";
+$var_pag[$n_var_pag++] = "tipo_persona_costo_agg$num3"."_$num1";
+$var_pag[$n_var_pag++] = "data_inserimento_costo_agg$num3"."_$num1";
+$var_pag[$n_var_pag++] = "utente_inserimento_costo_agg$num3"."_$num1";
+$var_pag[$n_var_pag++] = "val_costo_agg$num3"."_$num1";
+$var_pag[$n_var_pag++] = "percentuale_tasse_costo_agg$num3"."_$num1";
+$var_pag[$n_var_pag++] = "valore_giornaliero_max_costo_agg$num3"."_$num1";
+} # fine for $num3
+$var_pag[$n_var_pag++] = "num_pagamenti_$num1";
+$num4 = 0;
+if (isset($_POST["num_pagamenti_$num1"])) $num4 = (int) $_POST["num_pagamenti_$num1"];
+elseif (isset($_GET["num_pagamenti_$num1"])) $num4 = (int) $_GET["num_pagamenti_$num1"];
+for ($num3 = 0 ; $num3 < $num4 ; $num3++) {
+$var_pag[$n_var_pag++] = "data_paga$num3"."_$num1";
+$var_pag[$n_var_pag++] = "utente_paga$num3"."_$num1";
+$var_pag[$n_var_pag++] = "metodo_paga$num3"."_$num1";
+$var_pag[$n_var_pag++] = "saldo_paga$num3"."_$num1";
+$var_pag[$n_var_pag++] = "valuta_paga$num3"."_$num1";
+$var_pag[$n_var_pag++] = "tasso_cambio_paga$num3"."_$num1";
+$var_pag[$n_var_pag++] = "valore_valuta_paga$num3"."_$num1";
+} # fine for $num3
+} # fine for $num1
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -61,7 +182,7 @@ if ($id_utente) {
 
 if (str_replace("-","",$numero_contratto) != $numero_contratto) {
 $numero_contratto = explode("-",$numero_contratto);
-if (!$num_ripeti or controlla_num_pos($num_ripeti) == "NO") $num_ripeti = 1;
+if (empty($num_ripeti) or controlla_num_pos($num_ripeti) == "NO") $num_ripeti = 1;
 for ($num1 = 1 ; $num1 <= $num_ripeti ; $num1++) ${"codice_lingua_".$num1} = $numero_contratto[1];
 $numero_contratto = $numero_contratto[0];
 } # fine if (str_replace("-","",$numero_contratto) != $numero_contratto)
@@ -167,8 +288,12 @@ $nome_contratto = $nomi_contratti['salv'][$numero_contratto];
 
 $mostra_contratto = "SI";
 $mostra_foot = "";
+if (!isset($origine)) $origine = "";
+if (!isset($origine_vecchia)) $origine_vecchia = "";
+$mostra_torna_indietro = 0;
+$dir_salva = "";
 
-if ($id_transazione == "tabdoc" and $priv_vedi_tab_doc != "n") {
+if (isset($id_transazione) and $id_transazione == "tabdoc" and $priv_vedi_tab_doc != "n") {
 $contr_corr_orig = $contr_corr;
 if (substr($contr_corr,-3) == ".gz") $contr_corr = substr($contr_corr,0,-3);
 $tipo_contratto = "";
@@ -188,15 +313,15 @@ $n_file = 1;
 $nome_file_contr[$n_file] = $contr_corr_orig;
 if ($mostra_contratto == "NO") {
 unset($id_transazione);
-$mostra_torna_indietro = "SI";
+$mostra_torna_indietro = 1;
 } # fine if ($mostra_contratto == "NO")
-} # fine if ($id_transazione == "tabdoc" and $priv_vedi_tab_doc != "n")
-elseif ($id_transazione) {
+} # fine if (isset($id_transazione) and $id_transazione == "tabdoc" and $priv_vedi_tab_doc != "n")
+elseif (!empty($id_transazione)) {
 $manda_mail = "NO";
 $dati_transazione = recupera_dati_transazione($id_transazione,$id_sessione,$anno,"SI",$tipo_transazione);
 if ($tipo_transazione != "con_s") {
 $mostra_contratto = "NO";
-$mostra_torna_indietro = "SI";
+$mostra_torna_indietro = 1;
 unset($id_transazione);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
@@ -210,29 +335,44 @@ $tipo_contratto = risul_query($dati_transazione,0,'dati_transazione3');
 $origine = risul_query($dati_transazione,0,'dati_transazione4');
 $origine_vecchia = risul_query($dati_transazione,0,'dati_transazione5');
 $num_file_salva = count($nome_file_contr);
-if ($cancella == "SI" and $priv_cancella_contratti != "n") {
+if (isset($cancella) and $cancella == "SI" and $priv_cancella_contratti != "n") {
 $mostra_contratto = "NO";
-$mostra_torna_indietro = "SI";
+$mostra_torna_indietro = 1;
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 $mostra_foot = "SI";
 for ($num1 = 1 ; $num1 <= $num_file_salva ; $num1++) {
-if (@is_file($dir_salvato."/".$nome_file_contr[$num1])) unlink($dir_salvato."/".$nome_file_contr[$num1]);
+if (is_file($dir_salvato."/".$nome_file_contr[$num1])) {
+unlink($dir_salvato."/".$nome_file_contr[$num1]);
+if (strstr($nome_file_contr[$num1],"_1+1_") or strstr($nome_file_contr[$num1],"_1+1.")) {
+if (substr($nome_file_contr[$num1],-3) == ".gz") {
+$file_dat = explode(".",substr($nome_file_contr[$num1],0,-3));
+$agg_suff = 4;
+} # fine if (substr($nome_file_contr[$num1],-3) == ".gz")
+else {
+$file_dat = explode(".",$nome_file_contr[$num1]);
+$agg_suff = 1;
+} # fine else if (substr($nome_file_contr[$num1],-3) == ".gz")
+$file_dat = $file_dat[(count($file_dat) - 1)];
+$file_dat = substr($nome_file_contr[$num1],0,(-1 * (strlen($file_dat) + $agg_suff)));
+if (is_file($dir_salvato."/".$file_dat.".dat")) unlink($dir_salvato."/".$file_dat.".dat");
+} # fine if (strstr($nome_file_contr[$num1],"_1+1_") or strstr($nome_file_contr[$num1],"_1+1."))
+} # fine if (is_file($dir_salvato."/".$nome_file_contr[$num1]))
 echo "".mex("Il documento",$pag)." <b>".$nome_file_contr[$num1]."</b> ".mex("è stato <b style=\"font-weight: normal; color: blue;\">cancellato</b>",$pag).".<br>";
 } # fine for $num1
-} # fine if ($cancella == "SI" and $priv_cancella_contratti != "n")
+} # fine if (isset($cancella) and $cancella == "SI" and $priv_cancella_contratti != "n")
 elseif ($n_file < 1 or $n_file > $num_file_salva or controlla_num_pos($n_file) != "SI") $n_file = 1;
 } # fine else if ($tipo_transazione != "con_s")
-} # fine elseif ($id_transazione)
+} # fine elseif (!empty($id_transazione))
 
 
 
-if ($manda_mail == "SI") {
+if (isset($manda_mail) and $manda_mail == "SI") {
 $dati_contratto = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo $LIKE 'contr%'");
 $tipo_contratto = risul_query($dati_contratto,0,'tipo');
 if ($tipo_contratto == "contreml") {
 $mostra_contratto = "NO";
-$mostra_torna_indietro = "SI";
+$mostra_torna_indietro = 1;
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 if ($modifica_pers == "NO") {
@@ -340,13 +480,14 @@ $destinatario_email = aggslashdb(trim($destinatari_email3[$num3]));
 if (str_replace("@","",$destinatario_email) != $destinatario_email) {
 $clienti = esegui_query("select * from $tableclienti where email $ILIKE '$destinatario_email%' or email $ILIKE '% $destinatario_email%' or email $ILIKE '%,$destinatario_email%' ");
 for ($num4 = 0 ; $num4 < numlin_query($clienti) ; $num4++) {
-$doc_inviati = risul_query($clienti,$num4,'doc_inviati');
-if (str_replace("#@?".${"oggetto_email".$num1}."#@?","",$doc_inviati) == $doc_inviati) {
 $idclienti = risul_query($clienti,$num4,'idclienti');
+$doc_inviati = risul_query($clienti,$num4,'doc_inviati');
+if (str_replace("#@?".${"oggetto_email".$num1}."#|?","",$doc_inviati) == $doc_inviati) {
 if (!$doc_inviati) $doc_inviati = "#@?";
-$doc_inviati .= ${"oggetto_email".$num1}."#@?";
-esegui_query("update $tableclienti set doc_inviati = '".aggslashdb($doc_inviati)."' where idclienti = '$idclienti' ");
+$doc_inviati .= str_replace("#|?","",str_replace("#@?","",${"oggetto_email".$num1}))."#|?".date("Y-m-d",(time() + (C_DIFF_ORE * 3600)))."#@?";
 } # fine if (str_replace(${"oggetto_email".$num1},"",$doc_inviati) == $doc_inviati)
+else $doc_inviati = preg_replace("/#@\?".${"oggetto_email".$num1}."#\|\?[^#]*#@\?/","#@?".${"oggetto_email".$num1}."#|?".date("Y-m-d",(time() + (C_DIFF_ORE * 3600)))."#@?",$doc_inviati);
+esegui_query("update $tableclienti set doc_inviati = '".aggslashdb($doc_inviati)."' where idclienti = '$idclienti' ");
 } # fine for $num4
 } # fine if (str_replace("@","",$destinatario_email) != $destinatario_email)
 } # fine for $num3
@@ -358,7 +499,7 @@ else echo "<br>&nbsp;".mex("Non si è potuto inviare l'email a",$pag)." <b style
 } # fine for $num1
 
 } # fine if ($tipo_contratto == "contreml")
-} # fine if ($manda_mail == "SI")
+} # fine if (isset($manda_mail) and $manda_mail == "SI")
 
 
 
@@ -388,7 +529,7 @@ $campo_personalizzato_ = "campo_personalizzato_";
 $num_persone_tipo_ = "num_persone_tipo_";
 include("./includes/variabili_contratto.php");
 
-if (!$num_ripeti or controlla_num_pos($num_ripeti) == "NO") $num_ripeti = 1;
+if (empty($num_ripeti) or controlla_num_pos($num_ripeti) == "NO") $num_ripeti = 1;
 
 if (@get_magic_quotes_gpc()) {
 for ($n_r = 1 ; $n_r <= $num_ripeti ; $n_r++) {
@@ -397,7 +538,7 @@ for ($num1 = 0 ; $num1 < $num_var_predef_ripeti ; $num1++) ${$var_predef[$num1].
 } # fine if (@get_magic_quotes_gpc())
 
 
-if ($lista_prenota) {
+if (!empty($lista_prenota)) {
 $lista_clienti = "";
 $lista_cassa = "";
 if ($priv_vedi_tab_prenotazioni != "n" or ($priv_vedi_tab_mesi != "n" and $priv_mod_prenotazioni != "n")) {
@@ -405,30 +546,30 @@ $lista_prenota = explode(",",$lista_prenota);
 $num_ripeti = count($lista_prenota) - 2;
 include("./includes/dati_lista_prenota.php");
 } # fine if ($priv_vedi_tab_mesi != "n" or ($priv_vedi_tab_mesi != "n" and $priv_mod_prenotazioni != "n"))
-} # fine if ($lista_prenota)
+} # fine if (!empty($lista_prenota))
 
-if ($lista_clienti) {
+if (!empty($lista_clienti)) {
 $lista_cassa = "";
 if ($vedi_clienti != "NO") {
 $lista_clienti = explode(",",$lista_clienti);
 $num_ripeti = count($lista_clienti) - 2;
 include("./includes/dati_lista_clienti.php");
 } # fine if ($vedi_clienti != "NO")
-} # fine if ($lista_clienti)
+} # fine if (!empty($lista_clienti))
 
-if ($lista_cassa and controlla_num_pos($lista_cassa) == "SI") {
+if (!empty($lista_cassa) and controlla_num_pos($lista_cassa) == "SI") {
 if ($priv_vedi_tab_costi != "n" and ($attiva_casse_consentite == "n" or $casse_consentite_vett[$lista_cassa] == "SI")) {
 $num_ripeti = 1;
 include("./includes/dati_lista_cassa.php");
 } # fine if ($priv_vedi_tab_costi != "n" and ($attiva_casse_consentite == "n" or $casse_consentite_vett[$lista_cassa] == "SI"))
-} # fine if ($lista_cassa and controlla_num_pos($lista_cassa) == "SI")
+} # fine if (!empty($lista_cassa) and controlla_num_pos($lista_cassa) == "SI")
 
 
 
 $mostra_headers = "SI";
 $messaggio_di_errore = "";
 $num_contr_esist = 0;
-if (!$id_transazione) $contratto = crea_contratto($numero_contratto,$tipo_contratto,$id_utente,$id_sessione,$origine,$origine_vecchia);
+if (empty($id_transazione)) $contratto = crea_contratto($numero_contratto,$tipo_contratto,$id_utente,$id_sessione,$origine,$origine_vecchia);
 else {
 if (@is_file($dir_salvato."/".$nome_file_contr[$n_file])) {
 if (substr($nome_file_contr[$n_file],-3) == ".gz") $contratto = @gzfile($dir_salvato."/".$nome_file_contr[$n_file]);
@@ -437,17 +578,16 @@ if (@is_array($contratto)) $contratto = implode("",$contratto);
 else $contratto = "";
 } # fine if (@is_file($dir_salvato."/".$nome_file_contr[$n_file]))
 else $contratto = "";
-} # fine else if (!$id_transazione)
+} # fine else if (empty($id_transazione))
 
 if ($messaggio_di_errore) {
 $tipo_contratto = "contrhtm";
-$dir_salva = "";
 $contratto = "<div style=\"padding: 5px;\">
 <br><span class=\"colred\">".mex("Errore",$pag)."</span>:<br>
 <br><div style=\"padding: 0 0 0 10px;\">
 $messaggio_di_errore
 </div></div>";
-$mostra_torna_indietro = "SI";
+$mostra_torna_indietro = 1;
 } # fine if ($messaggio_di_errore)
 
 
@@ -464,7 +604,7 @@ $foothtm = esegui_query("select testo from $tablecontratti where numero = '$nume
 if (numlin_query($foothtm)) $foothtm = risul_query($foothtm,0,'testo');
 } # fine if (numlin_query($headhtm) == 1)
 } # fine if ($tipo_contratto == "contrhtm" and !$dir_salva)
-if ($tipo_contratto == "contreml") $mostra_torna_indietro = "SI";
+if ($tipo_contratto == "contreml") $mostra_torna_indietro = 1;
 if ($tipo_contratto == "contrrtf" and !$dir_salva) {
 $mostra_headers = "NO";
 if ($nome_file_contr) $nome_file = $nome_file_contr[$n_file];
@@ -513,7 +653,7 @@ else include("./includes/head.php");
 
 
 if ($dir_salva) {
-$mostra_torna_indietro = "SI";
+$mostra_torna_indietro = 1;
 crea_messaggio_contr_salva($nome_file_contr,$num_file_salva,$num_contr_esist,$nome_file_contr_esist,$numero_contratto,$nomi_contratti,$dir_salva,$tipo_contratto,$num_ripeti,$origine,$origine_vecchia,$lista_var_form,$mostra_headers,$anno,$id_sessione,$id_utente,$tema,$tableversioni,$tabletransazioni,$pag);
 } # fine if ($dir_salva)
 
@@ -525,7 +665,7 @@ if (!$dir_salva) echo $contratto;
 
 
 
-if ($mostra_torna_indietro == "SI") {
+if ($mostra_torna_indietro) {
 if (!$origine) $origine = "./inizio.php";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"".htmlspecialchars($origine)."\"><div><br><br>
 <input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars($origine_vecchia)."\">
@@ -534,10 +674,10 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"".htmlspecialchars
 <input type=\"hidden\" name=\"torna_indietro\" value=\"1\">
 &nbsp;&nbsp;".bottone_submit_contr(mex("Torna indietro",$pag),"indi","indietro","gobk")."
 </div></form><br>";
-} # fine if ($mostra_torna_indietro == "SI")
+} # fine if ($mostra_torna_indietro)
 
 
-if (($mostra_contratto == "SI" and $mostra_headers == "SI") or $manda_mail == "SI" or $dir_salva or $mostra_foot) {
+if (($mostra_contratto == "SI" and $mostra_headers == "SI") or (isset($manda_mail) and $manda_mail == "SI") or $dir_salva or $mostra_foot) {
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/foot.php");
 else include("./includes/foot.php");
 } # fine if (($mostra_contratto == "SI" and $mostra_headers == "SI") or...
